/* global jQuery */
jQuery( document ).ready( function( $ ) {
	"use strict";

	var $menuEdit = $( '#menu-to-edit' );

	/**
	 * Show/Hide Mega menu custom fields
	 *
	 * @returns {void}
	 */
	function showHideFields() {
		var isMegaMenuEnabled = false;

		$menuEdit.find( '.menu-item' ).each( function() {
			var $item = $( this ),
				$checkboxMegaMenuEnabled = $item.find( '.edit-menu-item-mega-menu-enabled' ),
				$selectColumns = $item.find( '.edit-menu-item-mega-menu-columns' ),
				hideColumnTitleField;

			if ( $item.hasClass( 'menu-item-depth-0' ) ) {
				if ( $checkboxMegaMenuEnabled.is( ':checked' ) ) {
					$item.addClass( 'mega-menu-show' );
					$selectColumns.prop( 'disabled', false );
					isMegaMenuEnabled = true;
				} else {
					$item.removeClass( 'mega-menu-show' );
					$selectColumns.prop( 'disabled', true );
					isMegaMenuEnabled = false;
				}

				hideColumnTitleField = true;
			} else {
				$selectColumns.prop( 'disabled', true );
				$checkboxMegaMenuEnabled.prop( 'checked', false );

				if ( isMegaMenuEnabled && $item.hasClass( 'menu-item-depth-1' ) ) {
					$item.addClass( 'mega-menu-show' );
					hideColumnTitleField = false;
				} else {
					$item.removeClass( 'mega-menu-show' );
					hideColumnTitleField = true;
				}
			}

			$item.find( '.edit-mega-menu-disable-column-title' ).prop( 'disabled', hideColumnTitleField );
		} );
	}

	/**
	 * Show/Hide Mega menu custom fields when mega menu is toggled
	 *
	 * @returns {void}
	 */
	$menuEdit.on( 'click', '.edit-menu-item-mega-menu-enabled', function() {
		var $checkboxMegaMenuEnabled = $( this ),
			$item = $checkboxMegaMenuEnabled.closest( '.menu-item' ),
			isMegaMenuEnabled = $checkboxMegaMenuEnabled.is( ':checked' );

		// Current item
		if ( isMegaMenuEnabled ) {
			$item.addClass( 'mega-menu-show' );
		} else {
			$item.removeClass( 'mega-menu-show' );
		}
		$item.find( '.edit-menu-item-mega-menu-columns' ).prop( 'disabled', !isMegaMenuEnabled );

		// Child items (DOM siblings)
		$item = $item.next();
		while ( $item.length ) {
			if ( $item.hasClass( 'menu-item-depth-1' ) ) {
				if ( isMegaMenuEnabled ) {
					$item.addClass( 'mega-menu-show' );
				} else {
					$item.removeClass( 'mega-menu-show' );
				}
				$item.find( '.edit-mega-menu-disable-column-title' ).prop( 'disabled', !isMegaMenuEnabled );
			} else if ( $item.hasClass( 'menu-item-depth-0' ) ) {
				break;
			}

			$item = $item.next();
		}

		return true;
	} );

	var showHideTimeout = false;
	$( '.menu-item-bar' ).live( 'mouseup', function( e ) {
		if ( !$( e.target ).is( 'a' ) ) {
			clearTimeout( showHideTimeout );
			showHideTimeout = setTimeout( showHideFields, 700 );
		}
	} );

	showHideFields();
} );
