<?php
/**
 * Galactica Themes
 *
 * Prevent theme from running on old and unsupported WordPress versions.
 *
 * @package GalacticaThemes
 * @subpackage Framework
 */

// Don't allow direct access
if ( !defined( 'ABSPATH' ) ) {
	die;
}


/**
 * Prevent switching to current Galactica theme on old and unsupported versions of WordPress and switch to the default theme.
 *
 * @return void
 */
function galactica_switch_theme() {
	switch_theme( WP_DEFAULT_THEME, WP_DEFAULT_THEME );
	unset( $_GET['activated'] );

	add_action( 'admin_notices', 'galactica_upgrade_notice' );
}
add_action( 'after_switch_theme', 'galactica_switch_theme' );

/**
 * Add message for unsuccessful theme switch.
 *
 * Prints an update nag after an unsuccessful attempt to switch to current Galactica theme on old and unsupported WordPress versions
 *
 * @return void
 */
function galactica_upgrade_notice() {
	$message = sprintf( esc_html__( '%s theme requires at least WordPress version %s. You are running version %s. Please upgrade WordPress and try again.', 'adama' ), GALACTICA_THEME_NAME, GALACTICA_MIN_WP_VERSION, $GLOBALS['wp_version'] );
	echo '<div class="error"><p>', $message, '</p></div>';
}

/**
 * Prevent the Theme Customizer from being loaded on old and unsupported WordPress versions
 *
 * @return void
 */
function galactica_customize() {
	wp_die( sprintf( esc_html__( '%s theme requires at least WordPress version %s. You are running version %s. Please upgrade WordPress and try again.', 'adama' ), GALACTICA_THEME_NAME, GALACTICA_MIN_WP_VERSION, $GLOBALS['wp_version'] ), '', array(
		'back_link' => true,
	) );
}
add_action( 'load-customize.php', 'galactica_customize' );

/**
 * Prevent the Theme Preview from being loaded on old and unsupported WordPress versions
 *
 * @return void
 */
function galactica_preview() {
	if ( isset( $_GET['preview'] ) ) {
		wp_die( sprintf( esc_html__( '%s theme requires at least WordPress version %s. You are running version %s. Please upgrade WordPress and try again.', 'adama' ), GALACTICA_THEME_NAME, GALACTICA_MIN_WP_VERSION, $GLOBALS['wp_version'] ) );
	}
}
add_action( 'template_redirect', 'galactica_preview' );
