<?php
/**
 * Galactica Themes
 *
 * Set up the framework and provides some helper functions.
 *
 * @package GalacticaThemes
 * @subpackage Framework
 */

// Don't allow direct access
if ( !defined( 'ABSPATH' ) ) {
	die;
}


// Helper functions
require_once( GALACTICA_FRAMEWORK_DIR . '/helper.php' );

// Mini Shortcodes
require_once( GALACTICA_FRAMEWORK_DIR . '/mini-shortcodes.php' );

// Sidebar functions
require_once( GALACTICA_FRAMEWORK_DIR . '/sidebar.php' );

// Social links/buttons
require_once( GALACTICA_FRAMEWORK_DIR . '/social.php' );

// Resizes images on the fly
require_once( GALACTICA_FRAMEWORK_DIR . '/aqua-resizer/galactica_aq_resizer.php' );

// Mega Menu
require_once( GALACTICA_FRAMEWORK_DIR . '/mega-menu.php' );

// Admin only
if ( is_admin() ) {

	// Remember current theme version so that we can detect theme updates
	// upgrader_process_complete action can be used for auto updates, but not for manual ones
	$galactica_theme_version = get_option( GALACTICA_THEME_SLUG . '_theme_version', false );
	if ( $galactica_theme_version !== GALACTICA_THEME_VERSION ) {
		update_option( GALACTICA_THEME_SLUG . '_theme_version', GALACTICA_THEME_VERSION, true );
		galactica_recompile_options_css_schedule();
	}

	/**
	 * Add CSS and JS to admin panel
	 *
	 * @return void
	 */
	function galactica_admin_assets() {
		// Include minified scripts and styles when script debug mode is off
		$min_sufix = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '.min';

		// CSS
		wp_enqueue_style( 'galactica-admin', GALACTICA_FRAMEWORK_ASSETS_URL . '/css/admin.css' );

		// JavaScript

		// Mega Menu JavaScript
		$current_screen = get_current_screen();
		if ( $current_screen->id == 'nav-menus' ) {
			wp_enqueue_script( 'galactica-mega-menu', GALACTICA_FRAMEWORK_ASSETS_URL . '/js/mega-menu' . $min_sufix . '.js', array( 'jquery' ), GALACTICA_THEME_VERSION, true );
		}
	}
	add_action( 'admin_enqueue_scripts', 'galactica_admin_assets', 100 );

} else {
	// Front end only

	// Breadcrumbs
	require_once( GALACTICA_FRAMEWORK_DIR . '/breadcrumb.php' );

	// Remove the Recent Comments default widget styles.
	add_filter( 'show_recent_comments_widget_style', '__return_false', 999 );


	if ( !function_exists( 'galactica_assets' ) ) {
		/**
		 * Register framework styles and scripts
		 *
		 * @return void
		 */
		function galactica_assets() {

			// Google Maps
			$google_maps_api_key = galactica_option( 'api_key_google_maps', '' );
			wp_register_script( 'google-maps-api', 'https://maps.googleapis.com/maps/api/js?v=3.exp&key=' . urlencode( $google_maps_api_key ), array(), GALACTICA_THEME_VERSION, true );

			// Enqueue Facebook script in footer
			wp_register_script( 'facebook-jssdk', false, array(), GALACTICA_THEME_VERSION, true );

		}
	}
	add_action( 'wp_enqueue_scripts', 'galactica_assets', 5 );

	if ( !function_exists( 'galactica_custom_scripts_footer' ) ) {
		/**
		 * Print custom scripts after _wp_footer_scripts function (use for non-important scripts like analytics and social)
		 *
		 * @return void
		 */
		function galactica_custom_scripts_footer() {
			global $wp_scripts;

			// Facebook JS SDK
			if ( wp_script_is( 'facebook-jssdk', 'enqueued' ) /* && !wp_script_is( 'facebook-jssdk', 'done' ) */ ) {
				echo '
<div id="fb-root"></div>
<script>(function(d, s, id) {
  var js, fjs = d.getElementsByTagName(s)[0];
  if (d.getElementById(id)) return;
  js = d.createElement(s); js.id = id;
  js.src = "https://connect.facebook.net/en_US/sdk.js#xfbml=1&version=v2.4";
  fjs.parentNode.insertBefore(js, fjs);
}(document, "script", "facebook-jssdk"));</script>
';

				$wp_scripts->done[] = 'facebook-jssdk';
			}

		}
	}
	add_action( 'wp_print_footer_scripts', 'galactica_custom_scripts_footer', 200, 0 );

}

/**
 * Flush rewrite rules after switching theme.
 *
 * @return void
 */
function galactica_framework_after_switch_theme() {
	flush_rewrite_rules();
}
add_action( 'after_switch_theme', 'galactica_framework_after_switch_theme' );

/**
 * Runs on WordPress Init
 *
 * @return void
 */
function galactica_framework_init() {

	// Flush rewrite rules if needed
	galactica_flush_rewrite_rules_check();

}
add_action( 'init', 'galactica_framework_init' );
