<?php
/**
 * Galactica Themes
 *
 * Mega Menu
 *
 * @package GalacticaThemes
 * @subpackage Framework
 */

// Don't allow direct access
if ( !defined( 'ABSPATH' ) ) {
	die;
}


if ( !class_exists( 'Galactica_Mega_Menu' ) ) {

	/**
	 * Mega menu admin screen.
	 */
	class Galactica_Mega_Menu {

		/**
		 * Initialization.
		 *
		 * @return void
		 */
		function __construct() {

			// Add custom fields to menu
			add_filter( 'wp_setup_nav_menu_item', array( $this, 'add_nav_custom_fields' ) );

			// Save custom fields
			add_action( 'wp_update_nav_menu_item', array( $this, 'update_nav_custom_fields' ), 10, 3 );

			// Change menu walker
			add_filter( 'wp_edit_nav_menu_walker', array( $this, 'edit_nav_menu_walker' ) );

			// Unofficial admin menu custom fields (Walker_Nav_Menu_Edit_Custom_Fields)
			add_action( 'wp_nav_menu_item_custom_fields', array( 'Galactica_Mega_Menu', 'wp_nav_menu_item_custom_fields' ), 10, 2 );
		}

		/**
		 * Add custom fields to $item object
		 *
		 * @param object $menu_item   Menu item data object.
		 *
		 * @return object   Menu item data object.
		 */
		function add_nav_custom_fields( $menu_item ) {

			// Level 0
			$menu_item->mega_menu_enabled = get_post_meta( $menu_item->ID, '_menu_item_galactica_mega_menu_enabled', true );
			$menu_item->mega_menu_columns = get_post_meta( $menu_item->ID, '_menu_item_galactica_mega_menu_columns', true );

			// Level 1
			$menu_item->mega_menu_disable_column_title = get_post_meta( $menu_item->ID, '_menu_item_galactica_mega_menu_disable_column_title', true );

			return $menu_item;

		}

		/**
		 * Update custom fields
		 *
		 * @param int   $menu_id         The ID of the menu.
		 * @param int   $menu_item_db_id The ID of the menu item.
		 * @param array $args            The menu item's data.
		 *
		 * @return void
		 */
		function update_nav_custom_fields( $menu_id, $menu_item_db_id, $args ) {

			if ( isset( $_REQUEST['menu-settings-column-nonce'] ) ) {
				check_admin_referer( 'add-menu_item', 'menu-settings-column-nonce' );
			} else if ( isset( $_REQUEST['update-nav-menu-nonce'] ) ) {
				check_admin_referer( 'update-nav_menu', 'update-nav-menu-nonce' );
			} else {
				return;
			}

			// Level 0
			// Enable Mega menu
			$mega_menu_enabled = isset( $_REQUEST['menu-item-mega-menu-enabled'], $_REQUEST['menu-item-mega-menu-enabled'][$menu_item_db_id]);
			update_post_meta( $menu_item_db_id, '_menu_item_galactica_mega_menu_enabled', $mega_menu_enabled );

			// Columns
			if ( isset( $_REQUEST['menu-item-mega-menu-columns'], $_REQUEST['menu-item-mega-menu-columns'][$menu_item_db_id] ) && is_array( $_REQUEST['menu-item-mega-menu-columns'] ) ) {
				$mega_menu_columns = absint( $_REQUEST['menu-item-mega-menu-columns'][$menu_item_db_id] );
				update_post_meta( $menu_item_db_id, '_menu_item_galactica_mega_menu_columns', $mega_menu_columns );
			}

			// Level 1
			// Disable Mega Menu Column Title
			$mega_menu_disable_column_title = isset( $_REQUEST['menu-item-mega-menu-disable-column-title'], $_REQUEST['menu-item-mega-menu-disable-column-title'][$menu_item_db_id]);
			update_post_meta( $menu_item_db_id, '_menu_item_galactica_mega_menu_disable_column_title', $mega_menu_disable_column_title );

		}

		/**
		 * Change Walker
		 *
		 * @param string $walker The walker class to use.
		 * @return string
		 */
		function edit_nav_menu_walker( $walker ) {

			if ( $walker === 'Walker_Nav_Menu_Edit' ) {
				$walker = 'Galactica_Mega_Menu_Walker_Nav_Menu_Edit';
			}

			return $walker;

		}

		/**
		 * Unofficial admin menu custom fields (Walker_Nav_Menu_Edit_Custom_Fields)
		 * @param type $item_id
		 * @param type $item
		 */
		public static function wp_nav_menu_item_custom_fields( $item_id, $item ) {

			?>

			<!-- Custom field Enable Mega menu -->
			<p class="field-mega-menu-enabled description description-wide">
				<label for="edit-menu-item-mega-menu-enabled-<?php echo $item_id; ?>">
					<input id="edit-menu-item-mega-menu-enabled-<?php echo $item_id; ?>" type="checkbox" class="edit-menu-item-mega-menu-enabled" name="menu-item-mega-menu-enabled[<?php echo $item_id; ?>]" <?php checked( $item->mega_menu_enabled ); ?>/>
					<?php esc_html_e( 'Enable mega menu', 'adama' ); ?>
				</label>
			</p>

			<!-- Custom field Columns -->
			<p class="field-mega-menu-columns description description-thin">
				<label for="edit-menu-item-mega-menu-columns-<?php echo $item_id; ?>">
					<?php esc_html_e( 'Mega menu columns:', 'adama' ); ?>
					<select name="menu-item-mega-menu-columns[<?php echo $item_id; ?>]" id="edit-menu-item-mega-menu-columns-<?php echo $item_id; ?>" class="widefat edit-menu-item-mega-menu-columns">
						<?php foreach( array( '1' => 1, '2' => 2, '3' => 3, '4' => 4 ) as $text => $value): ?>
							<option value="<?php echo esc_attr( $value ); ?>" <?php selected( $value, $item->mega_menu_columns ); ?>><?php echo esc_html( $text ); ?></option>
						<?php endforeach; ?>
					</select>
				</label>
			</p>

			<!-- Custom field Disable column title -->
			<p class="field-mega-menu-disable-column-title description description-wide">
				<label for="edit-mega-menu-disable-column-title-<?php echo $item_id; ?>">
					<input id="edit-mega-menu-disable-column-title-<?php echo $item_id; ?>" type="checkbox" class="edit-mega-menu-disable-column-title" name="menu-item-mega-menu-disable-column-title[<?php echo $item_id; ?>]" <?php checked( $item->mega_menu_disable_column_title ); ?>/>
					<?php esc_html_e( 'Disable column title in mega menu', 'adama' ); ?>
				</label>
			</p>

			<?php
		}

	}
}
new Galactica_Mega_Menu();


/**
 * Create HTML list of nav menu input items.
 *
 * @package WordPress
 * @since 3.0.0
 * @uses Walker_Nav_Menu
 */
class Galactica_Mega_Menu_Walker_Nav_Menu_Edit extends Walker_Nav_Menu {
	/**
	 * Starts the list before the elements are added.
	 *
	 * @see Walker_Nav_Menu::start_lvl()
	 *
	 * @since 3.0.0
	 *
	 * @param string $output Passed by reference.
	 * @param int    $depth  Depth of menu item. Used for padding.
	 * @param array  $args   Not used.
	 */
	public function start_lvl( &$output, $depth = 0, $args = array() ) {}

	/**
	 * Ends the list of after the elements are added.
	 *
	 * @see Walker_Nav_Menu::end_lvl()
	 *
	 * @since 3.0.0
	 *
	 * @param string $output Passed by reference.
	 * @param int    $depth  Depth of menu item. Used for padding.
	 * @param array  $args   Not used.
	 */
	public function end_lvl( &$output, $depth = 0, $args = array() ) {}

	/**
	 * Start the element output.
	 *
	 * @see Walker_Nav_Menu::start_el()
	 * @since 3.0.0
	 *
	 * @global int $_wp_nav_menu_max_depth
	 *
	 * @param string $output Passed by reference. Used to append additional content.
	 * @param object $item   Menu item data object.
	 * @param int    $depth  Depth of menu item. Used for padding.
	 * @param array  $args   Not used.
	 * @param int    $id     Not used.
	 */
	public function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {
		global $_wp_nav_menu_max_depth;
		$_wp_nav_menu_max_depth = $depth > $_wp_nav_menu_max_depth ? $depth : $_wp_nav_menu_max_depth;

		ob_start();
		$item_id = esc_attr( $item->ID );
		$removed_args = array(
			'action',
			'customlink-tab',
			'edit-menu-item',
			'menu-item',
			'page-tab',
			'_wpnonce',
		);

		$original_title = false;
		if ( 'taxonomy' == $item->type ) {
			$original_title = get_term_field( 'name', $item->object_id, $item->object, 'raw' );
			if ( is_wp_error( $original_title ) )
				$original_title = false;
		} elseif ( 'post_type' == $item->type ) {
			$original_object = get_post( $item->object_id );
			$original_title = get_the_title( $original_object->ID );
		} elseif ( 'post_type_archive' == $item->type ) {
			$original_object = get_post_type_object( $item->object );
			if ( $original_object ) {
				$original_title = $original_object->labels->archives;
			}
		}

		$classes = array(
			'menu-item menu-item-depth-' . $depth,
			'menu-item-' . esc_attr( $item->object ),
			'menu-item-edit-' . ( ( isset( $_GET['edit-menu-item'] ) && $item_id == $_GET['edit-menu-item'] ) ? 'active' : 'inactive'),
		);

		$title = $item->title;

		if ( ! empty( $item->_invalid ) ) {
			$classes[] = 'menu-item-invalid';
			/* translators: %s: title of menu item which is invalid */
			$title = sprintf( esc_html__( '%s (Invalid)', 'adama' ), $item->title );
		} elseif ( isset( $item->post_status ) && 'draft' == $item->post_status ) {
			$classes[] = 'pending';
			/* translators: %s: title of menu item in draft status */
			$title = sprintf( esc_html__( '%s (Pending)', 'adama' ), $item->title );
		}

		$title = ( ! isset( $item->label ) || '' == $item->label ) ? $title : $item->label;

		$submenu_text = '';
		if ( 0 == $depth )
			$submenu_text = 'style="display: none;"';

		?>
		<li id="menu-item-<?php echo $item_id; ?>" class="<?php echo implode(' ', $classes ); ?>">
			<div class="menu-item-bar">
				<div class="menu-item-handle">
					<span class="item-title"><span class="menu-item-title"><?php echo esc_html( $title ); ?></span> <span class="is-submenu" <?php echo $submenu_text; ?>><?php esc_html_e( 'sub item', 'adama' ); ?></span></span>
					<span class="item-controls">
						<span class="item-type"><?php echo esc_html( $item->type_label ); ?></span>
						<span class="item-order hide-if-js">
							<a href="<?php
								echo wp_nonce_url(
									add_query_arg(
										array(
											'action' => 'move-up-menu-item',
											'menu-item' => $item_id,
										),
										remove_query_arg($removed_args, admin_url( 'nav-menus.php' ) )
									),
									'move-menu_item'
								);
							?>" class="item-move-up" aria-label="<?php esc_attr_e( 'Move up', 'adama' ) ?>">&#8593;</a>
							|
							<a href="<?php
								echo wp_nonce_url(
									add_query_arg(
										array(
											'action' => 'move-down-menu-item',
											'menu-item' => $item_id,
										),
										remove_query_arg($removed_args, admin_url( 'nav-menus.php' ) )
									),
									'move-menu_item'
								);
							?>" class="item-move-down" aria-label="<?php esc_attr_e( 'Move down', 'adama' ); ?>">&#8595;</a>
						</span>
						<a class="item-edit" id="edit-<?php echo $item_id; ?>" href="<?php
							echo ( isset( $_GET['edit-menu-item'] ) && $item_id == $_GET['edit-menu-item'] ) ? admin_url( 'nav-menus.php' ) : add_query_arg( 'edit-menu-item', $item_id, remove_query_arg( $removed_args, admin_url( 'nav-menus.php#menu-item-settings-' . $item_id ) ) );
						?>" aria-label="<?php esc_attr_e( 'Edit Menu Item', 'adama'); ?>"><?php esc_html_e( 'Edit', 'adama' ); ?></a>
					</span>
				</div>
			</div>

			<div class="menu-item-settings wp-clearfix" id="menu-item-settings-<?php echo $item_id; ?>">
				<?php if ( 'custom' == $item->type ) : ?>
					<p class="field-url description description-wide">
						<label for="edit-menu-item-url-<?php echo $item_id; ?>">
							<?php esc_html_e( 'URL', 'adama' ); ?><br />
							<input type="text" id="edit-menu-item-url-<?php echo $item_id; ?>" class="widefat code edit-menu-item-url" name="menu-item-url[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->url ); ?>" />
						</label>
					</p>
				<?php endif; ?>
				<p class="description description-wide">
					<label for="edit-menu-item-title-<?php echo $item_id; ?>">
						<?php esc_html_e( 'Navigation Label', 'adama' ); ?><br />
						<input type="text" id="edit-menu-item-title-<?php echo $item_id; ?>" class="widefat edit-menu-item-title" name="menu-item-title[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->title ); ?>" />
					</label>
				</p>
				<p class="field-title-attribute field-attr-title description description-wide">
					<label for="edit-menu-item-attr-title-<?php echo $item_id; ?>">
						<?php esc_html_e( 'Title Attribute', 'adama' ); ?><br />
						<input type="text" id="edit-menu-item-attr-title-<?php echo $item_id; ?>" class="widefat edit-menu-item-attr-title" name="menu-item-attr-title[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->post_excerpt ); ?>" />
					</label>
				</p>
				<p class="field-link-target description">
					<label for="edit-menu-item-target-<?php echo $item_id; ?>">
						<input type="checkbox" id="edit-menu-item-target-<?php echo $item_id; ?>" value="_blank" name="menu-item-target[<?php echo $item_id; ?>]"<?php checked( $item->target, '_blank' ); ?> />
						<?php esc_html_e( 'Open link in a new tab', 'adama' ); ?>
					</label>
				</p>
				<p class="field-css-classes description description-thin">
					<label for="edit-menu-item-classes-<?php echo $item_id; ?>">
						<?php esc_html_e( 'CSS Classes (optional)', 'adama' ); ?><br />
						<input type="text" id="edit-menu-item-classes-<?php echo $item_id; ?>" class="widefat code edit-menu-item-classes" name="menu-item-classes[<?php echo $item_id; ?>]" value="<?php echo esc_attr( implode(' ', $item->classes ) ); ?>" />
					</label>
				</p>
				<p class="field-xfn description description-thin">
					<label for="edit-menu-item-xfn-<?php echo $item_id; ?>">
						<?php esc_html_e( 'Link Relationship (XFN)', 'adama' ); ?><br />
						<input type="text" id="edit-menu-item-xfn-<?php echo $item_id; ?>" class="widefat code edit-menu-item-xfn" name="menu-item-xfn[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->xfn ); ?>" />
					</label>
				</p>
				<p class="field-description description description-wide">
					<label for="edit-menu-item-description-<?php echo $item_id; ?>">
						<?php esc_html_e( 'Description', 'adama' ); ?><br />
						<textarea id="edit-menu-item-description-<?php echo $item_id; ?>" class="widefat edit-menu-item-description" rows="3" cols="20" name="menu-item-description[<?php echo $item_id; ?>]"><?php echo esc_html( $item->description ); // textarea_escaped ?></textarea>
						<span class="description"><?php esc_html_e( 'The description will be displayed in the menu if the current theme supports it.', 'adama' ); ?></span>
					</label>
				</p>

				<?php // Custom fields
				Galactica_Mega_Menu::wp_nav_menu_item_custom_fields( $item_id, $item ); ?>

				<p class="field-move hide-if-no-js description description-wide">
					<label>
						<span><?php esc_html_e( 'Move', 'adama' ); ?></span>
						<a href="#" class="menus-move menus-move-up" data-dir="up"><?php esc_html_e( 'Up one', 'adama' ); ?></a>
						<a href="#" class="menus-move menus-move-down" data-dir="down"><?php esc_html_e( 'Down one', 'adama' ); ?></a>
						<a href="#" class="menus-move menus-move-left" data-dir="left"></a>
						<a href="#" class="menus-move menus-move-right" data-dir="right"></a>
						<a href="#" class="menus-move menus-move-top" data-dir="top"><?php esc_html_e( 'To the top', 'adama' ); ?></a>
					</label>
				</p>

				<div class="menu-item-actions description-wide submitbox">
					<?php if ( 'custom' != $item->type && $original_title !== false ) : ?>
						<p class="link-to-original">
							<?php printf( esc_html__( 'Original: %s', 'adama' ), '<a href="' . esc_attr( $item->url ) . '">' . esc_html( $original_title ) . '</a>' ); ?>
						</p>
					<?php endif; ?>
					<a class="item-delete submitdelete deletion" id="delete-<?php echo $item_id; ?>" href="<?php
					echo wp_nonce_url(
						add_query_arg(
							array(
								'action' => 'delete-menu-item',
								'menu-item' => $item_id,
							),
							admin_url( 'nav-menus.php' )
						),
						'delete-menu_item_' . $item_id
					); ?>"><?php esc_html_e( 'Remove', 'adama' ); ?></a> <span class="meta-sep hide-if-no-js"> | </span> <a class="item-cancel submitcancel hide-if-no-js" id="cancel-<?php echo $item_id; ?>" href="<?php echo esc_url( add_query_arg( array( 'edit-menu-item' => $item_id, 'cancel' => time() ), admin_url( 'nav-menus.php' ) ) );
						?>#menu-item-settings-<?php echo $item_id; ?>"><?php esc_html_e( 'Cancel', 'adama' ); ?></a>
				</div>

				<input class="menu-item-data-db-id" type="hidden" name="menu-item-db-id[<?php echo $item_id; ?>]" value="<?php echo $item_id; ?>" />
				<input class="menu-item-data-object-id" type="hidden" name="menu-item-object-id[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->object_id ); ?>" />
				<input class="menu-item-data-object" type="hidden" name="menu-item-object[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->object ); ?>" />
				<input class="menu-item-data-parent-id" type="hidden" name="menu-item-parent-id[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->menu_item_parent ); ?>" />
				<input class="menu-item-data-position" type="hidden" name="menu-item-position[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->menu_order ); ?>" />
				<input class="menu-item-data-type" type="hidden" name="menu-item-type[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->type ); ?>" />
			</div><!-- .menu-item-settings-->
			<ul class="menu-item-transport"></ul>
		<?php
		$output .= ob_get_clean();
	}

} // Walker_Nav_Menu_Edit
