<?php
/**
 * Galactica Themes
 *
 * Mini Shortcodes for footer texts.
 *
 * @package GalacticaThemes
 * @subpackage Framework
 */

// Don't allow direct access
if ( !defined( 'ABSPATH' ) ) {
	die;
}


if ( !function_exists( 'galactica_do_mini_shortcode' ) ) {
	/**
	 * Regular Expression callable for do_shortcode() for calling shortcode hook.
	 *
	 * @param array $match Regular expression match array
	 * @return string
	 */
	function galactica_do_mini_shortcode( $match ) {

		$out = '';

		switch ( $match[1] ) {
			case 'current-year':
				$out = date( 'Y' );
				break;
			case 'site-title':
				$out = esc_html( get_bloginfo( 'name' ) );
				break;
			case 'site-tagline':
				$out = esc_html( get_bloginfo( 'description' ) );
				break;
			case 'site-url':
				$out = sprintf( '<a href="%s" target="_blank">%s</a>', esc_url( site_url() ), esc_html( get_bloginfo( 'name' ) ) );
				break;
			case 'theme-url':
				$out = sprintf( '<a href="%s" target="_blank">%s</a>', GALACTICA_WEBSITE_URL, esc_html( GALACTICA_THEME_NAME ) );
				break;
			case 'wp-url':
				$out = '<a href="https://wordpress.org/" target="_blank">WordPress</a>';
				break;
			default:
				$out = $match[0];
				break;
		}

		return $out;
	}
}

if ( !function_exists( 'galactica_mini_shortcode' ) ) {
	/**
	 * Find and replace mini shortcodes in text.
	 *
	 * @param array $text Regular expression match array
	 * @return string
	 */
	function galactica_mini_shortcode( $text ) {
		$text = preg_replace_callback( '/\[(current-year|site-title|site-tagline|site-url|theme-url|wp-url)\]/s', 'galactica_do_mini_shortcode', $text );
		return $text;
	}
}
