<?php
/**
 * Galactica Themes
 *
 * Sidebar functions
 *
 * @package GalacticaCore
 * @subpackage SidebarManager
 */

// Don't allow direct access
if ( !defined( 'ABSPATH' ) ) {
	die;
}


if ( !function_exists( 'galactica_sidebar_body_class' ) ) {
	/**
	 * Return body class that depend on position of the sidebar
	 *
	 * @return string
	 */
	function galactica_sidebar_body_class() {

		$body_class = '';

		// Disable classic sidebar on fullwidth template
		if ( is_page_template( 'templates/fullwidth.php' ) ) {
			$body_class = 'sidebar-none';
		}

		// Sidebar Manager
		if ( empty( $body_class ) && galactica_option( 'enable_sidebar_manager', true ) ) {

			// wp_reset_query();

			$page_id = galactica_get_page_id();
			if ( !empty( $page_id ) ) {
				$sidebar_position = get_post_meta( $page_id, 'galactica_sidebar_position', true );
			}

			if ( is_post_type_archive( 'post' ) || is_category() || is_tag() || is_date() || ( empty( $sidebar_position ) && ( is_singular( 'post' ) || is_home() ) ) ) {
				// Blog
				$sidebar_position = galactica_option( 'blog_sidebar_position', 'none' );
			} else if ( is_tax( array( 'bsg_portfolio_category', 'bsg_portfolio_technology', 'bsg_portfolio_tags' ) ) || ( empty( $sidebar_position ) && ( is_singular( 'bsg_portfolio' ) || is_page_template( 'templates/portfolio-boxed.php' ) ) ) ) {
				// Portfolio
				$sidebar_position = galactica_option( 'portfolio_sidebar_position', 'none' );
			}

			if ( !empty( $sidebar_position ) ) {
				// Custom sidebar
				$body_class = "sidebar-{$sidebar_position}";
			}

		}

		if ( empty( $body_class ) ) {
			$sidebar_position = galactica_option( 'sidebar_position', 'none' );
			$body_class = "sidebar-{$sidebar_position}";
		}

		return $body_class;
	}
}

if ( !function_exists( 'galactica_is_sidebar_enabled' ) ) {
	/**
	 * Test if sidebar should be shown
	 *
	 * @return bool
	 */
	function galactica_is_sidebar_enabled() {

		// Disable classic sidebar on fullwidth template
		if ( is_page_template( 'templates/fullwidth.php' ) ) {
			return false;
		}

		// Sidebar Manager
		if ( galactica_option( 'enable_sidebar_manager', true ) ) {

			// wp_reset_query();

			$page_id = galactica_get_page_id();
			if ( !empty( $page_id ) ) {
				$sidebar_position = get_post_meta( $page_id, 'galactica_sidebar_position', true );
			}

			if ( is_post_type_archive( 'post' ) || is_category() || is_tag() || is_date() || ( empty( $sidebar_position ) && ( is_singular( 'post' ) || is_home() ) ) ) {
				// Blog
				$sidebar_position = galactica_option( 'blog_sidebar_position', 'none' );
			} else if ( is_tax( array( 'bsg_portfolio_category', 'bsg_portfolio_technology', 'bsg_portfolio_tags' ) ) || ( empty( $sidebar_position ) && ( is_singular( 'bsg_portfolio' ) || is_page_template( 'templates/portfolio-boxed.php' ) ) ) ) {
				// Portfolio
				$sidebar_position = galactica_option( 'portfolio_sidebar_position', 'none' );
			}

			if ( !empty( $sidebar_position ) ) {
				if ( $sidebar_position === 'none' ) {
					return false;
				} else {
					return true;
				}
			}

		}

		$sidebar_position = galactica_option( 'sidebar_position', 'none' );
		if ( empty( $sidebar_position ) || $sidebar_position === 'none' ) {
			return false;
		}

		return true;
	}
}

if ( !function_exists( 'galactica_dynamic_sidebar' ) ) {
	/**
	 * Display dynamic sidebar from theme's Sidebar Manager
	 *
	 * @param int|string $name Optional, default is 'galactica-sidebar'. Index, name or ID of dynamic sidebar
	 * @param string $position Which sidebar position should we check
	 * @return bool True, if widget sidebar was found and called. False if not found or not called
	 */
	function galactica_dynamic_sidebar( $name = 'galactica-sidebar', $position = 'classic' ) {

		// Sidebar Manager
		if ( galactica_option( 'enable_sidebar_manager', true ) ) {

			// wp_reset_query();

			$page_id = galactica_get_page_id();
			if ( !empty( $page_id ) ) {
				$sidebar_name = get_post_meta( $page_id, "galactica_sidebar_{$position}", true );
			}

			if ( $position === 'classic' ) {
				if ( galactica_option( 'blog_enable_custom_sidebar', false ) && ( is_post_type_archive( 'post' ) || is_category() || is_tag() || is_date() || ( empty( $sidebar_name ) && ( is_singular( 'post' ) || is_home() ) ) ) ) {
					// Blog
					$sidebar_name = 'galactica-blog-sidebar';
				} else if ( galactica_option( 'portfolio_enable_custom_sidebar', false ) && ( is_tax( array( 'bsg_portfolio_category', 'bsg_portfolio_technology', 'bsg_portfolio_tags' ) ) || ( empty( $sidebar_name ) && ( is_singular( 'bsg_portfolio' ) || is_page_template( 'templates/portfolio-boxed.php' ) ) ) ) ) {
					// Portfolio
					$sidebar_name = 'galactica-portfolio-sidebar';
				}
			}

			if ( !empty( $sidebar_name ) ) {
				// Custom sidebar
				return dynamic_sidebar( $sidebar_name );
			}

		}

		return dynamic_sidebar( $name );
	}
}

if ( !function_exists( 'galactica_slideout_is_active_sidebar' ) ) {
	/**
	 * Test if slideout sidebar is active
	 *
	 * @return bool
	 */
	function galactica_slideout_is_active_sidebar() {

		$sidebar_slideout = 'galactica-slideout';

		// Sidebar Manager
		if ( galactica_option( 'enable_sidebar_manager', true ) ) {

			// wp_reset_query();

			$page_id = galactica_get_page_id();
			if ( !empty( $page_id ) ) {
				$sidebar_slideout_replacement = get_post_meta( $page_id, 'galactica_sidebar_slideout', true );
				if ( !empty( $sidebar_slideout_replacement ) ) {
					$sidebar_slideout = $sidebar_slideout_replacement;
				}
			}

		}

		return is_active_sidebar( $sidebar_slideout );
	}
}
