<?php
/**
 * Galactica Themes
 *
 * Social functions.
 *
 * @package GalacticaThemes
 * @subpackage Framework
 */

// Don't allow direct access
if ( !defined( 'ABSPATH' ) ) {
	die;
}


/**
 * Get supported social list.
 *
 * @param string $context Location from where is this function called.
 * @return array
 */
function galactica_social_list( $context = '' ) {

	$social_list = array(
		array(
			'name' => esc_html__( 'Google+', 'adama' ),
			'slug' => 'google_plus',
			'icon' => 'fa-google-plus',
		),
		array(
			'name' => esc_html__( 'Facebook', 'adama' ),
			'slug' => 'facebook',
			'icon' => 'fa-facebook',
		),
		array(
			'name' => esc_html__( 'Flickr', 'adama' ),
			'slug' => 'flickr',
			'icon' => 'fa-flickr',
		),
		array(
			'name' => esc_html__( 'Dribbble', 'adama' ),
			'slug' => 'dribbble',
			'icon' => 'fa-dribbble',
		),
		array(
			'name' => esc_html__( 'Instagram', 'adama' ),
			'slug' => 'instagram',
			'icon' => 'fa-instagram',
		),
		array(
			'name' => esc_html__( 'LinkedIn', 'adama' ),
			'slug' => 'linkedin',
			'icon' => 'fa-linkedin',
		),
		array(
			'name' => esc_html__( 'Pinterest', 'adama' ),
			'slug' => 'pinterest',
			'icon' => 'fa-pinterest',
		),
		array(
			'name' => esc_html__( 'Reddit', 'adama' ),
			'slug' => 'reddit',
			'icon' => 'fa-reddit',
		),
		array(
			'name' => esc_html__( 'RSS', 'adama' ),
			'slug' => 'rss',
			'icon' => 'fa-rss',
		),
		array(
			'name'			 => esc_html__( 'Skype', 'adama' ),
			'slug'			 => 'skype',
			'icon'			 => 'fa-skype',
			'is_username'	 => true,
		),
		array(
			'name' => esc_html__( 'Tumblr', 'adama' ),
			'slug' => 'tumblr',
			'icon' => 'fa-tumblr',
		),
		array(
			'name' => esc_html__( 'Twitter', 'adama' ),
			'slug' => 'twitter',
			'icon' => 'fa-twitter',
		),
		array(
			'name' => esc_html__( 'Youtube', 'adama' ),
			'slug' => 'youtube',
			'icon' => 'fa-youtube-play',
		),
		array(
			'name' => esc_html__( 'Website', 'adama' ),
			'slug' => 'website',
			'icon' => 'fa-globe',
		),
	);

	return apply_filters( 'galactica/social/list', $social_list, $context );
}

if ( !function_exists( 'galactica_team_social_list_html' ) ) {
	/**
	 * Get social list html for team member.
	 *
	 * @param array $args {
	 *     Optional. Arguments to generate social list.
	 *
	 *     @type string $before The HTML or text to prepend to social list. Default empty.
	 *     @type string $after The HTML or text to append to social list. Default empty.
	 *     @type string $classes Classes for social list. Default 'social-icons'.
	 * }
	 * @return text HTML
	 */
	function galactica_team_social_list_html( $args = array() ) {
		$defaults = array(
			'before'  => '',
			'after'   => '',
			'classes' => 'social-icons',
		);
		$args = wp_parse_args( $args, $defaults );

		$output = '';
		$social_list = galactica_social_list( 'team-member' );

		if ( !empty( $social_list ) ) {
			foreach ( $social_list as $social_item ) {
				$url = get_post_meta( get_the_ID(), "adama_team_social_{$social_item['slug']}", true );

				if ( !empty( $url ) ) {
					$output .= sprintf(
						'<li class="social-%s">
							<a href="%s" target="_blank"><i class="fa %s"></i></a>
						</li>',
						sanitize_html_class( $social_item['slug'] ),
						galactica_esc_social_url( $url, $social_item['slug'] ),
						sanitize_html_class( $social_item['icon'] )
					);
				}
			}

			if ( !empty( $output ) ) {
				$output = $args['before'] . '<ul class="' . esc_attr( $args['classes'] ) . '">' . $output . '</ul>' . $args['after'];
			}
		}

		return $output;
	}
}

if ( !function_exists( 'galactica_kses_allowed_protocols' ) ) {
	/**
	 * Added Skype to allowed protocols
	 * @param array $protocols
	 * @return array
	 */
	function galactica_kses_allowed_protocols( $protocols ) {
		$protocols[] = 'skype';
		return $protocols;
	}
}
add_filter( 'kses_allowed_protocols', 'galactica_kses_allowed_protocols' );
