<?php
/**
 * Single Portfolio Template
 *
 * @package GalacticaThemes
 * @subpackage Template
 */

get_header(); ?>

<section class="w-section">
	<div class="container container-outer <?php echo adama_get_single_portfolio_layout_class(); ?>">
		<div class="row">

			<div id="content" class="col-md-9 col-content" role="main">

				<?php if ( have_posts() ) : ?>
					<?php while ( have_posts() ) : the_post(); ?>

						<div class="container container-inner">

							<div class="portfolio-media-wrap">
								<?php
								switch ( get_post_meta( get_the_ID(), 'adama_portfolio_single_type', true ) ) {
									case 'slider':
										echo adama_portfolio_slider();
										break;
									case 'video':
										$portfolio_oembed = get_post_meta( get_the_ID(), 'adama_portfolio_oembed', true );

										if ( !empty( $portfolio_oembed ) && ( $oembed = wp_oembed_get( $portfolio_oembed ) ) ) { ?>
											<div class="portfolio-video embed-responsive embed-responsive-16by9">
												<?php echo $oembed; ?>
											</div>
										<?php }
										break;
									default:
										if ( has_post_thumbnail() ) {
											echo adama_get_post_thumbnail( array( 'class' => 'img-responsive' ) );
										}
										break;
								}
								 ?>
							</div>

							<div class="vertical-info-wrap">
								<?php
									$portfolio_intro = get_post_meta( get_the_ID(), 'adama_portfolio_intro', true );

									if ( !empty( $portfolio_intro ) ) {
										echo '<div class="col-md-12 portfolio-intro">' . apply_filters( 'the_content', $portfolio_intro ) . '</div>';
									}


									$vertical_info_out = '';
									$portfolio_content_full_width = ' portfolio-content-full';

									$portfolio_attributes_title = get_post_meta( get_the_ID(), 'adama_portfolio_attributes_title', true );

									if ( !empty( $portfolio_attributes_title ) ) {
										$vertical_info_out .= sprintf( '<h3 class="title-underline">%s</h3>', esc_html( $portfolio_attributes_title ) );
									}

									// Technologies
									if ( has_term( '', 'bsg_portfolio_technology' ) ) {
										$vertical_info_out .= sprintf(
											'<div class="vertical-info-box">
												<h4>%1$s</h4>
												<div class="vertical-info-content">
													%2$s
												</div>
											</div>',
											esc_html( 'Technologies:', 'adama' ),
											get_the_term_list( get_the_ID(), 'bsg_portfolio_technology', '', ', ', '' )
										);
									}

									// Categories
									if ( has_term( '', 'bsg_portfolio_category' ) ) {
										$vertical_info_out .= sprintf(
											'<div class="vertical-info-box">
												<h4>%1$s</h4>
												<div class="vertical-info-content">
													%2$s
												</div>
											</div>',
											esc_html( 'Categories:', 'adama' ),
											get_the_term_list( get_the_ID(), 'bsg_portfolio_category', '', ', ', '' )
										);
									}

									// Tags
									if ( has_term( '', 'bsg_portfolio_tags' ) ) {
										$vertical_info_out .= sprintf(
											'<div class="vertical-info-box">
												<h4>%1$s</h4>
												<div class="vertical-info-content">
													%2$s
												</div>
											</div>',
											esc_html( 'Tags:', 'adama' ),
											get_the_term_list( get_the_ID(), 'bsg_portfolio_tags', '', ', ', '' )
										);
									}

									// Custom Attributes
									$portfolio_attributes = galactica_option( 'portfolio_attributes', array() );
									if ( !empty( $portfolio_attributes ) ) {
										foreach ( $portfolio_attributes as $portfolio_attribute ) {
											if ( !empty( $portfolio_attribute['name'] ) ) {
												$data = get_post_meta( get_the_ID(), 'adama_portfolio_attribute_' . sanitize_title( $portfolio_attribute['slug'] ), true );
												if ( !empty( $data ) ) {
													$data_out = '';

													switch ( $portfolio_attribute['type'] ) {
														case 'url':
															$data_out = sprintf( '<a href="%1$s" target="_blank">%2$s</a>', esc_url( $data ), esc_html( preg_replace( '/^(https?|ftp):\/\//', '', $data ) ) );
															break;
														case 'date':
															$data_out = esc_html( date_i18n( get_option( 'date_format' ), (int) $data ) );
															break;
														case 'text':
														default:
															$data_out = esc_html( $data );
															break;
													}

													$vertical_info_out .= sprintf(
														'<div class="vertical-info-box">
															<h4>%1$s:</h4>

															<div class="vertical-info-content">
																%2$s
															</div>
														</div>',
														esc_html( $portfolio_attribute['name'] ),
														$data_out
													);
												}
											}
										}
									}

									// Otuput vertical info
									if ( !empty( $vertical_info_out ) ) {
										$portfolio_content_full_width = '';

										$vertical_info_out = sprintf(
											'<div class="vertical-info">%s</div>',
											$vertical_info_out
										);
									}
								?>

								<div class="portfolio-content<?php echo esc_attr( $portfolio_content_full_width ); ?>">
									<?php
										the_content();

										galactica_link_pages();
									?>
								</div>

								<?php
									// Otuput vertical info
									echo $vertical_info_out;
								?>

							</div>

						</div>

					<?php endwhile; ?>
				<?php endif; ?>

				<?php
					// Show social share buttons
					if ( galactica_option( 'portfolio_enable_share', true ) ) { ?>
						<div class="container container-inner">
							<?php adama_social_share(); ?>
						</div>
				<?php } ?>

				<?php
					// Show previous/next navigation
					if ( galactica_option( 'portfolio_enable_prev_next_nav', true ) ) {
						adama_prev_next();
					}
				?>

				<?php
					// Related projects
					$related_projects = get_post_meta( get_the_ID(), 'adama_portfolio_related_projects', true );

					if ( !empty( $related_projects ) && function_exists( 'galactica_core_html_portfolio' ) ) : ?>
						<section class="w-section related-projects">
							<div class="container container-inner">
								<?php $related_projects_title = galactica_option( 'portfolio_related_projects_title' );
									if ( $related_projects_title ) : ?>
										<h3 class="section-title"><?php echo esc_html( $related_projects_title ); ?></h3>
								<?php endif; ?>

								<?php echo galactica_core_html_portfolio( array( 'layout' => 'text-bellow' ), array( 'post__in' => $related_projects, 'orderby' => 'post__in' ) ); ?>
							</div>
						</section>
				<?php endif;

				// Load comments template
				if ( comments_open() ) { ?>
					<div class="container">
						<?php comments_template(); ?>
					</div>
				<?php } ?>

			</div><!-- #content -->
			<?php get_sidebar(); ?>

		</div><!-- .row -->
	</div><!-- .container-outer -->
</section>

<?php get_footer();