<?php
/**
 * Single Team Member Template
 *
 * @package GalacticaThemes
 * @subpackage Template
 */

get_header(); ?>

<section class="w-section">
	<div class="container">
		<div class="row">

			<div id="content" class="col-md-9 col-content" role="main">

				<?php while ( have_posts() ) : the_post(); ?>

					<div class="row">
						<div class="col-md-6">
							<?php echo adama_get_post_thumbnail( array( 'class' => 'img-full-width img-responsive team-member-single-image' ), array( 'columns' => 2 ) ); ?>
						</div>
						<div class="col-md-6">
							<?php
							$job_title = get_post_meta( get_the_ID(), 'adama_team_job_title', true );
							if ( !empty( $job_title ) ) {
								echo '<h2>', esc_html( $job_title ), '</h2>';
							}
							?>

							<div class="vertical-info-wrap">
								<div class="portfolio-content">
									<?php
										the_content();

										galactica_link_pages();
									?>
								</div>
								<div class="vertical-info">
									<div class="vertical-info-box">
										<h4><?php esc_html_e( 'Name:', 'adama' ); ?></h4>
										<div class="vertical-info-content">
											<?php echo get_the_title(); ?>
										</div>
									</div>

									<?php $skills = wp_get_post_terms( get_the_ID(), 'bsg_team_skills', array( 'fields' => 'names' ) ); ?>
									<?php if ( !empty( $skills ) ) : ?>
										<div class="vertical-info-box">
											<h4><?php esc_html_e( 'Skills:', 'adama' ); ?></h4>
											<div class="vertical-info-content">
												<?php
													$skills_string = implode( ', ', $skills );
													echo esc_html( $skills_string );
												?>
											</div>
										</div>
									<?php endif; ?>

									<?php $phone = get_post_meta( get_the_ID(), 'adama_team_phone', true );
										if ( !empty( $phone ) ) { ?>
											<div class="vertical-info-box">
												<h4><?php esc_html_e( 'Phone:', 'adama' ); ?></h4>
												<div class="vertical-info-content">
													<?php
														// Phone - remove everything but numbers
														$phone_number = galactica_phone_extract( $phone );
														if ( empty( $phone_number ) ) {
															echo $phone;
														} else {
															echo '<a href="tel:' . esc_attr( $phone_number ) . '">' . esc_html( $phone ) . '</a>';
														}
													?>
												</div>
											</div>
									<?php } ?>

									<?php $email = get_post_meta( get_the_ID(), 'adama_team_email', true ); ?>
									<?php if ( !empty( $email ) ) : ?>
										<div class="vertical-info-box">
											<h4><?php esc_html_e( 'Email:', 'adama' ); ?></h4>
											<div class="vertical-info-content">
												<a href="<?php echo esc_url( 'mailto:' . $email ); ?>"><?php echo esc_html( $email ); ?></a>
											</div>
										</div>
									<?php endif; ?>

									<?php
										// Social icons
										echo galactica_team_social_list_html( array( 'before' => '<div class="vertical-info-box">', 'after' => '</div>', 'classes' => 'social-icons social-big text-left' ) );
									?>

								</div>
							</div>
						</div>
					</div>

					<?php
						$related_projects = get_post_meta( get_the_ID(), 'adama_team_related_projects', true );

						if ( !empty( $related_projects ) && function_exists( 'galactica_core_html_portfolio' ) ) : ?>
							<section class="w-section related-projects">
								<h3 class="section-title"><?php esc_html_e( 'My Projects', 'adama' ); ?></h3>

								<?php echo galactica_core_html_portfolio( array( 'layout' => 'text-bellow' ), array( 'post__in' => $related_projects, 'orderby' => 'post__in' ) ); ?>
							</section>
					<?php endif;

					// Load comments template
					if ( comments_open() ) { ?>
						<div class="container">
							<?php comments_template(); ?>
						</div>
					<?php }

				endwhile; ?>

			</div><!-- #content -->
			<?php get_sidebar(); ?>

		</div>
	</div>
</section>

<?php get_footer();