<?php
/**
 * Single Post Template
 *
 * @package GalacticaThemes
 * @subpackage Template
 */

get_header(); ?>

<section class="slice">
	<div class="w-section inverse blog-grid">
		<div class="container container-outer">
			<div class="row">

				<div id="content" class="col-md-9 col-content" role="main">

					<?php while ( have_posts() ) : the_post(); ?>

						<div class="container container-inner">
							<div class="row">
								<div class="col-md-12">
									<div class="blog-post entry-content">
										<?php
											$post_media = '';

											switch ( get_post_format() ) {
												case 'gallery':
													$post_media = adama_post_slider();
													break;
												case 'video':
												case 'audio':
													$post_oembed = get_post_meta( get_the_ID(), 'adama_post_oembed', true );

													if ( !empty( $post_oembed ) && ( $oembed = wp_oembed_get( $post_oembed ) ) ) {
														$post_media = '<div class="blog-post-oembed embed-responsive embed-responsive-16by9">' . $oembed .'</div>';
													}
													break;
												case 'image':
													if ( has_post_thumbnail() ) {
														$post_media = adama_get_post_thumbnail( array( 'class' => 'img-responsive' ) );
													}
													break;
											}

											if ( !empty( $post_media ) ) {
												echo '<div class="post-media-wrap">' . $post_media . '</div>';
											}
										?>

										<?php
											// Content
											if ( get_post_format() === 'quote' ) {
												galactica_format_quote_content();
											} else {
												the_content();
											}

											galactica_link_pages();
										?>

										<ul class="meta-list">
											<?php if ( galactica_option( 'blog_hide_author_info', true ) ) : ?>
												<li>
													<span><?php esc_html_e( 'By', 'adama' ) ?></span>
													<?php
														printf( ' <span class="bold"><span class="author vcard"><a href="%1$s">%2$s</a></span></span>',
															esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
															get_the_author()
														);
													?>
													<span class="sep">|</span>
												</li>
											<?php endif; ?>

											<li>
												<?php printf( '<span>%1$s</span>', get_the_date() ); ?>
											</li>

											<li>
												<span class="sep">|</span>
												<span><?php esc_html_e( 'Categories', 'adama' ); ?>:</span> <?php the_category( ', ' ); ?>
											</li>

											<?php if ( has_tag() ) : ?>
												<li>
													<span class="sep">|</span>
													<span><?php esc_html_e( 'Tags', 'adama' ); ?>:</span> <?php the_tags( '' ); ?>
												</li>
											<?php endif; ?>

											<?php if ( comments_open() || get_comments_number() ) : ?>
													<li>
														<span class="sep">|</span>
														<?php comments_popup_link( esc_html__( '0 Comments', 'adama' ), esc_html__( '1 Comment', 'adama' ), esc_html__( '% Comments', 'adama' ), 'link-comments' ); ?>
													</li>
											<?php endif; ?>
										</ul>
									</div>
								</div>
							</div>

							<?php
								// Show social share buttons
								if ( galactica_option( 'blog_post_enable_share', true ) ) :
									adama_social_share();
								endif;
							?>

							<?php
								// About the Author
								if ( galactica_option( 'blog_hide_author_info', true ) && galactica_option( 'blog_hide_about_author', true ) ) : ?>
								<div class="about-author-container">
									<div class="avatar-container">
										<?php echo get_avatar( get_the_author_meta( 'ID' ), '72' ); ?>
									</div>

									<h4><?php the_author_posts_link(); ?></h4>

									<div class="description">
										<?php the_author_meta( 'description' ); ?>
									</div>
								</div>
							<?php endif; ?>
						</div>

						<?php
							// Previous/Next posts
							if ( galactica_option( 'blog_enable_prev_next_nav', true ) ) {
								adama_prev_next();
							}
						?>

						<div class="container container-inner">
							<?php
								// Related posts
								if ( galactica_option( 'blog_post_enable_related_posts', true ) ) :
									echo adama_post_get_related();
								endif;
							?>

							<?php
								// Comments
								if ( comments_open() || get_comments_number() ) :
									comments_template();
								endif;
							?>
						</div>

					<?php endwhile; ?>

				</div><!-- #content -->
				<?php get_sidebar(); ?>

			</div>
		</div>
	</div>
</section>

<?php get_footer();