<?php
/**
 * Galactica Themes
 *
 * @package GalacticaThemes
 * @subpackage Theme
 */

// Don't allow direct access
if ( !defined( 'ABSPATH' ) ) {
	die;
}


if ( !function_exists( 'adama_metabox_setup' ) ) {
	/**
	 * Build metabox panels
	 *
	 * @return void
	 */
	function adama_metabox_setup() {

		// Fetch all public post types
		$post_types_public = get_post_types( array( 'public' => true ), 'names', 'and' );

		// Detect slider plugins
		$sliders = function_exists( 'galactica_core_slider_detect' ) ? galactica_core_slider_detect( 'metabox' ) : array();

		// Fetch portfolios
		$portfolios = adama_get_portfolios_for_metabox();


		// Public Pages - Sidebar Manager
		if ( post_type_exists( 'bsg_sidebar' ) ) {
			// Fetch list of sidebars
			$sidebars = adama_get_sidebars_for_metabox();

			$cmb_sidebar_manager = new_cmb2_box( array(
				'id'           => 'adama_metabox_sidebar_manager',
				'classes'      => 'galactica-metabox',
				'title'        => esc_html__( 'Sidebar Settings', 'adama' ),
				'object_types' => (array) $post_types_public,
				'context'      => 'side',
				'priority'     => 'low',
				'show_names'   => true,
				'fields'       => array(
					array(
						'name'       => esc_html__( 'Classic Sidebar Position', 'adama' ),
						'desc'       => esc_html__( 'Select classic sidebar position.', 'adama' ),
						'id'         => 'galactica_sidebar_position',
						'type'       => 'select',
						'options'    => array(
							''      => esc_html__( 'Default position', 'adama' ),
							'right' => esc_html__( 'Right sidebar', 'adama' ),
							'left'  => esc_html__( 'Left sidebar', 'adama' ),
							'none'  => esc_html__( 'No sidebar', 'adama' ),
						),
						'std'        => '',
						'attributes' => array(
							'data-depends'  => json_encode( array(
								'page_template' => array(
									'!=' => 'templates/fullwidth.php',
								),
							) ),
						),
					),
					array(
						'name'       => esc_html__( 'Classic Sidebar', 'adama' ),
						'desc'       => sprintf( esc_html__( 'Select sidebar to be shown on this page. Custom sidebars can be created with %s.', 'adama' ), sprintf( '<a href="%s" target="_blank">%s</a>', esc_url( admin_url( 'edit.php?post_type=bsg_sidebar' ) ), esc_html__( 'Sidebar Manager', 'adama' ) ) ),
						'id'         => 'galactica_sidebar_classic',
						'type'       => 'select',
						'options'    => $sidebars,
						'attributes' => array(
							'data-depends'  => json_encode( array(
								'page_template' => array(
									'!=' => 'templates/fullwidth.php',
								),
							) ),
						),
					),
					array(
						'name'        => esc_html__( 'Classic Sidebar', 'adama' ),
						'desc'        => esc_html__( 'Classic Sidebar options not available when "Full Width" template is selected.', 'adama' ),
						'id'          => 'galactica_sidebar_classic_disabled',
						'type'        => 'galactica_description',
						'row_classes' => 'depends-hide',
						'attributes'  => array(
							'data-depends'  => json_encode( array(
								'page_template' => array(
									'=' => 'templates/fullwidth.php',
								),
							) ),
						),
					),
				),
			));

			if ( galactica_option( 'enable_slideout', true ) ) {
				$cmb_sidebar_manager->add_field( array(
					'name'    => esc_html__( 'Slideout Sidebar', 'adama' ),
					'desc'    => sprintf( esc_html__( 'Select sidebar to be shown on this page. Custom sidebars can be created with %s.', 'adama' ), sprintf( '<a href="%s" target="_blank">%s</a>', esc_url( admin_url( 'edit.php?post_type=bsg_sidebar' ) ), esc_html__( 'Sidebar Manager', 'adama' ) ) ),
					'id'      => 'galactica_sidebar_slideout',
					'type'    => 'select',
					'options' => $sidebars,
				));
			}
		}

		// Public Pages - Page Settings
   		new_cmb2_box( array(
			'id'           => 'adama_metabox_page',
			'classes'      => 'galactica-metabox',
			'title'        => esc_html__( 'Page Settings', 'adama' ),
			'object_types' => (array) $post_types_public,
			'context'      => 'normal',
			'priority'     => 'high',
			'show_names'   => true,
			'fields'       => array(
				array(
					'name'    => esc_html__( 'Layout', 'adama' ),
					'desc'    => esc_html__( 'Allows you to override layout for this page.', 'adama' ),
					'id'      => 'adama_page_layout',
					'type'    => 'select',
					'options' => array(
						''      => esc_html__( 'Default Layout', 'adama' ),
						'fluid' => esc_html__( 'Fluid', 'adama' ),
						'boxed' => esc_html__( 'Boxed', 'adama' ),
					),
					'std'     => '',
				),
				array(
					'name'    => esc_html__( 'Hide Page Title', 'adama' ),
					'desc'    => esc_html__( 'Hide main page title on this page.', 'adama' ),
					'id'      => 'adama_hide_title',
					'type'    => 'galactica_switch',
				),
				array(
					'name'    => esc_html__( 'Hide Breadcrumb', 'adama' ),
					'desc'    => esc_html__( 'Hide breadcrumb on this page.', 'adama' ),
					'id'      => 'adama_hide_breadcrumb',
					'type'    => 'galactica_switch',
				),

				array(
					'name'    => esc_html__( 'Hero Type', 'adama' ),
					'desc'    => esc_html__( 'Select image, slider, or text to be shown in header.', 'adama' ),
					'id'      => 'adama_hero_type',
					'type'    => 'select',
					'options' => array(
						''        => esc_html__( 'None', 'adama' ),
						'slider'  => esc_html__( 'Slider', 'adama' ),
						'image'   => esc_html__( 'Image', 'adama' ),
//						'video'   => esc_html__( 'Video', 'adama' ),
//						'text'    => esc_html__( 'Text', 'adama' ),
						'content' => esc_html__( 'Content', 'adama' ),
					),
					'std'     => '',
				),

				// Hero - Slider
				array(
					'name'    => esc_html__( 'Slider Type', 'adama' ),
					'desc'    => esc_html__( 'Select slider type.', 'adama' ),
					'id'      => 'adama_hero_slider_type',
					'type'    => 'select',
					'options' => $sliders,
					'std'     => '',
					'attributes' => array(
						'data-required' => 'required',
						'data-depends'  => json_encode( array(
							'adama_hero_type' => array(
								'=' => 'slider',
							),
						) ),
					),
				),
				array(
					'name'       => esc_html__( 'Slider', 'adama' ),
					'desc'       => esc_html__( 'Select slider.', 'adama' ),
					'id'         => 'adama_hero_slider_id',
					'type'       => 'select',
					'options_cb' => 'adama_metabox_cb_slider',
					'std'        => '',
					'attributes' => array(
						'data-required' => 'required',
						'data-depends'  => json_encode( array(
							'adama_hero_type' => array(
								'=' => 'slider',
							),
						) ),
						'data-values_ajax' => json_encode( array(
							'action' => 'galactica_slider',
							'type'   => 'list',
							'data'   => array(
								'type' => 'adama_hero_slider_type',
							),
							'cache'  => true,
						) ),
					),
				),

				// Hero - Content
				array(
					'name'       => esc_html__( 'Hero Background Image', 'adama' ),
					'desc'       => esc_html__( 'Upload hero background image', 'adama' ),
					'id'         => 'adama_hero_background_image',
					'type'       => 'file',
					'attributes' => array(
						'data-depends'  => json_encode( array(
							'adama_hero_type' => array(
								'=' => 'content',
							),
						) ),
					),
				),
				array(
					'name'    => esc_html__( 'Hero Title', 'adama' ),
					'desc'    => esc_html__( 'Title for Hero section', 'adama' ),
					'id'      => 'adama_hero_title',
					'type'    => 'text',
					'std'     => '',
					'attributes' => array(
						'data-depends'  => json_encode( array(
							'adama_hero_type' => array(
								'=' => 'content',
							),
						) ),
					),
				),
				array(
					'name'    => esc_html__( 'Hero Text Description', 'adama' ),
					'desc'    => esc_html__( 'Additional text for Hero section.', 'adama' ),
					'id'      => 'adama_hero_description',
					'type'    => 'textarea_small',
					'std'     => '',
					'attributes' => array(
						'data-depends'  => json_encode( array(
							'adama_hero_type' => array(
								'=' => 'content',
							),
						) ),
					),
				),
				array(
					'name'    => esc_html__( 'Hero Background Color', 'adama' ),
					'desc'    => esc_html__( 'Background color for Hero section.', 'adama' ),
					'id'      => 'adama_hero_bg_color',
					'type'    => 'colorpicker',
					'std'     => '',
					'attributes' => array(
						'data-depends'  => json_encode( array(
							'adama_hero_type' => array(
								'=' => 'content',
							),
						) ),
					),
				),
				array(
					'name'    => esc_html__( 'Hero Text Color', 'adama' ),
					'desc'    => esc_html__( 'Text color for Hero section.', 'adama' ),
					'id'      => 'adama_hero_color',
					'type'    => 'colorpicker',
					'std'     => '',
					'attributes' => array(
						'data-depends'  => json_encode( array(
							'adama_hero_type' => array(
								'=' => 'content',
							),
						) ),
					),
				),
				array(
					'name'    => esc_html__( 'Hero Text Align', 'adama' ),
					'desc'    => esc_html__( 'Text align for Hero section.', 'adama' ),
					'id'      => 'adama_hero_align',
					'type'    => 'select',
					'options' => array(
						'left'   => esc_html__( 'Left', 'adama' ),
						'center' => esc_html__( 'Center', 'adama' ),
						'right'  => esc_html__( 'Right', 'adama' ),
					),
					'std'     => '',
					'attributes' => array(
						'data-depends'  => json_encode( array(
							'adama_hero_type' => array(
								'=' => 'content',
							),
						) ),
					),
				),

				// Hero - Image
				array(
					'name'       => esc_html__( 'Hero Image', 'adama' ),
					'desc'       => esc_html__( 'Upload hero image', 'adama' ),
					'id'         => 'adama_hero_image',
					'type'       => 'file',
					'attributes' => array(
						'data-required' => 'required',
						'data-depends'  => json_encode( array(
							'adama_hero_type' => array(
								'=' => 'image',
							),
						) ),
					),
				),

//				// Hero - Video
//				array(
//					'name'       => esc_html__( 'Hero Video', 'adama' ),
//					'desc'       => esc_html__( 'Enter video URL', 'adama' ),
//					'id'         => 'adama_hero_video',
//					'type'       => 'text',
//					'attributes' => array(
//						'data-required' => 'required',
//						'data-depends'  => json_encode( array(
//							'adama_hero_type' => array(
//								'=' => 'video',
//							),
//						) ),
//					),
//				),
			),
		));

		// Contact page template
		new_cmb2_box( array(
			'id'           => 'adama_metabox_aboutus',
			'classes'      => 'galactica-metabox',
			'title'        => esc_html__( 'Contact Us Attributes', 'adama' ),
			'object_types' => array( 'page' ),
			'show_on'      => array( 'key' => 'page-template', 'value' => 'templates/contact.php' ),
			'context'      => 'normal',
			'priority'     => 'high',
			'show_names'   => true,
			'fields'       => array(
				array(
					'name'    => esc_html__( 'Map Position', 'adama' ),
					'desc'    => esc_html__( 'Select map position', 'adama' ),
					'id'      => 'adama_contact_map_position',
					'type'    => 'radio_inline',
					'options' => array(
						'top'	  => esc_html__( 'Above content', 'adama' ),
						'side'	  => esc_html__( 'Side', 'adama' ),
						'disable' => esc_html__( 'Hide', 'adama' ),
					),
					'std'     => 'top',
				),
				array(
					'name'    => esc_html__( 'Disable Form', 'adama' ),
					'desc'    => esc_html__( 'Disable default contact form.', 'adama' ),
					'id'      => 'adama_contact_disable_form',
					'type'    => 'galactica_switch',
				),
			),
		));

		// Portfolio
		if ( post_type_exists( 'bsg_portfolio' ) ) {
			$cmb_portfolio = new_cmb2_box( array(
				'id'           => 'adama_metabox_portfolio',
				'classes'      => 'galactica-metabox',
				'title'        => esc_html__( 'Portfolio Attributes', 'adama' ),
				'object_types' => array( 'bsg_portfolio' ),
				'context'      => 'normal',
				'priority'     => 'high',
				'show_names'   => true,
				'fields'       => array(
					array(
						'name'             => esc_html__( 'Portfolio Layout', 'adama' ),
						'desc'             => esc_html__( 'Override layout for single portfolio template.', 'adama' ),
						'id'               => 'adama_portfolio_single_layout',
						'type'             => 'select',
						'show_option_none' => true,
						'options'          => array(
							'horizontal' => esc_html__( 'Horizontal', 'adama' ),
							'vertical'   => esc_html__( 'Vertical', 'adama' ),
						),
					),
					array(
						'name'             => esc_html__( 'Portfolio Type', 'adama' ),
						'desc'             => esc_html__( 'Show featured image, video or slider on portfolio page.', 'adama' ),
						'id'               => 'adama_portfolio_single_type',
						'type'             => 'select',
						'show_option_none' => false,
						'options'          => array(
							'image'  => esc_html__( 'Featured image', 'adama' ),
							'video'  => esc_html__( 'Video', 'adama' ),
							'slider' => esc_html__( 'Slider', 'adama' ),
						),
						'default' => 'image'
					),
					array(
						'name'        => esc_html__( 'oEmbed URL', 'adama' ),
						'desc'        => sprintf( esc_html__( 'Embed videos supported by %s.', 'adama' ), sprintf( '<a href="https://codex.wordpress.org/Embeds#Okay.2C_So_What_Sites_Can_I_Embed_From.3F" target="_blank">%s</a>', 'WordPress oEmbed' ) ),
						'id'          => 'adama_portfolio_oembed',
						'type'        => 'text',
						'std'         => '',
						'attributes'    => array(
							'data-depends'  => json_encode( array(
								'adama_portfolio_single_type' => array(
									'=' => 'video',
								),
							) ),
						),
					),
					array(
						'name'         => esc_html__( 'Gallery', 'adama' ),
						'desc'         => esc_html__( 'Upload images for Portfolio gallery', 'adama' ),
						'id'           => 'adama_portfolio_gallery',
						'type'         => 'file_list',
						'preview_size' => array( 100, 100 ),
						'attributes'   => array(
							'data-depends'  => json_encode( array(
								'adama_portfolio_single_type' => array(
									'=' => 'slider',
								),
							) ),
						),
					),
					array(
						'name'          => esc_html__( 'Related Projects', 'adama' ),
						'desc'          => esc_html__( 'Select up to 4 related projects', 'adama' ),
						'id'            => 'adama_portfolio_related_projects',
						'type'          => 'pw_multiselect',
						'max_selection' => 4,
						'options'       => $portfolios,
					),
					array(
						'name' => esc_html__( 'Intro', 'adama' ),
						'desc' => esc_html__( 'Section above the content', 'adama' ),
						'id'   => 'adama_portfolio_intro',
						'type' => 'textarea_small',
						'std'  => '',
					),
					array(
						'name' => esc_html__( 'Attributes Title', 'adama' ),
						'desc' => esc_html__( 'Title for portfolio attributes', 'adama' ),
						'id'   => 'adama_portfolio_attributes_title',
						'type' => 'text',
						'std'  => '',
					),
				),
			));

			$portfolio_attributes = galactica_option( 'portfolio_attributes', array() );
			if ( !empty( $portfolio_attributes ) ) {
				foreach ( $portfolio_attributes as $key => $portfolio_attribute ) {

					if ( empty( $portfolio_attribute['name'] ) || empty( $portfolio_attribute['slug'] ) || empty( $portfolio_attribute['type'] ) ) {
						continue;
					}

					$type = 'text';
					switch ( $portfolio_attribute['type'] ) {
						case 'date':
							$type = 'text_date_timestamp';
							break;
						case 'url':
							$type = 'text_url';
							break;
					}

					$name = $portfolio_attribute['name'];
					$desc = $portfolio_attribute['desc'];
					if ( function_exists( 'icl_translate' ) && defined( 'ICL_LANGUAGE_CODE' ) ) {
						// Force WPML to translate labels
						$has_translation = false;
						$name = icl_translate( 'admin_texts_' . GALACTICA_THEME_OPTIONS, "[" . GALACTICA_THEME_OPTIONS . "][portfolio_attributes][{$key}]name", $name, false, $has_translation, ICL_LANGUAGE_CODE );

						if (!empty($desc)) {
							$has_translation = false;
							$desc = icl_translate( 'admin_texts_' . GALACTICA_THEME_OPTIONS, "[" . GALACTICA_THEME_OPTIONS . "][portfolio_attributes][{$key}]desc", $desc, false, $has_translation, ICL_LANGUAGE_CODE );
						}
					}

					$cmb_portfolio->add_field( array(
						'name' => esc_html( $name ),
						'desc' => esc_html( $desc ),
						'id'   => 'adama_portfolio_attribute_' . sanitize_title( $portfolio_attribute['slug'] ),
						'type' => $type,
					) );
				}
			}

			// Portfolio page template
			new_cmb2_box( array(
				'id'           => 'adama_metabox_portfolio_page',
				'classes'      => 'galactica-metabox',
				'title'        => esc_html__( 'Portfolio Template Settings', 'adama' ),
				'object_types' => array( 'page' ),
				'show_on'      => array( 'key' => 'page-template', 'value' => array( 'templates/portfolio-boxed.php', 'templates/portfolio-fluid.php' ) ),
				'context'      => 'normal',
				'priority'     => 'high',
				'show_names'   => true,
				'fields'       => array(
					array(
						'name'    => esc_html__( 'Items per Page', 'adama' ),
						'desc'    => esc_html__( 'Number of portfolio items. Leave empty for default.', 'adama' ),
						'id'      => 'adama_portfolio_items_per_page',
						'type'    => 'text',
						'attributes' => array(
							'type'    => 'number',
							// 'pattern' => '\d*',
						),
						'std'     => '',
					),
					array(
						'name'    => esc_html__( 'Columns', 'adama' ),
						'desc'    => esc_html__( 'Select number of columns', 'adama' ),
						'id'      => 'adama_portfolio_columns',
						'type'    => 'radio_inline',
						'options' => array(
							''  => esc_html__( 'Default', 'adama' ),
							'1' => '1',
							'2' => '2',
							'3' => '3',
							'4' => '4',
						),
						'std'     => '',
					),
					array(
						'name'    => esc_html__( 'Style', 'adama' ),
						'desc'    => esc_html__( 'Select style for portfolio items', 'adama' ),
						'id'      => 'adama_portfolio_style',
						'type'    => 'select',
						'options' => array(
							''            => esc_html__( 'Default', 'adama' ),
							'hover'       => esc_html__( 'Hover', 'adama' ),
							'text-bellow' => esc_html__( 'Text Below', 'adama' ),
						),
						'std'     => '',
					),
					array(
						'name'    => esc_html__( 'Space Out', 'adama' ),
						'desc'    => esc_html__( 'Adds padding between portfolio items', 'adama' ),
						'id'      => 'adama_portfolio_spaced',
						'type'    => 'select',
						'options' => array(
							''  => esc_html__( 'Default', 'adama' ),
							'1' => esc_html__( 'Yes', 'adama' ),
							'0' => esc_html__( 'No', 'adama' ),
						),
						'std'     => '',
					),
				),
			));
		}

		// Team
		if ( post_type_exists( 'bsg_team' ) ) {
			// Add jQuery UI tabs script
			add_action( 'cmb2_after_form', 'adama_metabox_uitab_script' );

			$cmb_team = new_cmb2_box( array(
				'id'           => 'adama_metabox_team',
				'classes'      => 'galactica-metabox galactica-metabox-tabs',
				'title'        => esc_html__( 'Team Member Attributes', 'adama' ),
				'object_types' => array( 'bsg_team' ),
				'context'      => 'normal',
				'priority'     => 'high',
				'show_names'   => true,
				'fields'       => array(
					array(
						'desc' => esc_html__( 'General', 'adama' ),
						'id'   => 'adama_tab_title_general',
						'type' => 'galactica_tab',
					),
					array(
						'name' => esc_html__( 'Job Title', 'adama' ),
						'desc' => esc_html__( 'Enter the job title for current team member', 'adama' ),
						'id'   => 'adama_team_job_title',
						'type' => 'text',
						'std'  => '',
					),
					array(
						'name' => esc_html__( 'Phone', 'adama' ),
						'desc' => esc_html__( 'Enter the phone for current team member', 'adama' ),
						'id'   => 'adama_team_phone',
						'type' => 'text',
						'std'  => '',
					),
					array(
						'name' => esc_html__( 'Email', 'adama' ),
						'desc' => esc_html__( 'Enter the email address for current team member', 'adama' ),
						'id'   => 'adama_team_email',
						'type' => 'text_email',
						'std'  => '',
					),
				),
			));

			if ( post_type_exists( 'bsg_portfolio' ) ) {
				$cmb_team->add_field( array(
					'name'          => esc_html__( 'My projects', 'adama' ),
					'desc'          => esc_html__( 'Select up to 4 related projects', 'adama' ),
					'id'            => 'adama_team_related_projects',
					'type'          => 'pw_multiselect',
					'max_selection' => 4,
					'options'       => $portfolios,
				) );
			}

			$social_list = galactica_social_list( 'team-member' );
			if ( !empty( $social_list ) ) {
				$cmb_team->add_field( array(
					'desc' => esc_html__( 'Social', 'adama' ),
					'id'   => 'adama_tab_title_social',
					'type' => 'galactica_tab',
				) );
				foreach ( $social_list as $social_item ) {
					$social_description = empty( $social_item['is_username'] ) ? esc_html__( 'Enter the %s URL', 'adama' ) : esc_html__( 'Enter the %s username', 'adama' );
					$cmb_team->add_field( array(
						'name' => esc_html( $social_item['name'] ),
						'desc' => sprintf( $social_description, $social_item['name'] ),
						'id'   => 'adama_team_social_' . sanitize_title( $social_item['slug'] ),
						'type' => 'text',
						'std'  => '',
					));
				}
			}
		}

		// Testimonial
		new_cmb2_box( array(
			'id'           => 'adama_metabox_testimonial',
			'classes'      => 'galactica-metabox',
			'title'        => esc_html__( 'Testimonial Attributes', 'adama' ),
			'object_types' => array( 'bsg_testimonial' ),
			'context'      => 'normal',
			'priority'     => 'high',
			'show_names'   => true,
			'fields'       => array(
				array(
					'name' => esc_html__( 'Author', 'adama' ),
					'desc' => esc_html__( 'Enter the name of the author for this testimonial e.g. Jon Doe', 'adama' ),
					'id'   => 'adama_testimonial_author',
					'type' => 'text',
					'std'  => '',
				),
				array(
					'name' => esc_html__( 'Author Job Title', 'adama' ),
					'desc' => esc_html__( "Enter the author's job title for this testimonial e.g. Company CEO", 'adama' ),
					'id'   => 'adama_testimonial_author_job_title',
					'type' => 'text',
					'std'  => '',
				),
				array(
					'name' => esc_html__( 'Author URL', 'adama' ),
					'desc' => sprintf( esc_html__( '(optional) Enter the URL for the author of this testimonial e.g. %s', 'adama' ), GALACTICA_WEBSITE_URL ),
					'id'   => 'adama_testimonial_url',
					'type' => 'text',
					'std'  => '',
				),
			),
		));

		// Blog post
		new_cmb2_box( array(
			'id'           => 'adama_metabox_post',
			'classes'      => 'galactica-metabox',
			'title'        => esc_html__( 'Post Attributes', 'adama' ),
			'object_types' => array( 'post' ),
			'context'      => 'normal',
			'priority'     => 'high',
			'show_names'   => true,
			'fields'       => array(
				array(
					'name'    => esc_html__( 'Related Posts Source', 'adama' ),
					'desc'    => esc_html__( 'Select source for related posts or disable related posts altogether.', 'adama' ),
					'id'      => 'adama_post_related_posts_source',
					'type'    => 'select',
					'options' => array(
						'disable'    => esc_html__( 'No related posts', 'adama' ),
						'categories' => esc_html__( 'From the same categories', 'adama' ),
						'custom'     => esc_html__( 'Choose posts', 'adama' ),
					),
					'default' => 'categories',
				),
				array(
					'name'          => esc_html__( 'Related Posts', 'adama' ),
					'desc'          => esc_html__( 'Select up to 3 related posts', 'adama' ),
					'id'            => 'adama_post_related_posts',
					'type'          => 'pw_multiselect',
					'max_selection' => 3,
					'options'       => adama_get_posts_for_metabox(),
					'attributes'    => array(
						'data-depends'  => json_encode( array(
							'adama_post_related_posts_source' => array(
								'=' => 'custom',
							),
						) ),
					),
				),
				array(
					'name'        => esc_html__( 'oEmbed URL', 'adama' ),
					'desc'        => sprintf( esc_html__( 'Embedding audio and video supported by %s.', 'adama' ), sprintf( '<a href="https://codex.wordpress.org/Embeds#Okay.2C_So_What_Sites_Can_I_Embed_From.3F" target="_blank">%s</a>', 'WordPress oEmbed' ) ),
					'id'          => 'adama_post_oembed',
					'type'        => 'text',
					'std'         => '',
					'attributes'  => array(
						'data-depends'  => json_encode( array(
							'__post_format' => array(
								'IN' => array( 'audio', 'video' ),
							),
						) ),
					),
				),
				array(
					'name'         => esc_html__( 'Gallery', 'adama' ),
					'desc'         => esc_html__( 'Upload images for Post gallery', 'adama' ),
					'id'           => 'adama_post_gallery',
					'type'         => 'file_list',
					'preview_size' => array( 100, 100 ),
					'attributes'   => array(
						'data-depends'  => json_encode( array(
							'__post_format' => array(
								'=' => 'gallery',
							),
						) ),
					),
				),
			),
		));

		// FAQ page template
		new_cmb2_box( array(
			'id'           => 'adama_metabox_faq',
			'classes'      => 'galactica-metabox',
			'title'        => esc_html__( 'FAQ Attributes', 'adama' ),
			'object_types' => array( 'page' ),
			'show_on'      => array( 'key' => 'page-template', 'value' => 'templates/faq.php' ),
			'context'      => 'normal',
			'priority'     => 'high',
			'show_names'   => true,
			'fields'       => array(
				array(
					'name'    => esc_html__( 'Disable Accordion', 'adama' ),
					'desc'    => esc_html__( 'Disable accordion layout.', 'adama' ),
					'id'      => 'adama_faq_disable_accordion',
					'type'    => 'galactica_switch',
				),
			),
		));
	}
}
add_action( 'cmb2_admin_init', 'adama_metabox_setup' );

/**
 * Callback function for hero_slider_id field options
 *
 * @param CMB2_Field $dis
 * @return array
 */
function adama_metabox_cb_slider( $dis ) {
	if ( !function_exists( 'galactica_core_slider_list' ) ) {
		return array();
	}

	$hero_slider_type = get_post_meta( $dis->object_id, 'adama_hero_slider_type', true );
	return galactica_core_slider_list( $hero_slider_type );
}

if ( !function_exists( 'adama_get_posts_for_metabox' ) ) {
	/**
	 * Fetch posts for metabox field
	 *
	 * @return array
	 */
	function adama_get_posts_for_metabox() {

		// Fetch posts
		$posts_args = array(
			'post_type'      => 'post',
			'post_status'    => 'publish',
			'posts_per_page' => -1,
			'orderby'        => 'title',
			'order'          => 'ASC',
		);
		$related_posts = get_posts( $posts_args );


		// Prepare for metabox
		$meta_field = array(
			'' => esc_html__( 'Select related posts', 'adama' ),
		);
		if ( !empty( $related_posts ) ) {
			foreach ( $related_posts as $related_post ) {
				$meta_field[$related_post->ID] = esc_html( "#{$related_post->ID} - {$related_post->post_title}" );
			}
		}

		return $meta_field;
	}
}

if ( !function_exists( 'adama_get_portfolios_for_metabox' ) ) {
	/**
	 * Fetch portfolios for metabox field
	 *
	 * @return array
	 */
	function adama_get_portfolios_for_metabox() {

		if ( !post_type_exists( 'bsg_portfolio' ) ) {
			return array();
		}

		// Fetch portfolios
		$posts_args = array(
			'post_type'      => 'bsg_portfolio',
			'post_status'    => 'publish',
			'posts_per_page' => -1,
			'orderby'        => 'title',
			'order'          => 'ASC',
		);
		$portfolios = get_posts( $posts_args );


		// Prepare for metabox
		$meta_field = array(
			'' => esc_html__( 'Select Related Portfolio', 'adama' ),
		);
		if ( !empty( $portfolios ) ) {
			foreach ( $portfolios as $portfolio ) {
				$meta_field[$portfolio->ID] = esc_html( "#{$portfolio->ID} - {$portfolio->post_title}" );
			}
		}

		return $meta_field;
	}
}

if ( !function_exists( 'adama_get_sidebars_for_metabox' ) ) {
	/**
	 * Fetch custom sidebars for metabox field
	 *
	 * @return array
	 */
	function adama_get_sidebars_for_metabox() {

		// Fetch custom sidebars
		$posts_args = array(
			'post_type'      => 'bsg_sidebar',
			'post_status'    => 'publish',
			'posts_per_page' => -1,
			'orderby'        => 'title',
			'order'          => 'ASC',
		);
		$sidebars = get_posts( $posts_args );


		// Prepare for metabox
		$meta_field = array(
			'' => esc_html__( 'Default sidebar', 'adama' ),
			//'_none' => esc_html__( 'No sidebar', 'adama' ),
		);
		if ( !empty( $sidebars ) ) {
			foreach ( $sidebars as $sidebar ) {
				$meta_field["galactica-{$sidebar->post_name}"] = esc_html( $sidebar->post_title );
			}
		}

		return $meta_field;
	}
}

if ( !function_exists( 'adama_metabox_uitab_script' ) ) {
	/**
	 * Add jQuery UI tabs script for metaboxes
	 *
	 * @return void
	 */
	function adama_metabox_uitab_script() {
		wp_enqueue_script( 'jquery-ui-tabs' );
	}
}
