<?php
/**
 * Galactica Themes
 *
 * @package GalacticaThemes
 * @subpackage Theme
 */

// Don't allow direct access
if ( !defined( 'ABSPATH' ) ) {
	die;
}


if ( !class_exists( 'ReduxFramework' ) ) {
	// Core plugin disabled?
	return;
}

if ( !function_exists( 'adama_options_init' ) ) {
	/**
	 * Builds theme options panel.
	 * Uses Redux https://docs.reduxframework.com/
	 *
	 * @return void
	 */
	function adama_options_init() {
		// Read theme data
		$theme = wp_get_theme();
		$theme_name = $theme->get( 'Name' );

		// Setup options framework
		$args = array(
			// TYPICAL
			'opt_name'             => GALACTICA_THEME_OPTIONS, // This is where your data is stored in the database and also becomes your global variable name.
			'display_name'         => $theme_name,             // Name that appears at the top of your panel
			'display_version'      => $theme->get( 'Version' ),// Version that appears at the top of your panel
			'menu_type'            => 'menu',                  // Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
			'allow_sub_menu'       => false,                   // Show the sections below the admin menu item or not
			'menu_title'           => $theme_name,
			'page_title'           => esc_html__( 'Options', 'adama' ),

			// You will need to generate a Google API key to use this feature.
			'google_api_key'       => 'AIzaSyDP_96ZeGH0VPt09J0j0Lfcl9LcXspipYo', // Must be defined to add google fonts to the typography module
			'google_update_weekly' => false,
			'async_typography'     => false,                   // Use a asynchronous font on the front end or font string
			'disable_google_fonts_link' => true,               // Disable this in case you want to create your own google fonts loader

			'admin_bar'            => false,                   // Show the panel pages on the admin bar
			// 'global_variable'      => GALACTICA_THEME_OPTIONS, // Set a different name for your global variable other than the opt_name
			'dev_mode'             => false,                   // Show the time the page took to load, etc
			'customizer'           => false,                   // Enable basic customizer support

			// OPTIONAL
			'page_priority'        => '59.adama',              // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
			'page_parent'          => 'options-general.php',   // For a full list of options, visit: https://developer.wordpress.org/reference/functions/add_submenu_page/#parameters
			'page_permissions'     => 'manage_options',        // Permissions needed to access the options panel.
			'menu_icon'            => '',                      // Specify a custom URL to an icon
			'last_tab'             => '',                      // Force your panel to always open to a specific tab (by id)
			'page_icon'            => 'icon-themes',           // Icon displayed in the admin panel next to your menu_title
			'page_slug'            => GALACTICA_THEME_OPTIONS, // Page slug used to denote the panel
			'save_defaults'        => true,                    // On load save the defaults to DB before user clicks save or not
			'default_show'         => false,                   // If true, shows the default value next to each field that is not the default value.
			'default_mark'         => '',                      // What to print by the field's title if the value shown is default. Suggested: *
			'show_import_export'   => false,                   // Shows the Import/Export panel when not used as a field.

			// CAREFUL -> These options are for advanced use only
			'transient_time'       => 60 * MINUTE_IN_SECONDS,
			'output'               => true,                    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
			'output_tag'           => true,                    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
			// 'footer_credit'     => '',                      // Disable the footer credit of Redux. Please leave if you can help it.
			'allow_tracking'       => false,

			// FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
			'database'             => '', // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!

			// HINTS
			'hints'                => array(
				'icon'          => 'el el-question-sign',
				'icon_position' => 'right',
				'icon_color'    => 'lightgray',
				'icon_size'     => 'normal',
				'tip_style'     => array(
					'color'   => 'light',
					'shadow'  => true,
					'rounded' => false,
					'style'   => '',
				),
				'tip_position'  => array(
					'my' => 'top left',
					'at' => 'bottom right',
				),
				'tip_effect'    => array(
					'show' => array(
						'effect'   => 'slide',
						'duration' => '500',
						'event'    => 'mouseover',
					),
					'hide' => array(
						'effect'   => 'slide',
						'duration' => '500',
						'event'    => 'click mouseleave',
					),
				),
			),
		);

//		// Warn user that Galactica Core plugin is not installed
//		if ( !defined( 'GALACTICA_CORE_PLUGIN_NAME' ) ) {
//			$plugin_slug = 'galactica-core';
//			$action = file_exists( WP_PLUGIN_DIR . '/' . $plugin_slug ) ? 'activate' : 'install';
//
//			$plugin_url = wp_nonce_url(
//				"admin.php?page=galactica-install-plugins&plugin={$plugin_slug}&tgmpa-{$action}={$action}-plugin",
//				"tgmpa-{$action}",
//				'tgmpa-nonce'
//			);
//
//			$args['intro_text']	= '<p class="galactica-options-required-core">' . sprintf( esc_html__( 'REQUIRED: Please install and activate required %s plugin before proceeding with options setup.', 'adama' ), '<a href="' . esc_url( $plugin_url ) . '">' . esc_html__( 'Galactica Core', 'adama' ) . '</a>' ) . '</p>';
//		}


		// Setup option sections
		$sections = array();

		// General settings
		$sections['general'] = array(
			'id'		 => 'general',
			'icon'       => 'el-icon-cogs',
			'title'      => esc_html__( 'General', 'adama' ),
			'submenu'    => true,
			'customizer' => true,
			'fields'     => array(
				array(
					'id'       => 'enable_retina',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Enable Retina Support', 'adama' ),
					'subtitle' => esc_html__( 'Enable/Disable the retina support for images.', 'adama' ),
					'default'  => false,
				),
				array(
					'id'       => 'logo',
					'type'     => 'media',
					'url'      => true,
					'mode'     => 'image',
					'title'    => esc_html__( 'Logo', 'adama' ),
					'subtitle' => esc_html__( 'Upload logo for your website.', 'adama' ),
				),
				array(
					'id'       => 'logoX2',
					'type'     => 'media',
					'url'      => true,
					'mode'     => 'image',
					'title'    => esc_html__( 'Logo (Retina)', 'adama' ),
					'subtitle' => esc_html__( 'Retina logo for your website.', 'adama' ),
					'desc'     => esc_html__( 'Upload higher quality logo for your website. This image needs to be exactly 2 times larger than normal logo.', 'adama' ),
				),
				array(
					// NOTE: Translatable field - ID in wpml-config
					'id'       => 'tracking_code',
					'type'     => 'textarea',
					'title'    => esc_html__( 'Tracking Code', 'adama' ),
					'subtitle' => esc_html__( 'Paste your analytics (Google Analytics or other) tracking code here. Please paste complete code including script tags. This will be added into the footer template of your theme.', 'adama' ),
				),
			)
		);

		$favicon_required = array();
		if ( version_compare( $GLOBALS['wp_version'], '4.3', '>=' ) ) {
			$sections['general']['fields'][] = array(
				'id'       => 'enable_custom_favicon',
				'type'     => 'switch',
				'on'       => esc_html__( 'Yes', 'adama' ),
				'off'      => esc_html__( 'No', 'adama' ),
				'title'    => esc_html__( 'Custom Favicon', 'adama' ),
				'subtitle' => esc_html__( 'Enable/Disable custom favicon.', 'adama' ),
				'default'  => true,
			);

			$favicon_required = array( 'enable_custom_favicon', '=', true );
		}

		$sections['general']['fields'][] = array(
			'id'       => 'section-favicon',
			'type'     => 'section',
			'title'    => esc_html__( 'Favicon', 'adama' ),
			'indent'   => true,
			'required' => $favicon_required,
		);
			$sections['general']['fields'][] = array(
				'id'       => 'favicon',
				'type'     => 'media',
				'url'      => true,
				'mode'     => 'image',
				'title'    => esc_html__( 'Favicon', 'adama' ),
				'subtitle' => esc_html__( 'Favicon for your website.', 'adama' ),
				'desc'     => esc_html__( 'Best to upload image of 32px * 32px size.', 'adama' ),
			);
			$sections['general']['fields'][] = array(
				'id'       => 'apple_iphone_icon',
				'type'     => 'media',
				'url'      => true,
				'mode'     => 'image',
				'title'    => esc_html__( 'Apple iPhone Icon', 'adama' ),
				'subtitle' => esc_html__( 'Upload your custom iPhone icon (57px * 57px).', 'adama' ),
			);
			$sections['general']['fields'][] = array(
				'id'       => 'apple_iphone_iconX2',
				'type'     => 'media',
				'url'      => true,
				'mode'     => 'image',
				'title'    => esc_html__( 'Apple iPhone Retina Icon', 'adama' ),
				'subtitle' => esc_html__( 'Upload your custom iPhone retina icon (114px * 114px).', 'adama' ),
			);
			$sections['general']['fields'][] = array(
				'id'       => 'apple_ipad_icon',
				'type'     => 'media',
				'url'      => true,
				'mode'     => 'image',
				'title'    => esc_html__( 'Apple iPad Icon', 'adama' ),
				'subtitle' => esc_html__( 'Upload your custom iPad icon (72px * 72px).', 'adama' ),
			);
			$sections['general']['fields'][] = array(
				'id'       => 'apple_ipad_iconX2',
				'type'     => 'media',
				'url'      => true,
				'mode'     => 'image',
				'title'    => esc_html__( 'Apple iPad Retina Icon', 'adama' ),
				'subtitle' => esc_html__( 'Upload your custom iPad retina icon (144px * 144px).', 'adama' ),
			);
			$sections['general']['fields'][] = array(
				'id'       => 'apple_ipad_2_mini_icon',
				'type'     => 'media',
				'url'      => true,
				'mode'     => 'image',
				'title'    => esc_html__( 'Apple iPad 2 and iPad mini Icon', 'adama' ),
				'subtitle' => esc_html__( 'Upload your custom iPad 2 and iPad mini icon (76px * 76px).', 'adama' ),
			);
			$sections['general']['fields'][] = array(
				'id'       => 'apple_ipad_2_mini_iconX2',
				'type'     => 'media',
				'url'      => true,
				'mode'     => 'image',
				'title'    => esc_html__( 'Apple iPad 2 and iPad mini Retina Icon', 'adama' ),
				'subtitle' => esc_html__( 'Upload your custom iPad 2 and iPad mini retina icon (152px * 152px).', 'adama' ),
			);
			$sections['general']['fields'][] = array(
				'id'       => 'apple_ipad_4s_icon',
				'type'     => 'media',
				'url'      => true,
				'mode'     => 'image',
				'title'    => esc_html__( 'Apple iPhone 4s, iPhone 5 and iPhone 6 Icon', 'adama' ),
				'subtitle' => esc_html__( 'Upload your custom iPhone 4s, 5 and 6 icon (120px * 120px).', 'adama' ),
			);
			$sections['general']['fields'][] = array(
				'id'       => 'apple_ipad_4s_iconX2',
				'type'     => 'media',
				'url'      => true,
				'mode'     => 'image',
				'title'    => esc_html__( 'Apple iPhone 4s, iPhone 5 and iPhone 6 Retina Icon', 'adama' ),
				'subtitle' => esc_html__( 'Upload your custom iPhone 4s, 5 and 6 retina icon (180px * 180px).', 'adama' ),
			);
		$sections['general']['fields'][] = array(
			'id'     => 'section-favicon-end',
			'type'   => 'section',
			'indent' => false,
		);

		// Layout
		$sections['layout'] = array(
			'id'		 => 'layout',
			'icon'       => 'el-icon-website',
			'title'      => esc_html__( 'Layout', 'adama' ),
			'submenu'    => true,
			'customizer' => false,
			'fields'     => array(
				array(
					'id'       => 'layout',
					'type'     => 'button_set',
					'title'    => esc_html__( 'Layout', 'adama' ),
					'subtitle' => esc_html__( 'Allows you to select fluid or boxed layout.', 'adama' ),
					'options'  => array(
						'fluid' => esc_html__( 'Fluid', 'adama' ),
						'boxed' => esc_html__( 'Boxed', 'adama' ),
					),
					'default'  => 'fluid',
				),
				array(
					'id'       => 'enable_slideout',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Enable Slideout Sidebar', 'adama' ),
					'subtitle' => esc_html__( 'Enable slideout sidebar on the right side of the website.', 'adama' ) . '<br/>' .
								  esc_html__( 'NOTE: Will be visible only if there are any widgets loaded in it.', 'adama' ),
					'default'  => true,
				),
				array(
					'id'       => 'sidebar_position',
					'type'     => 'image_select',
					'title'    => esc_html__( 'Classic Sidebar Position', 'adama' ),
					'subtitle' => esc_html__( 'Select main content and classic sidebar position.', 'adama' ),
					'options'  => array(
						'none'  => array(
							'alt' => esc_html__( 'No Sidebar', 'adama' ),
							'img' => ReduxFramework::$_url.'assets/img/1col.png'
						),
						'right' => array(
							'alt' => esc_html__( 'Right Sidebar', 'adama' ),
							'img' => ReduxFramework::$_url.'assets/img/2cr.png'
						),
						'left'  => array(
							'alt' => esc_html__( 'Left Sidebar', 'adama' ),
							'img' => ReduxFramework::$_url.'assets/img/2cl.png'
						),
					),
					'default'  => 'none',
				),
				array(
					'id'       => 'enable_sidebar_manager',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Enable Sidebar Manager', 'adama' ),
					'subtitle' => esc_html__( 'Allows you to create custom sidebars and to select custom sidebar for each page.', 'adama' ),
					'default'  => true,
				),
			),
		);

		// Header
		$sections['header'] = array(
			'id'		 => 'header',
			'icon'       => 'dashicons-before dashicons-desktop',
			'title'      => esc_html__( 'Header', 'adama' ),
			'submenu'    => true,
			'customizer' => true,
			'fields'     => array(
				array(
					'id'       => 'header_layout',
					'type'     => 'image_select',
					'title'    => esc_html__( 'Header Layout', 'adama' ),
					'subtitle' => esc_html__( 'Select a header layout.', 'adama' ),
					'options'  => array(
						'classic' => array(
							'alt' => esc_html__( 'Classic', 'adama' ),
							'img' => GALACTICA_THEME_ASSETS_URL . '/images/admin/header-layout-classic.png',
						),
						'centered' => array(
							'alt' => esc_html__( 'Centered', 'adama' ),
							'img' => GALACTICA_THEME_ASSETS_URL . '/images/admin/header-layout-centered.png',
						),
					),
					'default'  => 'classic',
				),
				array(
					'id'       => 'header_enable_sticky',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Enable Sticky Header', 'adama' ),
					'subtitle' => esc_html__( 'Fixed header position on scroll.', 'adama' ),
					'default'  => true,
				),
				array(
					'id'       => 'header_nav_height',
					'type'     => 'text',
					'title'    => esc_html__( 'Navigation Item Height (px)', 'adama' ),
					'validate' => 'numeric',
					'subtitle' => esc_html__( 'This must be a numeric value.', 'adama' ),
					'class'    => 'small-text',
					'compiler'  => true,
					'default'  => '',
				),
				array(
					'id'       => 'header_nav_mobile_breakpoint',
					'type'     => 'text',
					'title'    => esc_html__( 'Mobile Navigation Breakpoint (px)', 'adama' ),
					'validate' => 'numeric',
					'subtitle' => esc_html__( 'Controls when the navigation will change to mobile navigation. This must be a numeric value. Default: 768', 'adama' ),
					'class'    => 'small-text',
					'compiler'  => true,
					'default'  => '768',
				),
				array(
					'id'       => 'header_nav_enable_search',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Enable Search in Navigation', 'adama' ),
					'subtitle' => esc_html__( 'Add search form to navigation.', 'adama' ),
					'default'  => true,
				),

				array(
					'id'     => 'section-header-top',
					'type'   => 'section',
					'title'  => esc_html__( 'Top Bar', 'adama' ),
					'indent' => true,
				),
					array(
						'id'       => 'header_top_enable',
						'type'     => 'switch',
						'on'       => esc_html__( 'Yes', 'adama' ),
						'off'      => esc_html__( 'No', 'adama' ),
						'title'    => esc_html__( 'Enable Top Bar', 'adama' ),
						//'subtitle' => esc_html__( '', 'adama' ),
						'default'  => true,
					),
					array(
						'id'       => 'header_top_color',
						'type'     => 'button_set',
						'title'    => esc_html__( 'Color', 'adama' ),
						'required' => array( 'header_top_enable', '=', '1' ),
						'options'  => array(
							'dark'  => esc_html__( 'Dark', 'adama' ),
							'light' => esc_html__( 'Light', 'adama' ),
						),
						'default'  => 'dark',
					),
					array(
						'id'       => 'header_top_left_content',
						'type'     => 'button_set',
						'title'    => esc_html__( 'Left Content', 'adama' ),
						'required' => array( 'header_top_enable', '=', '1' ),
						'options'  => array(
							''               => esc_html__( 'Empty', 'adama' ),
							'contact_info'   => esc_html__( 'Contact Info', 'adama' ),
							'social_links'   => esc_html__( 'Social Links', 'adama' ),
							'text'           => esc_html__( 'Text Content', 'adama' ),
							// NOTE: secondary_menu is not in use because this side is hidden on small devices and menu would need left aligned dropdowns
						),
						'default'  => 'contact_info',
					),
					array(
						'id'       => 'header_top_right_content',
						'type'     => 'button_set',
						'title'    => esc_html__( 'Right Content', 'adama' ),
						'required' => array( 'header_top_enable', '=', '1' ),
						'options'  => array(
							''               => esc_html__( 'Empty', 'adama' ),
							'contact_info'   => esc_html__( 'Contact Info', 'adama' ),
							'secondary_menu' => esc_html__( 'Secondary Menu', 'adama' ),
							'social_links'   => esc_html__( 'Social Links', 'adama' ),
							'text'           => esc_html__( 'Text Content', 'adama' ),
						),
						'default'  => 'secondary_menu',
					),
					array(
						// NOTE: Translatable field - ID in wpml-config
						'id'       => 'header_top_phone',
						'type'     => 'text',
						'title'    => esc_html__( 'Phone', 'adama' ),
						'required' => array( 'header_top_enable', '=', '1' ),
						'default'  => '',
					),
					array(
						// NOTE: Translatable field - ID in wpml-config
						'id'       => 'header_top_email',
						'type'     => 'text',
						'title'    => esc_html__( 'Email', 'adama' ),
						'required' => array( 'header_top_enable', '=', '1' ),
						'default'  => '',
					),
					array(
						// NOTE: Translatable field - ID in wpml-config
						'id'       => 'header_top_address',
						'type'     => 'text',
						'title'    => esc_html__( 'Address', 'adama' ),
						'required' => array( 'header_top_enable', '=', '1' ),
						'default'  => '',
					),
					array(
						// NOTE: Translatable field - ID in wpml-config
						'id'       => 'header_top_text',
						'type'     => 'text',
						'title'    => esc_html__( 'Text Content', 'adama' ),
						'required' => array( 'header_top_enable', '=', '1' ),
						'default'  => sprintf( esc_html__( 'Welcome to %s theme', 'adama' ), GALACTICA_THEME_NAME ),
					),
					array(
						'id'       => 'header_top_nav_enable_login',
						'type'     => 'switch',
						'on'       => esc_html__( 'Yes', 'adama' ),
						'off'      => esc_html__( 'No', 'adama' ),
						'title'    => esc_html__( 'Enable Login link', 'adama' ),
						'subtitle' => esc_html__( 'Add login link to secondary menu in top bar. Useful for Shoping websites.', 'adama' ),
						'required' => array(
							array( 'header_top_enable', '=', '1' ),
							array( 'header_top_right_content', '=', 'secondary_menu' ),
						),
						'default'  => true,
					),
				array(
					'id'     => 'section-header-top-end',
					'type'   => 'section',
					'indent' => false,
				),
				array(
					'id'       => 'show_breadcrumb',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Show Breadcrumb', 'adama' ),
					'default'  => true,
				),

			),
		);

		// Footer
		$sections['footer'] = array(
			'id'		 => 'footer',
			'icon'       => 'el el-download-alt',
			'title'      => esc_html__( 'Footer', 'adama' ),
			'submenu'    => true,
			'customizer' => false,
			'fields'     => array(
				array(
					'id'       => 'footer_enable_uncover',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Uncover Footer', 'adama' ),
					'subtitle' => esc_html__( 'Uncovers fixed footer beneath page content on scroll. NOTE: Enabling this option will turn off transparent option for content background if set.', 'adama' ),
					'compiler' => true,
					'default'  => true,
				),
				array(
					'id'       => 'footer_enable_totop',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Show ToTop button', 'adama' ),
					'subtitle' => esc_html__( 'Allows users to easily scroll back to the top of the page.', 'adama' ),
					'default'  => true,
				),
				array(
					'id'       => 'footer_widget_areas',
					'type'     => 'button_set',
					'title'    => esc_html__( 'Footer Widget Areas', 'adama' ),
					'subtitle' => esc_html__( 'Select how many columns you want for your footer widgets.', 'adama' ),
					'options'  => array(
						'0' => esc_html__( 'None', 'adama' ),
						'1' => '1',
						'2' => '2',
						'3' => '3',
						'4' => '4',
					),
					'default'  => '4',
				),
				array(
					// NOTE: Translatable field - ID in wpml-config
					'id'       => 'footer_copyright_text',
					'type'     => 'editor',
					'title'    => esc_html__( 'Copyright Text', 'adama' ),
					'subtitle' => esc_html__( 'Available shortcodes in your footer text:', 'adama' ) . '
						<span class="option-description-tags">[current-year]</span>
						<span class="option-description-tags">[site-title]</span>
						<span class="option-description-tags">[site-tagline]</span>
						<span class="option-description-tags">[site-url]</span>
						<span class="option-description-tags">[theme-url]</span>
						<span class="option-description-tags">[wp-url]</span>',
					'default'  => 'Copyright &copy; [current-year] [site-title]',
				),
				array(
					'id'       => 'footer_enable_social',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Enable Social Icons', 'adama' ),
					'subtitle' => esc_html__( 'Show social icons in footer.', 'adama' ),
					'default'  => false,
				),
				array(
					// NOTE: Translatable field - ID in wpml-config
					'id'       => 'footer_credits_text',
					'type'     => 'editor',
					'title'    => esc_html__( 'Credits Text', 'adama' ),
					'subtitle' => esc_html__( 'Available shortcodes in your footer text:', 'adama' ) . '
						<span class="option-description-tags">[current-year]</span>
						<span class="option-description-tags">[site-title]</span>
						<span class="option-description-tags">[site-tagline]</span>
						<span class="option-description-tags">[site-url]</span>
						<span class="option-description-tags">[theme-url]</span>
						<span class="option-description-tags">[wp-url]</span>',
					'required' => array( 'footer_enable_social', '=', '0' ),
					'default'  => 'Powered by [theme-url] theme.',
				),
			),
		);

		$sections[] = array(
			'type' => 'divide',
		);


		$wp_font_subset = function_exists( 'galactica_core_wordpress_font_subset' ) ? galactica_core_wordpress_font_subset() : 'no-subset';
		if ( empty( $wp_font_subset ) || $wp_font_subset === 'no-subset' ) {
			$wp_font_subset = 'latin-ext';
		}

		// Typography
		$sections['typography'] = array(
			'id'		 => 'typography',
			'icon'       => 'el el-fontsize',
			'title'      => esc_html__( 'Typography', 'adama' ),
			'submenu'    => true,
			'customizer' => true,
			'fields'     => array(
				array(
					'id'          => 'font_body',
					'type'        => 'galactica_typography',
					'title'       => esc_html__( 'Body', 'adama' ),
					'subtitle'    => esc_html__( 'Select font options for your main body font.', 'adama' ),
					'compiler'    => array( 'body' ),
					'google'      => true,
					'color'       => false,
					'font-backup' => false,
					'font-family' => true,
					'font-size'   => true,
					'font-style'  => false,
					'font-weight' => true,
					'line-height' => true,
					'subsets'     => true,
					'text-align'  => false,
					'preview'     => array( 'always_display' => true ),
					'default'     => array(
						'google'      => true,
						'font-family' => 'Open Sans',
						'font-backup' => 'sans-serif',
						'font-size'   => '13px',
						'font-weight' => '400',
						'line-height' => '22px',
						'subsets'     => $wp_font_subset,
					),
				),
				array(
					'id'          => 'font_page_title',
					'type'        => 'galactica_typography',
					'title'       => esc_html__( 'Page Title', 'adama' ),
					'subtitle'    => esc_html__( 'Select font options for main page title.', 'adama' ),
					'compiler'    => array( '.title-bar .main-title' ),
					'google'      => true,
					'color'       => false,
					'font-backup' => false,
					'font-family' => true,
					'font-size'   => true,
					'font-style'  => false,
					'font-weight' => true,
					'line-height' => false,
					'subsets'     => true,
					'text-align'  => false,
					'preview'     => array( 'always_display' => true ),
					'default'     => array(
						'google'      => true,
						'font-family' => 'Roboto',
						'font-backup' => 'sans-serif',
						'font-size'   => '22px',
						'font-weight' => '500',
						'subsets'     => $wp_font_subset,
					),
				),
				array(
					'id'          => 'font_headings',
					'type'        => 'galactica_typography',
					'title'       => esc_html__( 'Headings', 'adama' ),
					'subtitle'    => esc_html__( 'Select font options for your headings: h1, h2, h3, h4, h5, h6.', 'adama' ),
					'compiler'    => array( 'h1, h2, h3, h4, h5, h6, .h1, .h2, .h3, .h4, .h5, .h6' ),
					'google'      => true,
					'color'       => false,
					'font-backup' => false,
					'font-family' => true,
					'font-size'   => false,
					'font-style'  => false,
					'font-weight' => true,
					'line-height' => false,
					'subsets'     => true,
					'text-align'  => false,
					'preview'     => array( 'always_display' => true, 'font-size' => '20px' ),
					'default'     => array(
						'google'      => true,
						'font-family' => 'Roboto',
						'font-backup' => 'sans-serif',
						'font-weight' => '400',
						'subsets'     => $wp_font_subset,
					),
				),
				array(
					'id'          => 'font_menu',
					'type'        => 'galactica_typography',
					'title'       => esc_html__( 'Menu', 'adama' ),
					'subtitle'    => esc_html__( 'Select font options for your main navigation menu.', 'adama' ),
					'compiler'    => array( '.navbar-primary .galactica-navbar-nav > li > a' ),
					'google'      => true,
					'color'       => false,
					'font-backup' => false,
					'font-family' => true,
					'font-size'   => true,
					'font-style'  => false,
					'font-weight' => true,
					'line-height' => false,
					'subsets'     => true,
					'text-align'  => false,
					'preview'     => array( 'always_display' => true ),
					'default'     => array(
						'google'      => true,
						'font-family' => 'Open Sans',
						'font-backup' => 'sans-serif',
						'font-size'   => '15px',
						'font-weight' => '400',
						'subsets'     => $wp_font_subset,
					)
				),
				array(
					'id'          => 'font_menu_dropdown',
					'type'        => 'galactica_typography',
					'title'       => esc_html__( 'Menu Dropdowns', 'adama' ),
					'subtitle'    => esc_html__( 'Select font options for your main navigation menu dropdowns.', 'adama' ),
					'compiler'    => array( '.navbar-primary .sub-menu > li > a' ),
					'google'      => true,
					'color'       => false,
					'font-backup' => false,
					'font-family' => true,
					'font-size'   => true,
					'font-style'  => false,
					'font-weight' => true,
					'line-height' => false,
					'subsets'     => true,
					'text-align'  => false,
					'preview'     => array( 'always_display' => true ),
					'default'     => array(
						'google'      => true,
						'font-family' => 'Open Sans',
						'font-backup' => 'sans-serif',
						'font-size'   => '14px',
						'font-weight' => '400',
						'subsets'     => $wp_font_subset,
					)
				),
			),
		);


		// Background Patterns Reader
		$patterns_path = GALACTICA_THEME_ASSETS_DIR . '/images/patterns/';
		$patterns_url  = GALACTICA_THEME_ASSETS_URL . '/images/patterns/';
		$patterns = array();
		if ( is_dir( $patterns_path ) ) {
			$patterns_dir = opendir( $patterns_path );
			if ( $patterns_dir ) {
				while ( ( $patterns_file = readdir( $patterns_dir ) ) !== false ) {
					if ( stristr( $patterns_file, '.png' ) !== false || stristr( $patterns_file, '.jpg' ) !== false ) {
						$name = explode( '.', $patterns_file );
						$name = str_replace( '.' . end( $name ), '', $patterns_file );
						$patterns[$patterns_url . $patterns_file] = array(
							'alt' => $name,
							'img' => $patterns_url . $patterns_file,
						);
					}
				}
			}
		}

		// Background
		$sections['background'] = array(
			'id'		 => 'background',
			'icon'       => 'dashicons-before dashicons-welcome-view-site',
			'title'      => esc_html__( 'Background', 'adama' ),
			'submenu'    => true,
			'customizer' => true,
			'fields'     => array(
				array(
					'id'          => 'body_background_color',
					'type'        => 'color',
					'title'       => esc_html__( 'Background Color', 'adama' ),
					'subtitle'    => esc_html__( 'Website background color.', 'adama' ),
					'compiler'    => array( 'background-color' => 'body' ),
					'transparent' => false,
					'default'     => '',
					'validate'    => 'color',
				),
				array(
					'id'       => 'body_background_image_type',
					'type'     => 'button_set',
					'title'    => esc_html__( 'Background Image Type', 'adama' ),
					'subtitle' => esc_html__( 'Enable custom or predefined pattern image for the website background.', 'adama' ),
					'compiler' => true,
					'options'  => array(
						''        => esc_html__( 'None', 'adama' ),
						'custom'  => esc_html__( 'Custom Image', 'adama' ),
						'pattern' => esc_html__( 'Pattern', 'adama' ),
					),
					'default'  => '',
				),
				array(
					'id'                    => 'body_background_image',
					'type'                  => 'galactica_background',
					'title'                 => esc_html__( 'Custom Background Image', 'adama' ),
					'subtitle'              => esc_html__( 'Upload custom image for the website background.', 'adama' ),
					'required'              => array( 'body_background_image_type', '=', 'custom' ),
					'compiler'              => array( 'body' ),
					'background-color'      => false,
					'background-repeat'     => true,
					'background-attachment' => true,
					'background-position'   => true,
					'background-image'      => true,
					'background-clip'       => false,
					'background-origin'     => false,
					'background-size'       => false,
					'preview_media'         => false,
					'preview'               => false,
					'transparent'           => false,
					'default'               => array(),
					//'validate'              => 'color', // Do not use - removes all but color
				),
				array(
					'id'       => 'body_background_image_pattern',
					'type'     => 'image_select',
					'title'    => esc_html__( 'Background Pattern', 'adama' ),
					'subtitle' => esc_html__( 'Select pattern image for the website background.', 'adama' ),
					'required' => array( 'body_background_image_type', '=', 'pattern' ),
					'compiler' => true,
					'class'    => 'galactica-pattern-images',
					'width'    => 64,
					'height'   => 64,
					'options'  => $patterns,
					'default'  => 'none',
				),
			),
		);

		// Style
		$sections['style'] = array(
			'id'		 => 'style',
			'icon'       => 'el el-brush',
			'title'      => esc_html__( 'Style', 'adama' ),
			'submenu'    => true,
			'customizer' => true,
			'fields'     => array(
				array(
					'id'       => 'color_scheme',
					'type'     => 'select',
					'title'    => esc_html__( 'Color Scheme', 'adama' ),
					'subtitle' => esc_html__( 'Main color scheme for the website.', 'adama' ),
					'compiler' => false,
					'options'  => array(
						'blue'         => esc_html__( 'Blue Theme', 'adama' ),
						'red'          => esc_html__( 'Red Theme', 'adama' ),
						'violet'       => esc_html__( 'Violet Theme', 'adama' ),
						'green'        => esc_html__( 'Green Theme', 'adama' ),
						'greendarker' => esc_html__( 'Darker Green Theme', 'adama' ),
						'yellow'       => esc_html__( 'Yellow Theme', 'adama' ),
						'orange'       => esc_html__( 'Orange Theme', 'adama' ),
					),
					'default'  => 'blue',
				),

				// General
				array(
					'id'   => 'style_info_general',
					'type' => 'info',
					'desc' => esc_html__( 'General', 'adama' ),
				),
				array(
					'id'          => 'style_link_color',
					'type'        => 'link_color',
					'title'       => esc_html__( 'Links Color', 'adama' ),
					'subtitle'    => esc_html__( 'Select your custom link color.', 'adama' ),
					'compiler'    => array( 'a' ),
					'regular'     => true,
					'hover'       => true,
					'active'      => false,
					'visited'     => false,
					'transparent' => false,
					'default'     => array(),
					'validate'    => 'color',
				),
				array(
					'id'          => 'button_color',
					'type'        => 'galactica_link_color',
					'title'       => esc_html__( 'Button Colors', 'adama' ),
					'subtitle'    => esc_html__( 'Select your custom colors for the primary button.', 'adama' ),
					'compiler'    => array(
						'.btn-two, .button, .button.alt, .wpcf7 .wpcf7-submit, input[type="submit"], .add-to-cart-hover .added_to_cart',
						'hover'  => '.btn-two:hover, .button:hover, .button.alt:hover, .wpcf7 .wpcf7-submit:hover, input[type="submit"]:hover, .add-to-cart-hover .added_to_cart:hover ' .
									'.btn-two:focus, .button:focus, .button.alt:focus, .wpcf7 .wpcf7-submit:focus, input[type="submit"]:focus, .add-to-cart-hover .added_to_cart:focus ' .
									'.btn-two:active, .button:active, .button.alt:active, .wpcf7 .wpcf7-submit:active, input[type="submit"]:active, .add-to-cart-hover .added_to_cart:active',
					),
					'regular'     => true,
					'hover'       => true,
					'active'      => false,
					'visited'     => false,
					'border'      => true,
					'transparent' => false,
					'default'     => array(),
					'validate'    => 'color',
				),

				// Content
				array(
					'id'   => 'style_info_content',
					'type' => 'info',
					'desc' => esc_html__( 'Content', 'adama' ),
				),
				array(
					'id'                    => 'content_background',
					'type'                  => 'galactica_background',
					'title'                 => esc_html__( 'Content Background', 'adama' ),
					'subtitle'              => esc_html__( 'Background color of the main content section. NOTE: Transparent option does not have any effect when "Uncover Footer" option is active.', 'adama' ),
					'compiler'              => array( '.main-content, .full-width-hero' ),
					'background-color'      => true,
					'background-repeat'     => true,
					'background-attachment' => false,
					'background-position'   => true,
					'background-image'      => true,
					'background-clip'       => false,
					'background-origin'     => false,
					'background-size'       => false,
					'preview_media'         => false,
					'preview'               => false,
					'transparent'           => true,
					'default'               => array(),
					//'validate'              => 'color', // Do not use - removes all but color
				),
				array(
					'id'          => 'content_color',
					'type'        => 'color',
					'title'       => esc_html__( 'Content Color', 'adama' ),
					'subtitle'    => esc_html__( 'Text color for the main content section.', 'adama' ),
					'compiler'    => array( 'color' => '.main-content' ),
					'transparent' => false,
					'default'     => '',
					'validate'    => 'color',
				),

				// Header Top
				array(
					'id'       => 'style_info_header_top',
					'type'     => 'info',
					'desc'     => esc_html__( 'Header Top', 'adama' ),
					'required' => array( 'header_top_enable', '=', '1' ),
				),
				array(
					'id'          => 'header_top_background',
					'type'        => 'color',
					'title'       => esc_html__( 'Background', 'adama' ),
					'subtitle'    => esc_html__( 'Background color of the top header section.', 'adama' ),
					'required'    => array( 'header_top_enable', '=', '1' ),
					'compiler'    => array( 'background' => '.top-header' ),
					'transparent' => false,
					'default'     => '',
					'validate'    => 'color',
				),
				array(
					'id'          => 'header_top_text_color',
					'type'        => 'color',
					'title'       => esc_html__( 'Color', 'adama' ),
					'subtitle'    => esc_html__( 'Text color for the top header section.', 'adama' ),
					'required'    => array( 'header_top_enable', '=', '1' ),
					'compiler'    => array( 'color' => '.top-header' ),
					'transparent' => false,
					'default'     => '',
					'validate'    => 'color',
				),
				array(
					'id'          => 'header_top_link_color',
					'type'        => 'link_color',
					'title'       => esc_html__( 'Link Color', 'adama' ),
					'subtitle'    => esc_html__( 'Link color for the top header section.', 'adama' ),
					'required'    => array( 'header_top_enable', '=', '1' ),
					'compiler'    => array( '.top-header a' ),
					'regular'     => true,
					'hover'       => true,
					'active'      => false,
					'visited'     => false,
					'transparent' => false,
					'default'     => array(),
					'validate'    => 'color',
				),
				array(
					'id'          => 'header_top_border',
					'type'        => 'color',
					'title'       => esc_html__( 'Border Color', 'adama' ),
					'subtitle'    => esc_html__( 'Border colors in top header.', 'adama' ),
					'required'    => array( 'header_top_enable', '=', '1' ),
					'compiler'    => array( 'border-color' => '.top-header, .top-header-menu > ul.menu > li' ),
					'transparent' => true,
					'default'     => '',
					'validate'    => 'color',
				),
				array(
					'id'          => 'header_top_nav_link_color',
					'type'        => 'galactica_link_color',
					'title'       => esc_html__( 'Navigation Link Colors', 'adama' ),
					'subtitle'    => esc_html__( 'Link text and background colors for top navigation.', 'adama' ),
					'required'    => array( 'header_top_enable', '=', '1' ),
					'compiler'    => array(
						'.top-header-menu > ul.menu > li > a',
						'active' => '.top-header-menu > ul.menu > li.current-menu-item > a',
						'hover'  => '.top-header-menu > ul.menu > li:hover > a, ' .
									'.top-header-menu > ul.menu > li.current-menu-item:hover > a',
					),
					'regular'     => true,
					'hover'       => true,
					'active'      => true,
					'visited'     => false,
					'border'      => false,
					'transparent' => false,
					'default'     => array(),
					'validate'    => 'color',
				),
				array(
					'id'          => 'header_top_nav_dropdown_borders',
					'type'        => 'color',
					'title'       => esc_html__( 'Navigation Dropdown Border Color', 'adama' ),
					'subtitle'    => esc_html__( 'Border color for the top navigation dropdowns.', 'adama' ),
					'required'    => array( 'header_top_enable', '=', '1' ),
					'compiler'    => array( 'border-color' => '.top-header-menu > ul.menu > li.dropdown .sub-menu' ),
					'transparent' => false,
					'default'     => '',
					'validate'    => 'color',
				),
				array(
					'id'          => 'header_top_nav_dropdown_link_color',
					'type'        => 'galactica_link_color',
					'title'       => esc_html__( 'Navigation Dropdown Link Colors', 'adama' ),
					'subtitle'    => esc_html__( 'Link text and background colors for the top navigation dropdowns.', 'adama' ),
					'required'    => array( 'header_top_enable', '=', '1' ),
					'compiler'    => array(
						'.top-header-menu ul.menu > li ul.sub-menu > li > a',
						'active' => '.top-header-menu ul.menu > li ul.sub-menu > li.current-menu-item > a',
						'hover'  => '.top-header-menu ul.menu > li ul.sub-menu > li:hover > a, ' .
									'.top-header-menu ul.menu > li ul.sub-menu > li.current-menu-item:hover > a',
					),
					'regular'     => true,
					'hover'       => true,
					'active'      => true,
					'visited'     => false,
					'border'      => false,
					'transparent' => false,
					'default'     => array(),
					'validate'    => 'color',
				),

				// Header
				array(
					'id'   => 'style_info_header',
					'type' => 'info',
					'desc' => esc_html__( 'Header', 'adama' ),
				),
				array(
					'id'          => 'header_background',
					'type'        => 'color',
					'title'       => esc_html__( 'Header Background', 'adama' ),
					'subtitle'    => esc_html__( 'Background color for the header.', 'adama' ),
					'compiler'    => array( 'background' => '.navbar-primary' ),
					'transparent' => false,
					'default'     => '',
					'validate'    => 'color',
				),
				array(
					'id'          => 'title_bar_background',
					'type'        => 'color',
					'title'       => esc_html__( 'Title Bar Background', 'adama' ),
					'subtitle'    => esc_html__( 'Background color for the title bar.', 'adama' ),
					'compiler'    => array( 'background' => '.title-bar' ),
					'transparent' => false,
					'default'     => '',
					'validate'    => 'color',
				),

				// Main Navigation
				array(
					'id'   => 'style_info_navigation',
					'type' => 'info',
					'desc' => esc_html__( 'Main Navigation', 'adama' ),
				),
				array(
					'id'          => 'nav_link_color',
					'type'        => 'galactica_link_color',
					'title'       => esc_html__( 'Link Colors', 'adama' ),
					'subtitle'    => esc_html__( 'Link text and background colors for  main navigation.', 'adama' ),
					'compiler'    => array(
						'.navbar-primary .galactica-navbar-nav > li > a',
						'active' => '.navbar-primary .galactica-navbar-nav > li.current-menu-item > a,
									.navbar-primary .galactica-navbar-nav > li.current-one-page-item > a',
						'hover'  => '.navbar-primary .galactica-navbar-nav > li > a:hover,
									.navbar-primary .galactica-navbar-nav > li.current-menu-item > a:hover,
									.navbar-primary .galactica-navbar-nav > li.current-one-page-item > a:hover,
									.galactica-navbar-collapse .galactica-nav li:hover > a',
					),
					'regular'     => true,
					'hover'       => true,
					'active'      => true,
					'visited'     => false,
					'border'      => false,
					'transparent' => false,
					'default'     => array(),
					'validate'    => 'color',
				),
				array(
					'id'          => 'nav_dropdown_background',
					'type'        => 'color',
					'title'       => esc_html__( 'Dropdown Background', 'adama' ),
					'subtitle'    => esc_html__( 'Background color for the main navigation dropdowns.', 'adama' ),
					'compiler'    => array( 'background' => '.navbar-primary .sub-menu, .galactica-navbar-collapse .galactica-nav .mega-menu > .sub-menu-container' ),
					'transparent' => false,
					'default'     => '',
					'validate'    => 'color',
				),
				array(
					'id'          => 'nav_dropdown_borders',
					'type'        => 'color',
					'title'       => esc_html__( 'Dropdown Border Color', 'adama' ),
					'subtitle'    => esc_html__( 'Border color for the main navigation dropdowns.', 'adama' ),
					'compiler'    => array( 'border-color' => '.navbar-primary .sub-menu li a' ),
					'transparent' => false,
					'default'     => '',
					'validate'    => 'color',
				),
				array(
					'id'          => 'nav_dropdown_link_color',
					'type'        => 'galactica_link_color',
					'title'       => esc_html__( 'Dropdown Link Colors', 'adama' ),
					'subtitle'    => esc_html__( 'Link text and background colors for the main navigation dropdowns.', 'adama' ),
					'compiler'    => array(
						'.navbar-primary .sub-menu > li > a, .galactica-navbar-collapse .galactica-nav li .mega-menu-column-title a, .galactica-navbar-collapse .galactica-nav .mega-menu > .sub-menu-container .sub-menu li:hover > a',
						'active' => '.navbar-primary .sub-menu > li.current-menu-item > a',
						'hover'  => '.navbar-primary .sub-menu > li:hover > a, ' .
									'.navbar-primary .sub-menu > li.current-menu-item:hover > a,
									.galactica-navbar-collapse .galactica-nav .mega-menu > .sub-menu-container .sub-menu li a:hover',
					),
					'regular'     => true,
					'hover'       => true,
					'active'      => true,
					'visited'     => false,
					'border'      => false,
					'transparent' => false,
					'default'     => array(),
					'validate'    => 'color',
				),

				// Footer bottom
				array(
					'id'   => 'style_info_footer',
					'type' => 'info',
					'desc' => esc_html__( 'Footer', 'adama' ),
				),
				array(
					'id'          => 'footer_background',
					'type'        => 'color',
					'title'       => esc_html__( 'Background', 'adama' ),
					'subtitle'    => esc_html__( 'Background color of the footer section.', 'adama' ),
					'compiler'    => array( 'background' => '.main-footer' ),
					'transparent' => false,
					'default'     => '',
					'validate'    => 'color',
				),
				array(
					'id'          => 'footer_color',
					'type'        => 'color',
					'title'       => esc_html__( 'Color', 'adama' ),
					'subtitle'    => esc_html__( 'Text color for the bottom part of the footer section.', 'adama' ),
					'compiler'    => array( 'color' => '.main-footer' ),
					'transparent' => false,
					'default'     => '',
					'validate'    => 'color',
				),
				array(
					'id'          => 'footer_link_color',
					'type'        => 'link_color',
					'title'       => esc_html__( 'Link Color', 'adama' ),
					'subtitle'    => esc_html__( 'Link color for the bottom part of the footer section.', 'adama' ),
					'compiler'    => array( '.footer-bottom a' ),
					'regular'     => true,
					'hover'       => true,
					'active'      => false,
					'visited'     => false,
					'transparent' => false,
					'default'     => array(),
					'validate'    => 'color',
				),

				// Footer Top (widget area)
				array(
					'id'   => 'style_info_footer_top',
					'type' => 'info',
					'desc' => esc_html__( 'Footer Widget Area', 'adama' ),
				),
				array(
					'id'          => 'footer_top_background',
					'type'        => 'color',
					'title'       => esc_html__( 'Background', 'adama' ),
					'subtitle'    => esc_html__( 'Background color of the widget (top) area of the footer section.', 'adama' ),
					'compiler'    => array( 'background' => '.footer-top' ),
					'transparent' => false,
					'default'     => '',
					'validate'    => 'color',
				),
				array(
					'id'          => 'footer_top_color',
					'type'        => 'color',
					'title'       => esc_html__( 'Color', 'adama' ),
					'subtitle'    => esc_html__( 'Text color for the widget (top) area of the footer section.', 'adama' ),
					'compiler'    => array( 'color' => '.footer-top' ),
					'transparent' => false,
					'default'     => '',
					'validate'    => 'color',
				),
				array(
					'id'          => 'footer_top_link_color',
					'type'        => 'link_color',
					'title'       => esc_html__( 'Link Color', 'adama' ),
					'subtitle'    => esc_html__( 'Link color for the widget (top) area of the footer section.', 'adama' ),
					'compiler'    => array( '.footer-top a' ),
					'regular'     => true,
					'hover'       => true,
					'active'      => false,
					'visited'     => false,
					'transparent' => false,
					'default'     => array(),
					'validate'    => 'color',
				),

				// Custom CSS
				array(
					'id'   => 'style_info_custom_css',
					'type' => 'info',
					'desc' => esc_html__( 'Custom CSS', 'adama' ),
				),
				array(
					'id'       => 'custom_css',
					'type'     => 'textarea',
					'title'    => esc_html__( 'Custom CSS', 'adama' ),
					'subtitle' => esc_html__( 'Quickly add some CSS to your theme by adding it to this block.', 'adama' ),
					'compiler' => true,
					'validate' => 'css',
				),
			),
		);

		// Slider
		$sections['slider'] = array(
			'id'		 => 'slider',
			'icon'       => 'dashicons-before dashicons-images-alt2',
			'title'      => esc_html__( 'Simple Slider', 'adama' ),
			'submenu'    => true,
			'customizer' => false,
			'fields'     => array(
				array(
					'id'       => 'simple_slider_enable',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Enable Simple Slider', 'adama' ),
					'default'  => true,
				),
				array(
					'id'       => 'simple_slider_autplay',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Autoplay', 'adama' ),
					'required' => array( 'simple_slider_enable', '=', '1' ),
					'default'  => true,
				),
				array(
					'id'       => 'simple_slider_interval',
					'type'     => 'text',
					'title'    => esc_html__( 'Interval (ms)', 'adama' ),
					'subtitle' => esc_html__( 'Autoplay speed (this must be a numeric value).', 'adama' ),
					'required' => array( 'simple_slider_enable', '=', '1' ),
					'validate' => 'numeric',
					'default'  => '3000',
					'class'    => 'small-text',
				),
				array(
					'id'       => 'simple_slider_loop',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Loop Slides', 'adama' ),
					'subtitle' => esc_html__( 'Infinite loop.', 'adama' ),
					'required' => array( 'simple_slider_enable', '=', '1' ),
					'default'  => true,
				),
				array(
					'id'       => 'simple_slider_show_indicators',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Show Dots', 'adama' ),
					'subtitle' => esc_html__( 'Show dots navigation.', 'adama' ),
					'required' => array( 'simple_slider_enable', '=', '1' ),
					'default'  => true,
				),
				array(
					'id'       => 'simple_slider_show_nav',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Show Navigation', 'adama' ),
					'subtitle' => esc_html__( 'Show next and previous buttons.', 'adama' ),
					'required' => array( 'simple_slider_enable', '=', '1' ),
					'default'  => false,
				),
				array(
					'id'       => 'simple_slider_hide_title',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Hide Slide Titles', 'adama' ),
					'subtitle' => esc_html__( 'Use this option to hide titles in sliders.', 'adama' ),
					'required' => array( 'simple_slider_enable', '=', '1' ),
					'default'  => false,
				),
			),
		);

		// LightBox
		$sections['lightbox'] = array(
			'id'		 => 'lightbox',
			'icon'       => 'dashicons-before dashicons-format-image',
			'title'      => esc_html__( 'LightBox', 'adama' ),
			'submenu'    => true,
			'customizer' => false,
			'fields'     => array(
				array(
					'id'       => 'lightbox_enable_for_posts',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Enable for Posts', 'adama' ),
					'subtitle' => esc_html__( 'Show post and page images that are inside the content area in the lightbox.', 'adama' ),
					'default'  => true,
				),
				array(
					'id'       => 'lightbox_skin',
					'type'     => 'select',
					'title'    => esc_html__( 'Skin', 'adama' ),
					'subtitle' => esc_html__( 'Sets the visual appearance of ligthbox.', 'adama' ),
					'options'  => array(
						'dark'        => esc_html__( 'Dark', 'adama' ),
						'flat-dark'   => esc_html__( 'Flat Dark', 'adama' ),
						'light'       => esc_html__( 'Light', 'adama' ),
						'mac'         => esc_html__( 'Mac', 'adama' ),
						'metro-black' => esc_html__( 'Metro Black', 'adama' ),
						'metro-white' => esc_html__( 'Metro White', 'adama' ),
						'parade'      => esc_html__( 'Parade', 'adama' ),
						'smooth'      => esc_html__( 'Smooth', 'adama' ),
					),
					'default'  => 'dark',
				),
				array(
					'id'       => 'lightbox_direction',
					'type'     => 'button_set',
					'title'    => esc_html__( 'Direction', 'adama' ),
					'options'  => array(
						'horizontal' => esc_html__( 'Horizontal', 'adama' ),
						'vertical'   => esc_html__( 'Vertical', 'adama' ),
					),
					'default'  => 'horizontal',
				),
				array(
					'id'       => 'lightbox_show_arrows',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Show Arrows', 'adama' ),
					'subtitle' => esc_html__( 'Enable the arrow buttons.', 'adama' ),
					'default'  => true,
				),
				array(
					'id'       => 'lightbox_show_thumnails',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Show Thumbnails', 'adama' ),
					'subtitle' => esc_html__( 'Enable thumbnail navigation.', 'adama' ),
					'default'  => false,
				),
//				array(
//					'id'       => 'lightbox_animation_speed',
//					'type'     => 'button_set',
//					'title'    => esc_html__( 'Animation Speed', 'adama' ),
//					'subtitle' => esc_html__( 'Chose the animation speed.', 'adama' ),
//					'options'  => array(
//						'fast'   => esc_html__( 'Fast', 'adama' ),
//						'normal' => esc_html__( 'Normal', 'adama' ),
//						'slow'   => esc_html__( 'Slow', 'adama' ),
//					),
//					'default'  => 'fast',
//				),
			),
		);

		$sections[] = array(
			'type' => 'divide',
		);

		// Portfolio
		$sections['portfolio'] = array(
			'id'		 => 'portfolio',
			'icon'       => 'dashicons-before dashicons-portfolio',
			'title'      => esc_html__( 'Portfolio', 'adama' ),
			'submenu'    => true,
			'customizer' => false,
			'fields'     => array(
				array(
					'id'       => 'portfolio_enabled',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Enable Portfolio', 'adama' ),
					'subtitle' => esc_html__( 'Use this option to enable or disable Portfolio.', 'adama' ),
					'default'  => true,
				),
				array(
					'id'       => 'portfolio_layout',
					'type'     => 'button_set',
					'title'    => esc_html__( 'Page Layout', 'adama' ),
					'subtitle' => esc_html__( 'Select layout for portfolio archive pages.', 'adama' ),
					'options'  => array(
						'fluid' => esc_html__( 'Fluid', 'adama' ),
						'boxed' => esc_html__( 'Boxed', 'adama' ),
					),
					'required' => array( 'portfolio_enabled', '=', '1' ),
					'default'  => 'boxed',
				),
				array(
					'id'       => 'portfolio_items_per_page',
					'type'     => 'text',
					'title'    => esc_html__( 'Items per Page', 'adama' ),
					'subtitle' => esc_html__( 'Number of portfolio items on portfolio archive pages.', 'adama' ),
					'validate' => 'numeric',
					'required' => array( 'portfolio_enabled', '=', '1' ),
					'default'  => '9',
					'class'    => 'small-text',
				),
				array(
					'id'       => 'portfolio_columns',
					'type'     => 'button_set',
					'title'    => esc_html__( 'Columns', 'adama' ),
					'subtitle' => esc_html__( 'Select number of columns for portfolio archive pages.', 'adama' ),
					'options'  => array(
						'1' => '1',
						'2' => '2',
						'3' => '3',
						'4' => '4',
					),
					'required' => array( 'portfolio_enabled', '=', '1' ),
					'default'  => '3',
				),
				array(
					'id'       => 'portfolio_style',
					'type'     => 'button_set',
					'title'    => esc_html__( 'Style', 'adama' ),
					'subtitle' => esc_html__( 'Select style for portfolio archive pages.', 'adama' ),
					'options'  => array(
						'hover'       => esc_html__( 'Hover', 'adama' ),
						'text-bellow' => esc_html__( 'Text Below', 'adama' ),
					),
					'required' => array( 'portfolio_enabled', '=', '1' ),
					'default'  => 'hover',
				),
				array(
					'id'       => 'portfolio_spaced',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Space Out', 'adama' ),
					'subtitle' => esc_html__( 'Adds padding between portfolio items on portfolio archive pages.', 'adama' ),
					'required' => array( 'portfolio_enabled', '=', '1' ),
					'default'  => false,
				),
				array(
					'id'       => 'portfolio_enable_custom_sidebar',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Enable Custom Portfolio Sidebar', 'adama' ),
					'subtitle' => esc_html__( 'Adds dedicated sidebar for portfolio pages.', 'adama' ),
					'required' => array( 'portfolio_enabled', '=', '1' ),
					'default'  => false,
				),
				array(
					'id'       => 'portfolio_sidebar_position',
					'type'     => 'image_select',
					'title'    => esc_html__( 'Portfolio Sidebar Position', 'adama' ),
					'subtitle' => esc_html__( 'Select sidebar position for portfolio pages.', 'adama' ),
					'options'  => array(
						'none'  => array(
							'alt' => esc_html__( 'No Sidebar', 'adama' ),
							'img' => ReduxFramework::$_url.'assets/img/1col.png'
						),
						'right' => array(
							'alt' => esc_html__( 'Right Sidebar', 'adama' ),
							'img' => ReduxFramework::$_url.'assets/img/2cr.png'
						),
						'left'  => array(
							'alt' => esc_html__( 'Left Sidebar', 'adama' ),
							'img' => ReduxFramework::$_url.'assets/img/2cl.png'
						),
					),
					'required' => array( 'portfolio_enabled', '=', '1' ),
					'default'  => 'none',
				),
				array(
					'id'       => 'portfolio_single_layout',
					'type'     => 'button_set',
					'title'    => esc_html__( 'Single Portfolio Layout', 'adama' ),
					'subtitle' => esc_html__( 'Select layout for single portfolio template.', 'adama' ),
					'options'  => array(
						'horizontal' => esc_html__( 'Horizontal', 'adama' ),
						'vertical'   => esc_html__( 'Vertical', 'adama' ),
					),
					'required' => array( 'portfolio_enabled', '=', '1' ),
					'default'  => 'vertical',
				),
				array(
					// NOTE: Translatable field - ID in wpml-config
					'id'                => 'portfolio_attributes',
					'type'              => 'galactica_attributes',
					'title'             => esc_html__( 'Custom Attributes', 'adama' ),
					'subtitle'          => esc_html__( 'Allows you to define extra project attributes which will be listed on project page.', 'adama' ),
					'show'              => array(
						'name' => true,
						'slug' => true,
						'type' => true,
						'desc' => true,
					),
					'placeholder'       => array(
						'name' => esc_html__( 'Name', 'adama' ),
						'slug' => esc_html__( 'Slug', 'adama' ),
						'desc' => esc_html__( 'Description', 'adama' ),
					),
					'validate_callback' => 'galactica_core_redux_validate_attributes',
					'required' => array( 'portfolio_enabled', '=', '1' ),
					'default'           => array(
						array(
							'type' => 'date',
							'slug' => 'release_date',
							'name' => esc_html__( 'Release Date', 'adama' ),
							'desc' => esc_html__( 'Enter the project date', 'adama' ),
						),
						array(
							'type' => 'text',
							'slug' => 'client',
							'name' => esc_html__( 'Client', 'adama' ),
							'desc' => esc_html__( 'Enter the name of the client e.g. Multi Corp.', 'adama' ),
						),
						array(
							'type' => 'url',
							'slug' => 'website',
							'name' => esc_html__( 'Website', 'adama' ),
							'desc' => esc_html__( 'Enter the website address of the client', 'adama' ),
						),
					),
				),
				array(
					// NOTE: Translatable field - ID in wpml-config
					'id'       => 'portfolio_related_projects_title',
					'type'     => 'text',
					'title'    => esc_html__( 'Related Projects Title', 'adama' ),
					'subtitle' => esc_html__( 'Replace base title for your related projects section.', 'adama' ),
					'required' => array( 'portfolio_enabled', '=', '1' ),
					'default'  => esc_html__( 'Related Projects', 'adama' ),
				),
				array(
					'id'       => 'portfolio_comments_enable',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Enable Comments', 'adama' ),
					'subtitle' => esc_html__( 'Use this option to enable or disable comments in your Portfolio section.', 'adama' ),
					'required' => array( 'portfolio_enabled', '=', '1' ),
					'default'  => false,
				),
				array(
					'id'       => 'portfolio_enable_share',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Enable Social Share', 'adama' ),
					'subtitle' => esc_html__( 'Show social share buttons on single portfolio page.', 'adama' ),
					'required' => array( 'portfolio_enabled', '=', '1' ),
					'default'  => true,
				),
				array(
					'id'       => 'portfolio_enable_prev_next_nav',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Enable Previous/Next Navigation', 'adama' ),
					'required' => array( 'portfolio_enabled', '=', '1' ),
					'default'  => true,
				),
				array(
					'id'       => 'portfolio_slug',
					'type'     => 'text',
					'title'    => esc_html__( 'URL base', 'adama' ),
					'subtitle' => esc_html__( 'Replace base slug for your portfolio items.', 'adama' ),
					'validate' => 'no_special_chars',
					'required' => array( 'portfolio_enabled', '=', '1' ),
					'default'  => 'portfolio-items',
				),
				array(
					'id'       => 'portfolio_slug_category',
					'type'     => 'text',
					'title'    => esc_html__( 'Category URL base', 'adama' ),
					'subtitle' => esc_html__( 'Replace base slug for your portfolio category.', 'adama' ),
					'validate' => 'no_special_chars',
					'required' => array( 'portfolio_enabled', '=', '1' ),
					'default'  => 'portfolio-category',
				),
				array(
					'id'       => 'portfolio_slug_tags',
					'type'     => 'text',
					'title'    => esc_html__( 'Tags URL base', 'adama' ),
					'subtitle' => esc_html__( 'Replace base slug for your portfolio tags.', 'adama' ),
					'validate' => 'no_special_chars',
					'required' => array( 'portfolio_enabled', '=', '1' ),
					'default'  => 'portfolio-tags',
				),
				array(
					'id'       => 'portfolio_slug_technology',
					'type'     => 'text',
					'title'    => esc_html__( 'Technology URL base', 'adama' ),
					'subtitle' => esc_html__( 'Replace base slug for technologies in your portfolio section.', 'adama' ),
					'validate' => 'no_special_chars',
					'required' => array( 'portfolio_enabled', '=', '1' ),
					'default'  => 'portfolio-technology',
				),
			),
		);

		// Team
		$sections['team'] = array(
			'id'		 => 'team',
			'icon'       => 'dashicons-before dashicons-groups',
			'title'      => esc_html__( 'Team Members', 'adama' ),
			'submenu'    => true,
			'customizer' => false,
			'fields'     => array(
				array(
					'id'       => 'team_enabled',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Enable Team', 'adama' ),
					'subtitle' => esc_html__( 'Use this option to enable or disable Team Members.', 'adama' ),
					'default'  => true,
				),
				array(
					'id'       => 'team_slug',
					'type'     => 'text',
					'title'    => esc_html__( 'Team URL base', 'adama' ),
					'subtitle' => esc_html__( 'Replace base slug for your team members.', 'adama' ),
					'validate' => 'no_special_chars',
					'required' => array( 'team_enabled', '=', '1' ),
					'default'  => 'team-members',
				),
				array(
					'id'       => 'team_slug_skills',
					'type'     => 'text',
					'title'    => esc_html__( 'Skills URL base', 'adama' ),
					'subtitle' => esc_html__( 'Replace base slug for your team skills.', 'adama' ),
					'validate' => 'no_special_chars',
					'required' => array( 'team_enabled', '=', '1' ),
					'default'  => 'team-skills',
				),
				array(
					'id'       => 'team_comments_enable',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Enable Comments', 'adama' ),
					'subtitle' => esc_html__( 'Enable comments on Team member single pages.', 'adama' ),
					'required' => array( 'team_enabled', '=', '1' ),
					'default'  => false,
				),
			),
		);

		// FAQ
		$sections['faq'] = array(
			'id'		 => 'faq',
			'icon'       => 'dashicons-before dashicons-feedback',
			'title'      => esc_html__( 'FAQ', 'adama' ),
			'submenu'    => true,
			'customizer' => false,
			'fields'     => array(
				array(
					'id'       => 'faq_enabled',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Enable FAQ', 'adama' ),
					'subtitle' => esc_html__( 'Use this option to enable or disable FAQs.', 'adama' ),
					'default'  => true,
				),
			),
		);

		// Testimonials
		$sections['testimonials'] = array(
			'id'		 => 'testimonials',
			'icon'       => 'dashicons-before dashicons-format-quote',
			'title'      => esc_html__( 'Testimonials', 'adama' ),
			'submenu'    => true,
			'customizer' => false,
			'fields'     => array(
				array(
					'id'       => 'testimonials_enabled',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Enable Testimonials', 'adama' ),
					'subtitle' => esc_html__( 'Use this option to enable or disable Testimonials.', 'adama' ),
					'default'  => true,
				),
			),
		);

		// Shop - WooCommerce
		if ( galactica_is_woocommerce_activated() ) {
			$shop_fields = array(
				array(
					'id'       => 'shop_columns',
					'type'     => 'button_set',
					'title'    => esc_html__( 'Shop Columns', 'adama' ),
					'subtitle' => esc_html__( 'Select how many columns you want for your shop.', 'adama' ),
					'options'  => array(
						'1' => '1',
						'2' => '2',
						'3' => '3',
						'4' => '4',
					),
					'default'  => '3',
				),
				array(
					'id'       => 'header_top_nav_enable_cart',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Enable Cart popup', 'adama' ),
					'subtitle' => esc_html__( 'Add mini cart popup to secondary menu in top bar.', 'adama' ),
					'required' => array(
						array( 'header_top_enable', '=', '1' ),
						array( 'header_top_right_content', '=', 'secondary_menu' ),
					),
					'default'  => true,
				),
				array(
					'id'       => 'shop_enable_share',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Enable Social Share', 'adama' ),
					'subtitle' => esc_html__( 'Show social share buttons on single product page.', 'adama' ),
					'default'  => true,
				),
				array(
					'id'       => 'shop_checkout_enable_help_messages',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Enable Checkout Help Messages', 'adama' ),
					'subtitle' => esc_html__( 'Show help messages on checkout page.', 'adama' ),
					'default'  => true,
				),
				array(
					// NOTE: Translatable field - ID in wpml-config
					'id'       => 'shop_checkout_message_1',
					'type'     => 'text',
					'title'    => esc_html__( 'Checkout Message 1', 'adama' ),
					'subtitle' => esc_html__( 'Insert your text and it will appear in the first message box on the checkout page.', 'adama' ),
					'required' => array( 'shop_checkout_enable_help_messages', '=', '1' ),
					'default'  => esc_html__( 'Need Assistance? Call customer service at XXX-XXX-XXX.', 'adama' ),
				),
				array(
					// NOTE: Translatable field - ID in wpml-config
					'id'       => 'shop_checkout_message_2',
					'type'     => 'text',
					'title'    => esc_html__( 'Checkout Message 2', 'adama' ),
					'subtitle' => esc_html__( 'Insert your text and it will appear in the second message box on the checkout page.', 'adama' ),
					'required' => array( 'shop_checkout_enable_help_messages', '=', '1' ),
					'default'  => esc_html__( 'E-mail them at info@example.com', 'adama' ),
				),
			);
		} else {
			$shop_fields = array(
				array(
					'id'   => 'shop_notice',
					'type' => 'info',
					'desc' => esc_html__( 'Please install WooCommerce plugin to be able to change shop options.', 'adama' ),
				),
			);
		}

		$sections['shop'] = array(
			'id'		 => 'shop',
			'icon'       => 'el-icon-shopping-cart',
			'title'      => esc_html__( 'Shop', 'adama' ),
			'submenu'    => true,
			'customizer' => false,
			'fields'     => $shop_fields,
		);

		// Blog
		$sections['blog'] = array(
			'id'		 => 'blog',
			'icon'       => 'el-icon-edit',
			'title'      => esc_html__( 'Blog', 'adama' ),
			'submenu'    => true,
			'customizer' => false,
			'fields'     => array(
				array(
					'id'       => 'blog_layout',
					'type'     => 'button_set',
					'title'    => esc_html__( 'Blog Layout', 'adama' ),
					'subtitle' => esc_html__( 'Select your preferred style for your main blog page, categories and tags.', 'adama' ),
					'options' => array(
						'list'    => esc_html__( 'List', 'adama' ),
						'grid'    => esc_html__( 'Grid', 'adama' ),
						'masonry' => esc_html__( 'Masonry', 'adama' ),
					),
					'default'  => 'list',
				),
				array(
					'id'       => 'blog_masonry_columns',
					'type'     => 'button_set',
					'title'    => esc_html__( 'Masonry Columns', 'adama' ),
					'subtitle' => esc_html__( 'Select how many columns you want for your blog archives with masonry layout.', 'adama' ),
					'required' => array( 'blog_layout', '=', 'masonry' ),
					'options'  => array(
						'2' => '2',
						'3' => '3',
						'4' => '4',
					),
					'default'  => '4',
				),
				array(
					'id'       => 'blog_enable_custom_sidebar',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Enable Custom Blog Sidebar', 'adama' ),
					'default'  => false,
				),
				array(
					'id'       => 'blog_sidebar_position',
					'type'     => 'image_select',
					'title'    => esc_html__( 'Blog Sidebar Position', 'adama' ),
					'subtitle' => esc_html__( 'Select sidebar position for blog pages.', 'adama' ),
					'options'  => array(
						'none'  => array(
							'alt' => esc_html__( 'No Sidebar', 'adama' ),
							'img' => ReduxFramework::$_url.'assets/img/1col.png'
						),
						'right' => array(
							'alt' => esc_html__( 'Right Sidebar', 'adama' ),
							'img' => ReduxFramework::$_url.'assets/img/2cr.png'
						),
						'left'  => array(
							'alt' => esc_html__( 'Left Sidebar', 'adama' ),
							'img' => ReduxFramework::$_url.'assets/img/2cl.png'
						),
					),
					'default'  => 'none',
				),
				array(
					'id'       => 'blog_enable_prev_next_nav',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Enable Previous/Next Navigation', 'adama' ),
					'default'  => true,
				),
				array(
					'id'       => 'blog_post_enable_share',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Enable Social Share', 'adama' ),
					'subtitle' => esc_html__( 'Show social share buttons on single post page.', 'adama' ),
					'default'  => true,
				),
				array(
					'id'       => 'blog_post_enable_related_posts',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Enable Related Posts', 'adama' ),
					'subtitle' => esc_html__( 'Show related posts on single post page.', 'adama' ),
					'default'  => true,
				),
				array(
					'id'       => 'blog_hide_author_info',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Show Author Information', 'adama' ),
					'subtitle' => esc_html__( 'Show/hide all author information.', 'adama' ),
					'default'  => true,
				),
				array(
					'id'       => 'blog_hide_about_author',
					'type'     => 'switch',
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'title'    => esc_html__( 'Show About the Author', 'adama' ),
					'subtitle' => esc_html__( 'Show/hide About the Author section on single post page.', 'adama' ),
					'default'  => true,
				),
			),
		);

		// Social
		// NOTE: This tab is referenced in Social widget
		$sections['social'] = array(
			'id'		 => 'social',
			'icon'       => 'dashicons-before dashicons-share',
			'title'      => esc_html__( 'Social', 'adama' ),
			'submenu'    => true,
			'customizer' => false,
			'fields'     => array(
				array(
					'id'      => 'social_nofollow',
					'type'    => 'switch',
					'on'      => esc_html__( 'Yes', 'adama' ),
					'off'     => esc_html__( 'No', 'adama' ),
					'title'   => esc_html__( 'NoFollow Links', 'adama' ),
					'default' => true,
				),
				array(
					'id'      => 'social_target',
					'type'    => 'select',
					'title'   => esc_html__( 'Link Target', 'adama' ),
					'options' => array(
						'_blank' => esc_html__( 'Blank', 'adama' ),
						'_self'  => esc_html__( 'Self', 'adama' ),
					),
					'default' => '_blank',
				),
			),
		);

		// Add social list
		$social_list = galactica_social_list( 'settings' );
		if ( !empty( $social_list ) ) {
			$sections['social']['fields'][] = array(
				'id'     => 'section-header-top',
				'type'   => 'section',
				'title'  => esc_html__( 'Social URLs', 'adama' ),
				'indent' => true,
			);

			foreach ( $social_list as $social ) {
				$validator = empty( $social['is_username'] ) ? 'url' : null;
				$social_description = empty( $social['is_username'] ) ? esc_html__( 'Please enter URL to show %s icon on your website.', 'adama' ) : esc_html__( 'Please enter username to show %s icon on your website.', 'adama' );

				$sections['social']['fields'][] = array(
					'id'       => "social_{$social['slug']}",
					'type'     => 'text',
					'validate' => $validator,
					'title'    => $social['name'],
					'desc'     => sprintf( $social_description, $social['name'] ),
				);
			}

			$sections['social']['fields'][] = array(
				'id'     => 'section-header-top-end',
				'type'   => 'section',
				'indent' => false,
			);
		}

		// Contact page
		$sections['contact-page'] = array(
			'id'		 => 'contact-page',
			'icon'       => 'dashicons-before dashicons-email-alt',
			'title'      => esc_html__( 'Contact Page', 'adama' ),
			'submenu'    => true,
			'customizer' => false,
			'fields'     => array(
				array(
					// NOTE: Translatable field - ID in wpml-config
					'id'       => 'contact_email',
					'type'     => 'text',
					'title'    => esc_html__( 'Contact Email', 'adama' ),
					'subtitle' => esc_html__( 'Enter email address for receiving contact form emails. If not entered admin email from WordPress options will be used instead.', 'adama' ),
					'validate' => 'email',
				),
				array(
					'id'       => 'section-contact-map-top',
					'type'     => 'section',
					'title'    => esc_html__( 'Map', 'adama' ),
					'subtitle' => esc_html__( 'Set Map related options for Contact page.', 'adama' ),
					'indent'   => true,
				),
					array(
						'id'       => 'contact_map_address',
						'type'     => 'multi_text',
						'title'    => esc_html__( 'Address', 'adama' ),
						'subtitle' => esc_html__( 'Enter one or more addresses that will be pinned on the map.', 'adama' ),
						'add_text' => esc_html__( 'Add Address', 'adama' ),
					),
					array(
						'id'       => 'contact_map_type',
						'type'     => 'select',
						'title'    => esc_html__( 'Type', 'adama' ),
						'subtitle' => esc_html__( 'Select map type.', 'adama' ),
						'options'  => array(
							'road'      => esc_html__( 'Road', 'adama' ),
							'satellite' => esc_html__( 'Satellite', 'adama' ),
							'hybrid'    => esc_html__( 'Hybrid', 'adama' ),
							'terrain'   => esc_html__( 'Terrain', 'adama' ),
						),
						'default'  => 'road',
					),
					array(
						'id'       => 'contact_map_height',
						'type'     => 'text',
						'title'    => esc_html__( 'Height (px)', 'adama' ),
						'subtitle' => esc_html__( 'Map height.', 'adama' ),
						'validate' => 'numeric',
						'default'  => 300,
					),
					array(
						'id'       => 'contact_map_zoom',
						'type'     => 'text',
						'title'    => esc_html__( 'Zoom', 'adama' ),
						'subtitle' => esc_html__( 'Zoom Level (from 0 to about 20).', 'adama' ),
						'validate' => 'numeric',
						'default'  => 15,
					),
					array(
						'id'       => 'api_key_google_maps',
						'type'     => 'text',
						'title'    => esc_html__( 'Google Maps API key', 'adama' ),
						'subtitle' => esc_html__( 'Required for Google Maps use', 'adama' ),
						'desc'     => esc_html__( 'To generate an API key:', 'adama' )
									. '<ol class="ol-decimal">'
									. '<li>' . sprintf( esc_html__( 'Go to the %sGoogle Developers Console%s.', 'adama' ), '<a href="https://console.developers.google.com/flows/enableapi?apiid=maps_backend,geocoding_backend,directions_backend,distance_matrix_backend,elevation_backend&keyType=CLIENT_SIDE&reusekey=true" target="_blank">', '</a>' )
									. '<li>' . esc_html__( 'Create or select a project.', 'adama' )
									. '<li>' . esc_html__( 'Click Continue to enable the API and any related services.', 'adama' )
									. '<li>' . esc_html__( 'On the Credentials page, get a Browser key (and set the API Credentials).', 'adama' )
										. '<br/>' . esc_html__( 'Note: If you have an existing Browser key, you may use that key.', 'adama' )
									. '</ol>'
									. '<a href="https://developers.google.com/maps/documentation/javascript/get-api-key#key" target="_blank">' . esc_html__( "More info on Google's website", 'adama' ) . '</a>',
						'default'  => '',
						'validate' => 'no_special_chars',
					),
				array(
					'id'     => 'section-contact-map-end',
					'type'   => 'section',
					'indent' => false,
				),
			),
		);

		$sections[] = array(
			'type' => 'divide',
		);

		// Tabs
		$tabs = array();

		// Auto Updater
		$sections['updater'] = array(
			'id'		 => 'updater',
			'icon'       => 'dashicons-before dashicons-update',
			'title'      => esc_html__( 'Theme Update', 'adama' ),
			'submenu'    => true,
			'customizer' => false,
			'fields'     => array(
				array(
					'id'       => 'updater_envato_username',
					'type'     => 'text',
					'title'    => esc_html__( 'ThemeForest Username', 'adama' ),
					'subtitle' => esc_html__( 'Enter the username of the user you used to purchase this theme.', 'adama' ),
					'default'  => '',
					'validate' => 'no_special_chars',
				),
				array(
					'id'       => 'updater_envato_api_key',
					'type'     => 'text',
					'title'    => esc_html__( 'ThemeForest API key', 'adama' ),
					'subtitle' => esc_html__( 'Enter the API Key from your Account here', 'adama' ),
					'desc'     => esc_html__( 'To generate an API key, go to your ThemeForest account and select Settings from the account dropdown, then navigate to the API Keys tab.', 'adama' ),
					'default'  => '',
					'validate' => 'no_special_chars',
				),
				array(
					'id'       => 'enable_auto_updater',
					'type'     => 'switch',
					'title'    => esc_html__( 'Enable Theme Auto Updates', 'adama' ),
					'subtitle' => esc_html__( 'Auto updates can be enabled only when you enter your Envato username and API key.', 'adama' ),
					'on'       => esc_html__( 'Yes', 'adama' ),
					'off'      => esc_html__( 'No', 'adama' ),
					'default'  => false,
				),
			),
		);

		// Backup
		$sections['backup'] = array(
			'id'		 => 'backup',  // 'import/export',
			'icon'       => 'dashicons-before dashicons-backup',
			'title'      => esc_html__( 'Backup', 'adama' ),
			'heading'    => '',
			'submenu'    => true,
			'customizer' => false,
			'fields'     => array(
				array(
					'id'         => 'redux_import_export',
					'type'       => 'import_export',
					'full_width' => true,
				)
			),
		);


		// Change content background if footer uncover is enabled
		add_filter( 'redux/validate/' . GALACTICA_THEME_OPTIONS . '/before_validation', 'adama_change_content_bg', 10, 2 );

		// Manage compiled CSS
		add_action( 'redux/options/' . GALACTICA_THEME_OPTIONS . '/compiler', 'adama_options_compiler', 10, 3 );

		// After options change
		add_action( 'redux/options/' . GALACTICA_THEME_OPTIONS . '/settings/change', 'adama_options_changed', 10, 2 );

		// Init options
		// NOTE: Filtering the sections array can be done via filter 'redux/options/' . GALACTICA_THEME_OPTIONS . '/sections'
		new ReduxFramework( $sections, $args, $tabs );

		// Recompiles custom css if marked for recompiling
		galactica_recompile_options_css();
	}
}
adama_options_init();


if ( !function_exists( 'adama_options_compiler' ) ) {
	/**
	 * Try to write typography & styling options CSS to a file or save to options for inline output.
	 *
	 * @param array $options
	 * @param string $css
	 * @param array $changed_values
	 * @return void
	 */
	function adama_options_compiler( $options, $css, $changed_values ) {

		// Pattern Background Image
		if ( !empty( $options['body_background_image_type'] ) && $options['body_background_image_type'] === 'pattern' && !empty( $options['body_background_image_pattern'] ) ) {
			$css .= "
				body {
					background-repeat:repeat;
					background-image:url('{$options['body_background_image_pattern']}');
				}";
		}

		// Navigation Item Height
		if ( !empty( $options['header_nav_height'] ) ) {
			$header_nav_height = galactica_int_range( $options['header_nav_height'], 0 );
			$css .= "
				.galactica-default-navbar > .galactica-nav > li > a {
					height: {$header_nav_height}px;
				}";
		}

		// Mobile Menu Breakpoint
		if ( isset( $options['header_nav_mobile_breakpoint'] ) ) {
			$header_nav_mobile_breakpoint = galactica_int_range( $options['header_nav_mobile_breakpoint'], 0 );
		} else {
			$header_nav_mobile_breakpoint = 768;
		}
		$css .= "
			@media (max-width: {$header_nav_mobile_breakpoint}px) {
				.galactica-default-navbar {
					display: none;
				}

				.galactica-navbar-header {
					margin-right: -15px;
					margin-left: -15px;
				}
				.navbar-primary .header-buttons-wrap,
				.navbar-primary .primary-menu-container,
				.navbar-primary .galactica-navbar-header,
				.galactica-mobile-navbar {
					display: block;
				}
				.navbar-primary .galactica-navbar-header {
					float: none;
				}

				header .galactica-navbar-brand,
				.header-layout-centered .galactica-navbar-header .galactica-navbar-brand {
					float: left;
					margin: 14px 0;
					padding: 0 15px;
				}
				header .galactica-navbar-brand img {
					max-width: 100%;
				}

				.header-layout-centered .galactica-navbar-header {
					text-align: left;
				}
			}";

		// Add custom CSS to the compiled CSS
		if ( !empty( $options['custom_css'] ) ) {
			$css .= trim( $options['custom_css'] );
		}


		// Trim whitespaces
		$css = preg_replace( '/\s+/', ' ', $css );
		$css = preg_replace( '/ ([,;\{\}])/', '$1', $css );
		$css = preg_replace( '/([,:;>\{\}]) /', '$1', $css );


		// This is temporary commented out because options file is very tiny and it's faster if we just use inline style
		// // Save options.css in file if possible or in database if not
		// $is_file = false;
		//
		// $file = galactica_theme_upload_file( 'options.css' );
		// if ( !empty( $file ) && !empty( $file['path'] ) ) {
		// 	if ( empty( $wp_filesystem ) ) {
		// 		require_once( ABSPATH . '/wp-admin/includes/file.php' );
		// 		WP_Filesystem();
		// 	}
		//
		// 	if ( !empty( $wp_filesystem ) && $wp_filesystem->put_contents( $file['path'], $css, FS_CHMOD_FILE ) ) {
		// 		$is_file = true;
		// 	}
		// }
		//
		// if ( $is_file ) {
		// 	delete_option( 'adama_options_compiled_css' );
		// } else {
		// 	update_option( 'adama_options_compiled_css', $css, true );
		// }
		update_option( 'adama_options_compiled_css', $css, true );
	}
}

if ( ! function_exists( 'adama_options_changed' ) ) {
	/**
	 * Detect if any of the slugs have been changed and mark rewrite rules for flushing.
	 *
	 * @param array $options
	 * @param array $changed_values
	 * @return void
	 */
	function adama_options_changed( $options, $changed_values ) {

		$flush_rewrite_rules = false;


		// List of options with slugs
		$options_list = array(
			'portfolio_slug',
			'portfolio_slug_category',
			'portfolio_slug_tags',
			'portfolio_slug_technology',
			'team_slug',
			'team_slug_skills',
		);

		// Check if any of the slugs were changed
		foreach ( $options_list as $option ) {
			if ( !empty( $changed_values[ $option ] ) ) {
				$flush_rewrite_rules = true;
				break;
			}
		}

		// Mark option to rewrite flush rules
		if ( $flush_rewrite_rules ) {
			galactica_flush_rewrite_rules_schedule();
		}

	}
}

if ( ! function_exists( 'adama_change_content_bg' ) ) {
	/**
	 * Change content background if footer uncover is enabled
	 *
	 * @param array $plugin_options
	 * @param array $options
	 * @return array
	 */
	function adama_change_content_bg( $plugin_options, $options ) {

		if ( !empty( $plugin_options['footer_enable_uncover'] ) && ( empty( $plugin_options['content_background']['background-color'] ) || $plugin_options['content_background']['background-color'] === 'transparent' ) ) {
			$plugin_options['content_background']['background-color'] = '';
		}

		return $plugin_options;
	}
}
