<?php
/**
 * Galactica Themes
 *
 * Set up the styles and scripts.
 *
 * @package GalacticaThemes
 * @subpackage Theme
 */

// Don't allow direct access
if ( !defined( 'ABSPATH' ) ) {
	die;
}


if ( !function_exists( 'adama_assets' ) ) {
	/**
	 * Register theme styles and scripts
	 *
	 * @return void
	 */
	function adama_assets() {

		global $wp_scripts;

		// Include minified scripts and styles when script debug mode is off
		$min_sufix = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '.min';

		// Current page template
		$page_template = get_page_template_slug( get_queried_object_id() );


		// Font CSS
		$google_fonts = adama_google_font_options();
		if ( !empty( $google_fonts ) ) {
			foreach ( $google_fonts as $google_font_subset => $google_font ) {
				wp_enqueue_style( 'font-google-' . esc_attr( str_replace( ',', '_', $google_font_subset ) ), $google_font );
			}
		}


		// CSS
		wp_enqueue_style( 'bootstrap', GALACTICA_THEME_ASSETS_URL . '/vendor/bootstrap/bootstrap' . $min_sufix . '.css', array(), GALACTICA_THEME_VERSION );

		// Main CSS based on selected color scheme
		$color_scheme = galactica_option( 'color_scheme', 'blue' );
		wp_enqueue_style( 'adama-main', GALACTICA_THEME_ASSETS_URL . '/css/style-' . $color_scheme . '.css', array( 'bootstrap' ), GALACTICA_THEME_VERSION );

		// Custom CSS
		$file_path = get_stylesheet_directory() . '/assets/css/custom.css';
		if ( file_exists( $file_path ) ) {
			wp_enqueue_style( 'adama-custom', get_stylesheet_directory_uri() . '/assets/css/custom.css', array(), galactica_file_mod_time( $file_path ) );
		}

		// Options CSS
		if ( get_option( 'adama_options_compiled_css' ) ) {
			// Output options CSS inline
			add_action( 'wp_head', 'adama_output_compiled_css', 150 );
		} else {
			// Compiled options CSS in a file
			$file = galactica_theme_upload_file( 'options.css' );
			if ( !empty( $file ) && file_exists( $file['path'] ) ) {
				wp_enqueue_style( 'adama-options', $file['url'], array(), galactica_file_mod_time( $file['path'] ) );
			}
		}


		// Lesser Font CSS
		$font_icons = galactica_icon_fonts();
		if ( !empty( $font_icons ) ) {
			foreach ( $font_icons as $font_icon_id => $font_icon ) {
				wp_enqueue_style( $font_icon_id, $font_icon['url'], array(), GALACTICA_THEME_VERSION );
			}
		}


		wp_enqueue_style( 'animate', GALACTICA_THEME_ASSETS_URL . '/vendor/animate/animate' . $min_sufix . '.css', array(), GALACTICA_THEME_VERSION );


		global $post;

		$menu_breakpoint = galactica_option( 'header_nav_mobile_breakpoint', 768 );
		$menu_breakpoint = !empty( $menu_breakpoint ) ? $menu_breakpoint : 768;

		// JavaScript settings & localisation
		$localize_data = array(
			'ajaxurl'                => admin_url( 'admin-ajax.php' ),
			'nonceAjax'              => wp_create_nonce( 'frontend_ajax' ),
			'pageID'                 => empty( $post->ID ) ? null : $post->ID,
			'footerEnableToTop'      => galactica_option( 'footer_enable_totop', true ),
			'footerEnableUncover'    => galactica_option( 'footer_enable_uncover', true ),

			'lightboxEnableForPosts' => galactica_option( 'lightbox_enable_for_posts', true ),
			'lightboxSkin'           => galactica_option( 'lightbox_skin', true ),
			'lightboxDirection'      => galactica_option( 'lightbox_direction', true ),
			'lightboxShowArrows'     => galactica_option( 'lightbox_show_arrows', true ),
			'lightboxShowThumnails'  => galactica_option( 'lightbox_show_thumnails', false ),

			'tErrorRequiredField'    => esc_html__( 'Please fill in the required field.', 'adama' ),
			'tErrorInvalidEmail'     => esc_html__( 'Email address seems invalid.', 'adama' ),
			'tErrorGlobal'           => esc_html__( 'There was an error submitting the form. Please check that you have entered valid information and try again.', 'adama' ),
			'tErrorGeocode'          => esc_html__( 'Geocode was not successful for the following reason: ', 'adama' ),
			'tErrorAjaxBadData'      => esc_html__( 'Bad data returned.', 'adama' ),
			'tErrorAjaxAborting'     => esc_html__( 'Aborting, too many ajax fails.', 'adama' ),
			'tInfiniteScrollLoading' => esc_html__( 'Loading...', 'adama' ),

			'mobileMenuBreakpoint'   => $menu_breakpoint,

			'equalHeight'            => array(
				array(
					// Equal height for product boxes
					'selector' => '.products li.product > .shop-product-meta',
					'carousel' => '.carousel-products',
				),
				array(
					// Equal height for team members
					'selector' => '.team-member > .figure',
					'carousel' => '.carousel-team-members',
				),
				array(
					// Equal height for team members
					'selector' => '.team-member > .entry-summary',
					'carousel' => '.carousel-team-members',
				),
				array(
					// Equal height for Content Box shortcode
					'selector' => '.content-boxes-border .content-box-content',
				),
				array(
					// Equal height for Content Box shortcode
					'selector' => '.galactica-posts-border .galactica-posts-content-wrap',
				),
			),
		);

		// JavaScript Head
		if ( galactica_is_retina_on() ) {
			wp_enqueue_script( 'picturefill', GALACTICA_THEME_ASSETS_URL . '/vendor/picturefill/picturefill' . $min_sufix . '.js', array(), GALACTICA_THEME_VERSION, false );
		}

		wp_enqueue_script( 'modernizr', GALACTICA_THEME_ASSETS_URL . '/vendor/modernizr/modernizr.custom.min.js', array(), GALACTICA_THEME_VERSION, false );
		wp_enqueue_script( 'adama-ie8', GALACTICA_THEME_ASSETS_URL . '/vendor/ie8.min.js', array(), GALACTICA_THEME_VERSION, false ); // html5shiv.js, respond.min.js
		$wp_scripts->add_data( 'adama-ie8', 'conditional', 'lt IE 9' );
		wp_enqueue_script( 'jquery' );
		wp_localize_script( 'jquery', 'adamaSettings', $localize_data );

		// JavaScript Footer
		wp_register_script( 'jquery-owl-carousel', GALACTICA_THEME_ASSETS_URL . '/vendor/owl-carousel/owl.carousel' . $min_sufix . '.js', array( 'jquery' ), GALACTICA_THEME_VERSION, true );
		wp_register_script( 'jquery-mixitup', GALACTICA_THEME_ASSETS_URL . '/vendor/mixitup/jquery.mixitup' . $min_sufix . '.js', array( 'jquery' ), GALACTICA_THEME_VERSION, true );
		wp_register_script( 'jquery-mixitup-init', GALACTICA_THEME_ASSETS_URL . '/vendor/mixitup/jquery.mixitup.init' . $min_sufix . '.js', array( 'jquery', 'jquery-mixitup' ), GALACTICA_THEME_VERSION, true );
		wp_register_script( 'jquery-easypiechart', GALACTICA_THEME_ASSETS_URL . '/vendor/easypiechart/jquery.easypiechart' . $min_sufix . '.js', array( 'jquery' ), GALACTICA_THEME_VERSION, true );

		if ( in_array( $page_template, array( 'templates/portfolio-boxed.php', 'templates/portfolio-fluid.php' ) ) || // is_page_template
			 is_tax( array( 'bsg_portfolio_category', 'bsg_portfolio_technology', 'bsg_portfolio_tags' ) ) ||
			 is_post_type_archive( 'bsg_portfolio' )
			) {
			wp_enqueue_script( 'jquery-mixitup' );
			wp_enqueue_script( 'jquery-mixitup-init' );
		}

		if ( is_search() || ( ( adama_get_blog_layout() === 'masonry' ) && ( is_archive() || is_home() ) ) ) {
			wp_enqueue_script( 'masonry' );
		}

		wp_enqueue_script( 'adama-vendor', GALACTICA_THEME_ASSETS_URL . '/vendor/vendor.min.js', array( 'jquery' ), GALACTICA_THEME_VERSION, true );
		wp_enqueue_script( 'adama-theme', GALACTICA_THEME_ASSETS_URL . '/js/theme.js', array( 'jquery', 'adama-vendor' ), GALACTICA_THEME_VERSION, true );

		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}

	}
}
add_action( 'wp_enqueue_scripts', 'adama_assets', 5 );

if ( !function_exists( 'adama_output_compiled_css' ) ) {
	/**
	 * Output compiled CSS in case compiled CSS could not be written to a file.
	 *
	 * @return void
	 */
	function adama_output_compiled_css() {
		$compiled_css = get_option( 'adama_options_compiled_css' );
		if ( !empty( $compiled_css ) ) {
			echo '<style type="text/css" id="adama-options-css">' . $compiled_css . '</style>';
		}
	}
}

if ( !function_exists( 'adama_google_font_options' ) ) {
	/**
	 * Fetch font options
	 *
	 * @return array
	 */
	function adama_google_font_options() {

		$theme_options = $GLOBALS[GALACTICA_THEME_OPTIONS];


		// Google fonts used by default
		$font_options = array(
			'font_body' => array(
				'family' => 'Open Sans',
				'weight' => array( '400', '700', '400italic', '700italic' ),
			),
			'font_page_title' => array(
				'family' => 'Roboto',
				'weight' => array( '500' ),
			),
			'font_headings' => array(
				'family' => 'Roboto',
				'weight' => array( '300', '400', '500', '700', '400italic', '700italic' ),
			),
			'font_menu' => array(
				'family' => 'Open Sans',
				'weight' => array( '400' ),
			),
			'font_menu_dropdown' => array(
				'family' => 'Open Sans',
				'weight' => array( '400' ),
			),
		);


		$wp_font_subset = function_exists( 'galactica_core_wordpress_font_subset' ) ? galactica_core_wordpress_font_subset() : 'no-subset';

		// Merge default fonts with user selected fonts
		foreach ( $font_options as $option => $font_option ) {

			// Default font subset from WP
			$subset_raw = $wp_font_subset;

			if ( !empty( $theme_options[$option] ) ) {

				$user_font_option = $theme_options[$option];

				// Remove font if not Google font
				if ( empty( $user_font_option['google'] ) ) {
					unset( $font_options[$option] );
					continue;
				}


				// Replace font family with user selected option
				if ( !empty( $user_font_option['font-family'] ) ) {
					$font_options[$option]['family'] = $user_font_option['font-family'];
				}

				// Add selected font weight if it doesn't exist already
				if ( !empty( $user_font_option['font-weight'] ) ) {
					if ( array_search( $user_font_option['font-weight'], $font_option['weight'] ) === false ) {
						$font_options[$option]['weight'][] = $user_font_option['font-weight'];
					}
				}

				// Add font subset
				if ( !empty( $user_font_option['subsets'] ) ) {
					$subset_raw = $user_font_option['subsets'];
				}

			}

			// Expand subset
			$font_subsets = 'latin,latin-ext';
			switch ( $subset_raw ) {
				case 'cyrillic':
				case 'cyrillic-ext':
					$font_subsets .= ',cyrillic,cyrillic-ext';
					break;
				case 'greek':
				case 'greek-ext':
					$font_subsets .= ',greek,greek-ext';
					break;
				case 'devanagari':
					$font_subsets .= ',devanagari';
					break;
				case 'vietnamese':
					$font_subsets .= ',vietnamese';
					break;
			}
			$font_options[$option]['subset'] = $font_subsets;

		}


		// Group Google fonts by subset and by family
		$google_fonts = array();
		foreach ( $font_options as $font_option ) {
			$subset = $font_option['subset'];
			$family = $font_option['family'];

			if ( !isset( $google_fonts[$subset] ) ) {
				$google_fonts[$subset] = array();
			}

			if ( !isset( $google_fonts[$subset][$family] ) ) {
				$google_fonts[$subset][$family] = $font_option['weight'];
			} else {
				$google_fonts[$subset][$family] = array_merge( $google_fonts[$subset][$family], $font_option['weight'] );
			}
		}


		// Build Google font URLs for each subset
		foreach ( $google_fonts as $font_subset => $google_font ) {
			$family = array();
			foreach ( $google_font as $font_family => $font_weights ) {
				$family[] = sprintf( '%s:%s', urlencode( $font_family ), implode( ',', array_unique( $font_weights ) ) );
			}

			$google_fonts[$font_subset] = sprintf( '//fonts.googleapis.com/css?family=%s&subset=%s', implode( '|', $family ), $font_subset );
		}

		return (array) apply_filters( 'galactica/assets/google_fonts', $google_fonts );
	}
}

if ( !function_exists( 'adama_customize_preview_init' ) ) {
	/**
	 * Bind JS handlers to make Theme Customizer preview reload changes asynchronously.
	 *
	 * @return void
	 */
	function adama_customize_preview_init() {

		// Include minified scripts and styles when script debug mode is off
		$min_sufix = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '.min';

		wp_enqueue_script( 'adama-customizer', GALACTICA_THEME_ASSETS_URL . '/js/theme-customizer' . $min_sufix . '.js', array( 'jquery', 'customize-preview' ), GALACTICA_THEME_VERSION, true );
	}
}
add_action( 'customize_preview_init', 'adama_customize_preview_init' );

if ( !function_exists( 'adama_custom_scripts_footer' ) ) {
	/**
	 * Print custom scripts after _wp_footer_scripts function (use for non-important scripts like analytics and social)
	 *
	 * @return void
	 */
	function adama_custom_scripts_footer() {

		// Tracking code
		$tracking_code = galactica_option( 'tracking_code' );
		if ( !empty( $tracking_code ) ) {
			echo $tracking_code;
		}

	}
}
add_action( 'wp_print_footer_scripts', 'adama_custom_scripts_footer', 200, 0 );
