<?php
/**
 * Galactica Themes
 *
 * Comments
 *
 * @package GalacticaThemes
 * @subpackage Theme
 */

// Don't allow direct access
if ( !defined( 'ABSPATH' ) ) {
	die;
}


if ( !function_exists( 'adama_comments_open' ) ) {
	/**
	 * Override comments setting for certain post types
	 * NOTE: This filter is also used to determine when the comments script will be loaded
	 *
	 * @param bool $open Whether comments are set to be closed or opened.
	 * @param int $post_id Post ID of the current post.
	 * @return bool True if the comments are open.
	 */
	function adama_comments_open( $open, $post_id ) {
		if ( !$open ) {
			return false;
		}

		$post_type = get_post_type( $post_id );
		switch ( $post_type ) {
			case 'bsg_portfolio':
				$open = (bool) galactica_option( 'portfolio_comments_enable', false );
				break;
			case 'bsg_team':
				$open = (bool) galactica_option( 'team_comments_enable', false );
				break;
		}

		return $open;
	}
}
add_filter( 'comments_open', 'adama_comments_open', 10, 2 );

if ( !function_exists( 'adama_comment' ) ) {
	/**
	 * Template for comments and pingbacks.
	 * Used as a callback by wp_list_comments() for displaying the comments.
	 *
	 * @param object $comment
	 * @param array $args
	 * @param int $depth
	 */
	function adama_comment( $comment, $args, $depth ) {
		$GLOBALS['comment'] = $comment;
		?>

		<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">

			<?php
			switch ( $comment->comment_type ) {
				case 'pingback':
				case 'trackback':
					// Display pingbacks & trackbacks differently than normal comments
					?>
						<p><?php esc_html_e( 'Pingback:', 'adama' ); ?> <?php comment_author_link(); ?> <?php edit_comment_link( esc_html__( '(Edit)', 'adama' ), '<span class="edit-link">', '</span>' ); ?></p>
					<?php
					break;

				default:
					// Proceed with normal comments
					global $post;
				?>

					<article id="comment-<?php comment_ID(); ?>" class="comment-container">
						<header class="comment-author vcard">
							<div class="avatar-wrap">
								<?php echo get_avatar( $comment, $args['avatar_size'], '', get_comment_author() ); ?>
							</div>

							<?php
								printf( '<cite class="fn">%1$s:</cite>',
									get_comment_author_link()
								);
							?>
						</header><!-- .comment-author -->

						<div class="comment-meta">
							<?php
								printf( '<a href="%1$s"><time datetime="%2$s">%3$s</time></a>',
									esc_url( get_comment_link( $comment->comment_ID ) ),
									esc_attr( get_comment_time( 'c' ) ),
									/* translators: 1: date, 2: time */
									sprintf( esc_html__( '%1$s at %2$s', 'adama' ), get_comment_date(), get_comment_time() )
								);
							?>
						</div><!-- .comment-meta -->

						<?php if ( $comment->comment_approved == '0' ) : ?>
							<p class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'adama' ); ?></p>
						<?php endif; ?>

						<section class="comment-content">
							<?php comment_text(); ?>
							<?php edit_comment_link( esc_html__( 'Edit', 'adama' ), '<p class="edit-link">', '</p>' ); ?>

							<div class="reply">
								<?php comment_reply_link( array_merge( $args, array( 'reply_text' => esc_html__( 'Reply', 'adama' ), 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
							</div><!-- .reply -->
						</section><!-- .comment-content -->

					</article>

					<?php
					break;
			}
	}
}

if ( !function_exists( 'adama_comment_form_default_fields' ) ) {
	/**
	 * Filter the default comment form fields.
	 *
	 * @param array $fields The default comment fields.
	 * @return array Modified comment fields.
	 */
	function adama_comment_form_default_fields( $fields ) {
		$commenter = wp_get_current_commenter();
		$req       = get_option( 'require_name_email' );
		$aria_req  = ( $req ? " aria-required='true'" : '' );
		$html_req  = ( $req ? " required='required'" : '' );

		$fields['author'] = '<p class="comment-form-author comment-form-inline-field">' . '<label for="author" class="sr-only">' . esc_html__( 'Name', 'adama' ) . ( $req ? ' ' . esc_html__( '(Required)', 'adama' ) : '' ) . '</label> ' .
							'<input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" placeholder="' . esc_html__( 'Name', 'adama' ) . ( $req ? ' ' . esc_html__( '(Required)', 'adama' ) : '' ) . '" size="30"' . $aria_req . $html_req . ' /></p>';
		$fields['email'] = '<p class="comment-form-email comment-form-inline-field"><label for="email" class="sr-only">' . esc_html__( 'Email', 'adama' ) . ( $req ? ' ' . esc_html__( '(Required)', 'adama' ) : '' ) . '</label> ' .
						   '<input id="email" name="email" type="email" value="' . esc_attr(  $commenter['comment_author_email'] ) . '" placeholder="' . esc_html__( 'Email', 'adama' ) . ( $req ? ' ' . esc_html__( '(Required)', 'adama' ) : '' ) . '" size="30"' . $aria_req . $html_req  . ' /></p>';
		$fields['url'] = '<p class="comment-form-url comment-form-inline-field"><label for="url" class="sr-only">' . esc_html__( 'Website', 'adama' ) . '</label> ' .
						 '<input id="url" name="url" type="url" value="' . esc_attr( $commenter['comment_author_url'] ) . '" placeholder="' . esc_html__( 'Website', 'adama' ) . '" size="30" /></p>';

		return $fields;
	}
}
add_filter( 'comment_form_default_fields', 'adama_comment_form_default_fields' );

if ( !function_exists( 'adama_comment_form_fields' ) ) {
	/**
	 * Filter the comment form fields.
	 *
	 * @param array $comment_fields The comment fields.
	 * @return array Modified comment fields.
	 */
	function adama_comment_form_fields( $comment_fields ) {
		$comment_fields['comment'] = array_shift( $comment_fields );

		return $comment_fields;
	}
}
add_filter( 'comment_form_fields', 'adama_comment_form_fields' );
