<?php
/**
 * Galactica Themes
 *
 * Set up the theme and provides some helper functions.
 *
 * When using a child theme you can override certain functions (those wrapped
 * in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before
 * the parent theme's file, so the child theme functions would be used.
 * @link https://codex.wordpress.org/Child_Themes
 *
 * @package GalacticaThemes
 * @subpackage Theme
 */

// Don't allow direct access
if ( !defined( 'ABSPATH' ) ) {
	die;
}


// Configure framework and theme
define( 'GALACTICA_THEME_NAME', 'Adama' );
define( 'GALACTICA_THEME_SLUG', 'adama' );
define( 'GALACTICA_THEME_OPTIONS', 'adama_options' );
define( 'GALACTICA_THEME_VERSION', '1.5.4' );
define( 'GALACTICA_WEBSITE_URL', 'http://adama.galactica-themes.com/' );

/** @var string Minimum WordPress requirement. Theme only works in WordPress 3.8 or later */
define( 'GALACTICA_MIN_WP_VERSION', '3.8' );

/** @var string Prefix for Widget names */
define( 'GALACTICA_WIDGET_PREFIX', 'Galactica' );

// Define paths
define( 'GALACTICA_FRAMEWORK_DIR', get_template_directory() . '/framework' );
define( 'GALACTICA_FRAMEWORK_URL', get_template_directory_uri() . '/framework' );
define( 'GALACTICA_FRAMEWORK_ASSETS_URL', GALACTICA_FRAMEWORK_URL . '/assets' );
define( 'GALACTICA_THEME_DIR', get_template_directory() . '/theme' );
define( 'GALACTICA_THEME_ASSETS_DIR', get_template_directory() . '/assets' );
define( 'GALACTICA_THEME_ASSETS_URL', get_template_directory_uri() . '/assets' );

// WPML - Do not load Language selector CSS
define( 'ICL_DONT_LOAD_LANGUAGE_SELECTOR_CSS', true );


// Check if theme is compatible with current WordPress
if ( is_admin() && version_compare( $GLOBALS['wp_version'], GALACTICA_MIN_WP_VERSION, '<' ) ) {
	require_once( GALACTICA_FRAMEWORK_DIR . '/compatibility.php' );
}

// Load options in global scope for use in theme
$GLOBALS[GALACTICA_THEME_OPTIONS] = (array) get_option( GALACTICA_THEME_OPTIONS, array() );

// Load Galactica Framework
require_once( GALACTICA_FRAMEWORK_DIR . '/framework-init.php' );


if ( !function_exists( 'adama_woocommerce_image_dimensions' ) ) {
	/**
	 * Define WooCommerce image sizes
	 *
	 * @return void
	 */
	function adama_woocommerce_image_dimensions() {
		global $pagenow;

		if ( !isset( $_GET['activated'] ) || $pagenow != 'themes.php' ) {
			return;
		}

		$catalog = array(
			'width' 	=> '522',	// 2 x 261px
			'height'	=> '0',	    // px
			'crop'		=> 0 		// false
		);
		$single = array(
			'width' 	=> '1094',	// 2 x 547px
			'height'	=> '0',	    // px
			'crop'		=> 0 		// false
		);
		$thumbnail = array(
			'width' 	=> '332',	// 2 x 166px
			'height'	=> '366',	// 2 x 183px
			'crop'		=> 1 		// true
		);

		// Image sizes
		update_option( 'shop_catalog_image_size', $catalog ); 		// Product category thumbs
		update_option( 'shop_single_image_size', $single ); 		// Single product image
		update_option( 'shop_thumbnail_image_size', $thumbnail ); 	// Image gallery thumbs
	}
}
add_action( 'after_switch_theme', 'adama_woocommerce_image_dimensions', 1 );

if ( !function_exists( 'adama_portfolio_images_json' ) ) {
	/**
	 * Returns array of portfolio images in JSON format
	 *
	 * @return string
	 */
	function adama_portfolio_images_json() {

		$images = '';

		$portfolio_type = get_post_meta( get_the_ID(), 'adama_portfolio_single_type', true );
		$gallery = get_post_meta( get_the_ID(), 'adama_portfolio_gallery', true );
		if ( $portfolio_type === 'slider' && !empty( $gallery ) ) {
			$images = array();
			foreach ( $gallery as $item ) {
				$images[] = array( 'url' => $item );
			}
			$images = json_encode( $images );
		}

		return $images;
	}
}

/**
 * Set up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support post thumbnails.
 *
 * @return void
 */
function adama_after_setup_theme() {

	// Localization support
	load_theme_textdomain( 'adama', get_template_directory() . '/languages' );

	// Enable post formats for the blog
	add_theme_support( 'post-formats', array( 'image', 'audio', 'video', 'gallery', 'link', 'quote', 'aside', 'status' ) );

	// Add support for title tags
	add_theme_support( 'title-tag' );

	// Add RSS feed links to <head> for posts and comments.
	add_theme_support( 'automatic-feed-links' );

	// Enable support for Post Thumbnails
	add_theme_support( 'post-thumbnails' );

	// Switch default core markup for search form, comment form, and comments to output valid HTML5.
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
	));

	// Enable custom excerpts for pages
	add_post_type_support( 'page', 'excerpt' );

	// This theme uses its own gallery styles.
	add_filter( 'use_default_gallery_style', '__return_false' );


	// Declare WooCommerce compatibility
	add_theme_support( 'woocommerce' );

	// Declare Yoast Breadcrumbs support
	add_theme_support( 'yoast-seo-breadcrumbs' );

	// Add support for custom logo
	add_theme_support( 'custom-logo' );

	if ( !is_admin() ) {
		// Front end only

		// Register theme styles & scripts
		require_once( GALACTICA_THEME_DIR . '/theme-assets.php' );

		// Meta tags
		require_once( GALACTICA_THEME_DIR . '/theme-meta.php' );

		// Contains functions used in template files
		require_once( GALACTICA_THEME_DIR . '/theme-template.php' );

		// Pagination functions
		require_once( GALACTICA_THEME_DIR . '/theme-pagination.php' );

		// Comments functions
		require_once( GALACTICA_THEME_DIR . '/theme-comment.php' );

	} else {
		// Admin only

		// Theme Plugins (after_setup_theme)
		require_once( GALACTICA_THEME_DIR . '/theme-plugins.php' );

	}

	// Media functions and walkers
	require_once( GALACTICA_THEME_DIR . '/theme-media.php' );

	// Menu functions and walkers
	require_once( GALACTICA_THEME_DIR . '/theme-menu.php' );

	// Init sidebars (widget areas)
	require_once( GALACTICA_THEME_DIR . '/theme-sidebars.php' );

	// WooCommerce
	require_once( GALACTICA_THEME_DIR . '/theme-woocommerce.php' );


	// Filters & actions
	add_action( 'init', 'adama_theme_init_before_widget_init', 0 );
	add_action( 'init', 'adama_theme_init' );
	add_action( 'admin_init', 'adama_theme_admin_init' );
}
add_action( 'after_setup_theme', 'adama_after_setup_theme' );

/**
 * Runs on WordPress init, before widgets_init hook so we use it to register custom post types
 *
 * @return void
 */
function adama_theme_init_before_widget_init() {

	// Include minified scripts and styles when script debug mode is off
	$min_sufix = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '.min';


	// List all icon fonts available in theme
	$font_icons = array(
		'font-awesome' => array(
			'name'  => 'Font Awesome',
			'class' => 'fa',
			'url'   => GALACTICA_THEME_ASSETS_URL . '/fonts/font-awesome/css/font-awesome' . $min_sufix . '.css',
		),
		'linearicons' => array(
			'name'  => 'Linearicons',
			'class' => 'lnr',
			'url'   => GALACTICA_THEME_ASSETS_URL . '/fonts/linearicons/style' . $min_sufix . '.css',
		),
	);
	$GLOBALS['galactica_icon_fonts'] = (array) apply_filters( 'galactica/assets/icon_fonts', $font_icons );

	// Return list of available animations
	add_action( 'galactica/shortcode/animation/list', 'galactica_animation_list' );


	// Post type customizations
	require_once( GALACTICA_THEME_DIR . '/theme-post-type.php' );


	// Register Portfolio post type
	if ( class_exists( 'Galactica_Portfolio' ) && galactica_option( 'portfolio_enabled', true ) ) {
		$args = array(
			'items_per_page' => max( galactica_portfolio_meta_option( 'portfolio_items_per_page', 9 ), galactica_portfolio_meta_option( 'portfolio_columns', 3 ) ),
			'slugs'          => array(
				'bsg_portfolio'            => galactica_option( 'portfolio_slug' ),
				'bsg_portfolio_category'   => galactica_option( 'portfolio_slug_category' ),
				'bsg_portfolio_technology' => galactica_option( 'portfolio_slug_technology' ),
				'bsg_portfolio_tags'       => galactica_option( 'portfolio_slug_tags' ),
			),
		);
		new Galactica_Portfolio( $args );


		// Custom columns
		if ( is_admin() ) {
			add_filter( 'manage_edit-bsg_portfolio_columns', 'adama_portfolio_column_add' );
			add_action( 'manage_bsg_portfolio_posts_custom_column', 'adama_portfolio_column_print', 10, 2 );
		}
	}

	// Register Team post type
	if ( class_exists( 'Galactica_Team' ) && galactica_option( 'team_enabled', true ) ) {
		$args = array(
			'slugs' => array(
				'bsg_team'        => galactica_option( 'team_slug' ),
				'bsg_team_skills' => galactica_option( 'team_slug_skills' ),
			),
		);
		new Galactica_Team( $args );

		// Custom columns
		if ( is_admin() ) {
			add_filter( 'manage_edit-bsg_team_columns', 'adama_team_column_add' );
			add_action( 'manage_bsg_team_posts_custom_column', 'adama_team_column_print', 10, 2 );
		}
	}

	// Register FAQ post type
	if ( class_exists( 'Galactica_FAQ' ) && galactica_option( 'faq_enabled', true ) ) {
		new Galactica_FAQ();
	}

	// Register Testimonials post type
	if ( class_exists( 'Galactica_Testimonial' ) && galactica_option( 'testimonials_enabled', true ) ) {
		new Galactica_Testimonial();

		// Custom columns
		if ( is_admin() ) {
			add_filter( 'manage_edit-bsg_testimonial_columns', 'adama_testimonial_column_add' );
			add_action( 'manage_bsg_testimonial_posts_custom_column', 'adama_testimonial_column_print', 10, 2 );
		}
	}

	// Initialize Sidebar Manager
	if ( class_exists( 'Galactica_Sidebar_Manager' ) && galactica_option( 'enable_sidebar_manager', true ) ) {
		new Galactica_Sidebar_Manager();
	}

	// Initialize Galactica Simple Slider
	if ( class_exists( 'Galactica_Simple_Slider' ) && galactica_option( 'simple_slider_enable', true ) ) {
		new Galactica_Simple_Slider();
	}

}

/**
 * Runs on WordPress Init
 *
 * @return void
 */
function adama_theme_init() {

	if ( !is_admin() ) {
		// Front end only

		// In case older version of WP does not support title-tag
		if ( !function_exists( '_wp_render_title_tag' ) ) {
			add_action( 'wp_head', 'adama_head_title', 1 );
		}

		// Add custom theme classes to the body element
		add_filter( 'body_class', 'adama_body_class' );

	} else {
		// Admin only

		// Build options panel (init)
		require_once( GALACTICA_THEME_DIR . '/config-options.php' );

		// Build metabox panels
		require_once( GALACTICA_THEME_DIR . '/config-metabox.php' );

	}

}

/**
 * Admin init
 *
 * @return void
 */
function adama_theme_admin_init() {

	// Theme update check
	if ( galactica_option( 'enable_auto_updater', false ) ) {

		$envato_username = trim( galactica_option( 'updater_envato_username', '' ) );
		$envato_api_key = trim( galactica_option( 'updater_envato_api_key', '' ) );

		if ( !empty( $envato_username ) && !empty( $envato_api_key ) ) {
			galactica_updater_check_updates( $envato_username, $envato_api_key, 'Galactica Themes' );
		}

	}

}
