<?php
/**
 * Galactica Themes
 *
 * Functions for handling images and other media.
 *
 * @package GalacticaThemes
 * @subpackage Theme
 */

// Don't allow direct access
if ( !defined( 'ABSPATH' ) ) {
	die;
}


// Maximum allowed width for any content in the theme, like oEmbeds and images added to posts
if ( ! isset( $GLOBALS['content_width'] ) ) {
	$GLOBALS['content_width'] = 1140;
}

if ( !function_exists( 'adama_get_placeholder_image' ) ) {
	/**
	 * Returns image placeholder.
	 *
	 * @param bool $output_html Optional. Choose to return jsut image URL or HTML with <img> tag.
	 * @param int $post_id Optional. Post ID.
	 * @param string|array $html_attr Optional. Query string or array of attributes.
	 * @return string
	 */
	function adama_get_placeholder_image( $output_html = true, $post_id = null, $html_attr = '' ) {
		$placeholder_url = apply_filters( 'adama/media/placeholder_url', GALACTICA_THEME_ASSETS_URL . '/images/placeholder.png', $post_id );

		if ( !$output_html ) {
			return $placeholder_url;
		}


		$placeholder_path = apply_filters( 'adama/media/placeholder_path', GALACTICA_THEME_ASSETS_DIR . '/images/placeholder.png', $post_id );
		list( $width, $height ) = getimagesize( $placeholder_path );
		$hwstring = image_hwstring( $width, $height );
		$placeholder_html = rtrim( "<img $hwstring" );

		$default_attr = array(
			'src' => $placeholder_url,
			'class' => 'image-placeholder',
			'alt' => '',
		);
		$html_attr = wp_parse_args( $html_attr, $default_attr );
		$html_attr = array_map( 'esc_attr', $html_attr );

		foreach ( $html_attr as $name => $value ) {
			$placeholder_html .= " $name=" . '"' . $value . '"';
		}
		$placeholder_html .= ' />';

		return apply_filters( 'adama/media/placeholder_html', $placeholder_html, $post_id, $html_attr );
	}
}

if ( !function_exists( 'adama_get_post_thumbnail' ) ) {
	/**
	 * Returns featured image.
	 *
	 * @param string|array $html_attr Optional. Query string or array of HTML attributes.
	 * @param array $attr Optional. Array of attributes.
	 * @return string
	 */
	function adama_get_post_thumbnail( $html_attr = '', $attr = array() ) {
		if ( has_post_thumbnail() ) {
			$attachment_id = get_post_thumbnail_id();
			return galactica_get_attachment_image( $attachment_id, $html_attr, $attr );
		} else {
			return adama_get_placeholder_image( true, null, $html_attr );
		}
	}
}

if ( !function_exists( 'adama_srcset_image_width' ) ) {
	/**
	 * Define maximum image width to be included in a 'srcset' attribute
	 *
	 * @param int $max_width The maximum image width to be included in the 'srcset'
	 * @param array $size_array Array of width and height values in pixels (in that order)
	 * @return int
	 */
	function adama_srcset_image_width( $max_width, $size_array ) {
		return 1920;
	}
}
add_filter( 'max_srcset_image_width', 'adama_srcset_image_width', 10, 2 );


if ( !function_exists( 'adama_custom_logo' ) ) {
	/**
	 * Change html for custom logo
	 *
	 * @param string $html The HTML code for custom logo
	 * @return string
	 */
	function adama_custom_logo( $html ) {
		$html = str_replace( 'custom-logo-link', 'custom-logo-link galactica-navbar-brand', $html );
		return $html;
	}
}
add_filter( 'get_custom_logo', 'adama_custom_logo', 10, 1 );
