<?php
/**
 * Galactica Themes
 *
 * Functions used for pagination.
 *
 * @package GalacticaThemes
 * @subpackage Theme
 */

// Don't allow direct access
if ( !defined( 'ABSPATH' ) ) {
	die;
}


if ( !function_exists( 'adama_pagination' ) ) {
	/**
	 * Output pagination links
	 *
	 * @param array $args Arguments to customize how the page links are output.
	 * @return void
	 */
	function adama_pagination( $args = array() ) {
		global $wp_query;

		$max_num_pages = intval( $wp_query->max_num_pages );

		// Don't show pagination if only one page
		if ( $max_num_pages <= 1 ) {
			return;
		}

		// Need an unlikely integer
		$big = 999999999;

		// Default setup
		$defaults = array(
			'base'      => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
			'format'    => '?paged=%#%',
			'current'   => max( 1, get_query_var( 'paged' ) ),
			'total'     => $max_num_pages,
			'end_size'  => 1,
			'mid_size'  => 3,
			'type'      => 'array',
			'prev_text' => '<i class="fa fa-angle-double-left"></i>',
			'next_text' => '<i class="fa fa-angle-double-right"></i>',
		);
		$args = wp_parse_args( $args, $defaults );

		// Build pagination links
		$page_links = paginate_links( apply_filters( 'adama/pagination/args', $args ) );

		// Build pagination HTML
		$output = '<div class="pagination-container">';
		$output .= '<ul class="pagination"><li>';
		$output .= join( '</li><li>', $page_links );
		$output .= '</li></ul>';
		$output .= '</div>';

		// Allow override by developers
		$output = apply_filters( 'adama/pagination/html', $output, $page_links );

		echo $output;
	}
}

if ( !function_exists( 'adama_prev_next' ) ) {
	/**
	 * Display navigation to next/previous post.
	 *
	 * @param string       $link_prev        Optional. Prevoious link permalink format.
	 * @param string       $link_next        Optional. Next link permalink format.
	 * @param bool         $in_same_term     Optional. Whether link should be in a same taxonomy term.
	 * @param array|string $excluded_terms   Optional. Array or comma-separated list of excluded term IDs.
	 * @param string       $taxonomy         Optional. Taxonomy, if $in_same_term is true. Default 'category'.
	 *
	 * @return void
	 */
	function adama_prev_next( $link_prev = null, $link_next = null, $in_same_term = false, $excluded_terms = '', $taxonomy = 'category' ) {
		if ( !is_singular() ) {
			return;
		}

		$link_prev = is_null( $link_prev ) ? esc_html__( 'Previous', 'adama' ) : $link_prev;
		$link_next = is_null( $link_next ) ? esc_html__( 'Next', 'adama' ) : $link_next;

		$output = '';

		$prev_link = get_previous_post_link( '<li class="link-prev">%link</li>', esc_html( $link_prev ), $in_same_term, $excluded_terms, $taxonomy );
		$next_link = get_next_post_link( '<li class="link-next">%link</li>', esc_html( $link_next ), $in_same_term, $excluded_terms, $taxonomy );

		if ( $prev_link || $next_link ) {
			// Build pagination HTML
			$output .= '<div class="prev-next-pagination-container">';
				$output .= '<div class="container container-inner">';
					$output .= '<ul class="prev-next-pagination">';
						$output .= $prev_link;
						$output .= $next_link;
					$output .= '</ul>';
				$output .= '</div>';
			$output .= '</div>';
		}

		// Allow override by developers
		$output = apply_filters( 'adama/pagination/prevnext/html', $output );

		echo $output;
	}
}

if ( !function_exists( 'adama_comment_nav' ) ) {
	/**
	 * Display navigation to next/previous comments when applicable.
	 *
	 * @return void
	 */
	function adama_comment_nav() {
		// Are there comments to navigate through?
		if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) :
		?>
			<nav class="navigation comment-navigation" role="navigation">
				<h2 class="screen-reader-text"><?php esc_html_e( 'Comment navigation', 'adama' ); ?></h2>
				<div class="nav-links clearfix">
					<?php
					if ( $prev_link = get_previous_comments_link( esc_html__( '&larr; Older Comments', 'adama' ) ) ) :
						printf( '<div class="nav-previous pull-left">%s</div>', $prev_link );
					endif;

					if ( $next_link = get_next_comments_link( esc_html__( 'Newer Comments &rarr;', 'adama' ) ) ) :
						printf( '<div class="nav-next pull-right">%s</div>', $next_link );
					endif;
					?>
				</div><!-- .nav-links -->
			</nav><!-- .comment-navigation -->
		<?php
		endif;
	}
}
