<?php
/**
 * Galactica Themes
 *
 * Functions for handling plugins
 *
 * @package GalacticaThemes
 * @subpackage Theme
 */

// Don't allow direct access
if ( !defined( 'ABSPATH' ) ) {
	die;
}


// Plugin Activation
require_once( GALACTICA_FRAMEWORK_DIR . '/vendor/tgm-plugin-activation/class-tgm-plugin-activation.php' );

/**
 * Register the required plugins for this theme.
 *
 * @return void
 */
function adama_register_required_plugins() {
	/**
	 * Array of plugin arrays. Required keys are name and slug.
	 * If the source is NOT from the .org repo, then source is also required.
	 */
	$plugins = array(
		array(
			'name'               => 'Galactica Core',
			'slug'               => 'galactica-core',
			'source'             => get_template_directory() . '/theme/plugins/galactica-core.zip',
			'required'           => true,
			'version'            => '1.2.4',
			'force_activation'   => false,
			'force_deactivation' => false,
		),
		array(
			'name'               => 'Galactica Demo Importer',
			'slug'               => 'galactica-importer',
			'source'             => get_template_directory() . '/theme/plugins/galactica-importer.zip',
			'required'           => false,
			'version'            => '1.0.5',
			'force_activation'   => false,
			'force_deactivation' => true,
		),
		array(
			'name'               => 'LayerSlider WP',
			'slug'               => 'LayerSlider',
			'source'             => get_template_directory() . '/theme/plugins/layerslider.zip',
			'required'           => false,
			'version'            => '6.7.6',
			'force_activation'   => false,
			'force_deactivation' => true,
		),
	);


	// Check if Galactica Core plugin is activated (NOTE: is_plugin_active does not work at this stage)
	$is_core_active = in_array( 'galactica-core/galactica-core.php', (array) get_option( 'active_plugins', array() ) );

	// Show notices if core plugin is not activated, otherwise only if user can install plugins
	$show_notices = !$is_core_active || current_user_can( 'install_plugins' );

	/**
	 * Configuration settings.
	 */
	$config = array(
		'id'           => 'galactica',                 // Unique ID for hashing notices for multiple instances of TGMPA
		'default_path' => '',                          // Default absolute path to bundled plugins
		'menu'         => 'galactica-install-plugins', // Menu slug
		'parent_slug'  => 'themes.php',                // Parent menu slug (if changing this note the capability)
		'has_notices'  => $show_notices,               // Show admin notices or not
		'dismissable'  => $is_core_active,             // If false, a user cannot dismiss the nag message
		'dismiss_msg'  => '',                          // If 'dismissable' is false, this message will be output at top of nag
		'is_automatic' => false,                       // Automatically activate plugins after installation or not
		'message'      => '',                          // Message to output right before the plugins table

		'strings'      => array(
			'page_title' => esc_html__( 'Theme Plugins', 'adama' ),
			'menu_title' => esc_html__( 'Theme Plugins', 'adama' ),
		)
	);

	if ( $is_core_active && function_exists( 'galactica_core_plugins_page' ) ) {
		$config['parent_slug'] = GALACTICA_THEME_OPTIONS; // Parent menu slug (if changing this note the capability)
		$config['capability']  = 'manage_options';        // Capability needed to view plugin install page, should be a capability associated with the parent menu used
	}

	tgmpa( $plugins, $config );
}
add_action( 'tgmpa_register', 'adama_register_required_plugins' );

// Customize LayerSlider notifications about licence
if ( defined( 'LS_PLUGIN_BASE' ) ) {
	if ( !get_option( 'layerslider-authorized-site', null ) ) {

		// Remove Layer Slider nag about licence purchase
		remove_action( 'after_plugin_row_' . LS_PLUGIN_BASE, 'layerslider_plugins_purchase_notice', 10, 3 );

		// Disable LayerSlider updater - because it overrides LayerSlider update from theme/TGMPA
		if ( class_exists( 'KM_PluginUpdatesV3' ) && !empty( $GLOBALS['wp_filter'] ) && !empty( $GLOBALS['wp_filter']['pre_set_site_transient_update_plugins'] ) ) {
			// Wordpress 4.7 uses WP_Hook
			if ( $GLOBALS['wp_filter']['pre_set_site_transient_update_plugins'] instanceof WP_Hook ) {
				$callbacks = &$GLOBALS['wp_filter']['pre_set_site_transient_update_plugins']->callbacks;
			} else {
				$callbacks = &$GLOBALS['wp_filter']['pre_set_site_transient_update_plugins'];
			}

			if ( !empty( $callbacks[10] ) ) {
				foreach ( $callbacks[10] as $key => $filter ) {
					if ( isset( $filter['function'][0] ) && ( $filter['function'][0] instanceof KM_PluginUpdatesV3 ) ) {
						unset( $callbacks[10][$key] );
					}
				}
			}
		}

//		/**
//		 * Add notification about Layer Slider auto updates
//		 *
//		 * @param string $plugin_file Path to the plugin file, relative to the plugins directory.
//		 * @param array $plugin_data An array of plugin data.
//		 * @param string $status Status of the plugin.
//		 * @return void
//		 */
//		function adama_layerslider_plugins_purchase_notice( $plugin_file, $plugin_data, $status ) {
//
//			$table = _get_list_table( 'WP_Plugins_List_Table' );
			/* ?>

			<tr class="plugin-update-tr">
				<td colspan="<?php echo $table->get_column_count(); ?>" class="plugin-update colspanchange">
					<div class="update-message ls-plugins-screen-notice">
						<?php esc_html_e( 'LayerSlider plugin comes bundled with your theme so updates are provided by your theme.', 'adama' ); ?>
					</div>
				</td>
			</tr>

			<?php */
//		}
//		add_action( 'after_plugin_row_' . LS_PLUGIN_BASE, 'adama_layerslider_plugins_purchase_notice', 10, 3 );
	}

	/**
	 * Activates notification about LayerSlider being received by a theme
	 * Must be used on layerslider_ready/after_setup_theme
	 *
	 * @return void
	 */
	$GLOBALS['lsAutoUpdateBox'] = false;
}

if ( function_exists( 'layerslider_set_as_theme' ) ) {
	layerslider_set_as_theme();
}

if ( function_exists( 'layerslider_hide_promotions' ) ) {
	layerslider_hide_promotions();
}
