<?php
/**
 * Galactica Themes
 *
 * Post type customizations
 *
 * @package GalacticaThemes
 * @subpackage Theme
 */

// Don't allow direct access
if ( !defined( 'ABSPATH' ) ) {
	die;
}


if ( !function_exists( 'adama_portfolio_column_add' ) ) {
	/**
	 * Add custom columns for Portfolio post type
	 *
	 * @param array $columns An associative array with columns
	 * @return array
	 */
	function adama_portfolio_column_add( $columns ) {

		$insert_position_columns = array(
			'title' => array(
				'portfolio_image' => esc_html__( 'Picture', 'adama' ),
			),
		);
		$columns = galactica_column_insert( $columns, $insert_position_columns );


		// Change column title
		$columns['taxonomy-bsg_portfolio_category']   = esc_html__( 'Categories', 'adama' );
		$columns['taxonomy-bsg_portfolio_technology'] = esc_html__( 'Technologies', 'adama' );

		return $columns;
	}
}

if ( !function_exists( 'adama_portfolio_column_print' ) ) {
	/**
	 * Return data for custom Portfolio columns
	 *
	 * @param string $column_name The key of the column to display
	 * @param int $post_id The ID of the current post
	 * @return void
	 */
	function adama_portfolio_column_print( $column_name, $post_id ) {
		switch ( $column_name ) {
			case 'portfolio_image':
				galactica_column_print_image( $post_id );
				break;
		}
	}
}

if ( !function_exists( 'adama_team_column_add' ) ) {
	/**
	 * Add custom columns for Team post type
	 *
	 * @param array $columns An associative array with columns
	 * @return array
	 */
	function adama_team_column_add( $columns ) {

		$insert_position_columns = array(
			'title' => array(
				'team_image' => esc_html__( 'Image', 'adama' ),
			),
			'taxonomy-bsg_team_skills' => array(
				'team_job_title' => esc_html__( 'Job Title', 'adama' ),
			),
		);

		return galactica_column_insert( $columns, $insert_position_columns );
	}
}

if ( !function_exists( 'adama_team_column_print' ) ) {
	/**
	 * Return data for custom Team columns
	 *
	 * @param string $column_name The key of the column to display
	 * @param int $post_id The ID of the current post
	 * @return void
	 */
	function adama_team_column_print( $column_name, $post_id ) {
		switch ( $column_name ) {
			case 'team_image':
				galactica_column_print_image( $post_id );
				break;
			 case 'team_job_title':
				$value = get_post_meta( $post_id, 'adama_team_job_title', true );
				echo !empty( $value ) ? $value : esc_html_x( '&#8212;', 'Empty job title column - team member', 'adama' );
				break;
		}
	}
}

if ( !function_exists( 'adama_testimonial_column_add' ) ) {
	/**
	 * Add custom columns for Testimonial post type
	 *
	 * @param array $columns An associative array with columns
	 * @return array
	 */
	function adama_testimonial_column_add( $columns ) {

		$insert_position_columns = array(
			'title' => array(
				'testimonial_image' => esc_html__( 'Image', 'adama' ),
			),
			'date' => array(
				'testimonial_author' => esc_html__( 'Author', 'adama' ),
			),
		);

		return galactica_column_insert( $columns, $insert_position_columns );
	}
}

if ( !function_exists( 'adama_testimonial_column_print' ) ) {
	/**
	 * Return data for custom Testimonial columns
	 *
	 * @param string $column_name The key of the column to display
	 * @param int $post_id The ID of the current post
	 * @return void
	 */
	function adama_testimonial_column_print( $column_name, $post_id ) {
		switch ( $column_name ) {
			case 'testimonial_image':
				galactica_column_print_image( $post_id );
				break;
			case 'testimonial_author':
				$value = get_post_meta( $post_id, 'adama_testimonial_author', true );
				echo !empty( $value ) ? $value : esc_html_x( '&#8212;', 'Empty author column - testimonials', 'adama' );
				break;
		}
	}
}
