<?php
/**
 * Galactica Themes
 *
 * Set up the sidebars (widget areas).
 *
 * @package GalacticaThemes
 * @subpackage Theme
 */

// Don't allow direct access
if ( !defined( 'ABSPATH' ) ) {
	die;
}


if ( !function_exists( 'adama_sidebars_add' ) ) {
	/**
	 * Initialize sidebars
	 *
	 * @return void
	 */
	function adama_sidebars_add() {

		// Main sidebar
		register_sidebar( array(
			'name'          => esc_html__( 'Sidebar', 'adama' ),
			'id'            => 'galactica-sidebar',
			'description'   => esc_html__( "Widgets in this area will be shown in website's sidebar.", 'adama' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widgettitle">',
			'after_title'   => '</h4>',
		) );

		if ( galactica_option( 'blog_enable_custom_sidebar', false ) ) {
			// Custom blog sidebar
			register_sidebar( array(
				'name'          => esc_html__( 'Blog Sidebar', 'adama' ),
				'id'            => 'galactica-blog-sidebar',
				'description'   => esc_html__( "Widgets in this area will be shown in blog's sidebar.", 'adama' ),
				'before_widget' => '<div id="%1$s" class="widget %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<h4 class="widgettitle">',
				'after_title'   => '</h4>',
			) );
		}

		if ( galactica_option( 'portfolio_enable_custom_sidebar', false ) ) {
			// Custom portfolio sidebar
			register_sidebar( array(
				'name'          => esc_html__( 'Portfolio Sidebar', 'adama' ),
				'id'            => 'galactica-portfolio-sidebar',
				'description'   => esc_html__( "Widgets in this area will be shown in portfolio's sidebar.", 'adama' ),
				'before_widget' => '<div id="%1$s" class="widget %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<h4 class="widgettitle">',
				'after_title'   => '</h4>',
			) );
		}

		// Slideout sidebar
		if ( galactica_option( 'enable_slideout', true ) ) {
			register_sidebar( array(
				'name'          => esc_html__( 'Slideout', 'adama' ),
				'id'            => 'galactica-slideout',
				'description'   => esc_html__( 'Widgets in this area will be shown in slideout sidebar on the right side.', 'adama' ),
				'before_widget' => '<div id="%1$s" class="widget %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<h4 class="widgettitle">',
				'after_title'   => '</h4>',
			) );
		}

		// Footer widget areas
		$footer_widget_count = intval( galactica_option( 'footer_widget_areas', 4 ) );
		for ( $i = 1; $i <= $footer_widget_count; $i++ ) {
			register_sidebar( array(
				'name'          => sprintf( esc_html__( 'Footer %d', 'adama' ), $i ),
				'id'            => sprintf( 'galactica-footer-%d', $i ),
				'description'   => sprintf( esc_html__( 'Footer Widgets Region %d.', 'adama' ), $i ),
				'before_widget' => '<div id="%1$s" class="widget widget-footer %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<h4 class="widgettitle">',
				'after_title'   => '</h4>',
			) );
		}
	}
}
add_action( 'widgets_init', 'adama_sidebars_add', 9 );
