<?php
/**
 * Thankyou page
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/checkout/thankyou.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     3.2.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} ?>

<div class="woocommerce-order shop-checkout-thankyou">

	<?php if ( $order ) : ?>

		<?php if ( $order->has_status( 'failed' ) ) : ?>

			<p class="woocommerce-notice woocommerce-notice--error woocommerce-thankyou-order-failed"><?php _e( 'Unfortunately your order cannot be processed as the originating bank/merchant has declined your transaction. Please attempt your purchase again.', 'adama' ); ?></p>

			<p class="woocommerce-notice woocommerce-notice--error woocommerce-thankyou-order-failed-actions">
				<a href="<?php echo esc_url( $order->get_checkout_payment_url() ); ?>" class="button pay"><?php _e( 'Pay', 'adama' ) ?></a>
				<?php if ( is_user_logged_in() ) : ?>
					<a href="<?php echo esc_url( adama_wc_get_page_permalink( 'myaccount' ) ); ?>" class="button pay"><?php _e( 'My account', 'adama' ); ?></a>
				<?php endif; ?>
			</p>

		<?php else : ?>

			<?php
			// WooCommerce > v3.0.0
			if ( method_exists( $order, 'get_billing_first_name' ) ) {
				$billing_first_name = $order->get_billing_first_name();
			} else {
				$billing_first_name = $order->billing_first_name;
			} ?>

			<p class="woocommerce-notice woocommerce-notice--success woocommerce-thankyou-order-received"><?php echo apply_filters( 'woocommerce_thankyou_order_received_text', sprintf( esc_html__( 'Thank you, %s. Your order has been received.', 'adama' ), $billing_first_name ), $order ); ?></p>

			<ul class="woocommerce-order-overview woocommerce-thankyou-order-details order_details">

				<li class="woocommerce-order-overview__order order">
					<?php _e( 'Order number:', 'adama' ); ?>
					<strong><?php echo $order->get_order_number(); ?></strong>
				</li>

				<li class="woocommerce-order-overview__date date">
					<?php _e( 'Date:', 'adama' ); ?>
					<strong>
						<?php
						// WooCommerce > v3.0.0
						if ( function_exists( 'wc_format_datetime' ) ) {
							echo wc_format_datetime( $order->get_date_created() );
						} else {
							echo date_i18n( get_option( 'date_format' ), strtotime( $order->order_date ) );
						} ?>
					</strong>
				</li>

				<?php /* WooCommerce > v3.2.0 */ if ( method_exists( $order, 'get_billing_email' ) && is_user_logged_in() && $order->get_user_id() === get_current_user_id() && $order->get_billing_email() ) : ?>
					<li class="woocommerce-order-overview__email email">
						<?php _e( 'Email:', 'adama' ); ?>
						<strong><?php echo $order->get_billing_email(); ?></strong>
					</li>
				<?php endif; ?>

				<li class="woocommerce-order-overview__total total">
					<?php _e( 'Total:', 'adama' ); ?>
					<strong><?php echo $order->get_formatted_order_total(); ?></strong>
				</li>

				<?php
				// WooCommerce > v3.0.0
				if ( method_exists( $order, 'get_payment_method_title' ) ) {
					$order_get_payment_method_title = $order->get_payment_method_title();
				} else {
					$order_get_payment_method_title = $order->payment_method_title;
				} ?>
				<?php if ( $order_get_payment_method_title ) : ?>

				<li class="woocommerce-order-overview__payment-method method">
					<?php _e( 'Payment method:', 'adama' ); ?>
					<strong><?php echo wp_kses_post( $order_get_payment_method_title ); ?></strong>
				</li>

				<?php endif; ?>

			</ul>
			<div class="clear"></div>

		<?php endif; ?>

		<?php
		// WooCommerce > v3.0.0
		if ( method_exists( $order, 'get_payment_method' ) ) {
			$order_get_payment_method = $order->get_payment_method();
		} else {
			$order_get_payment_method = $order->payment_method;
		}

		// WooCommerce > v3.0.0
		if ( method_exists( $order, 'get_id' ) ) {
			$order_get_id = $order->get_id();
		} else {
			$order_get_id = $order->id;
		} ?>
		<?php do_action( 'woocommerce_thankyou_' . $order_get_payment_method, $order_get_id ); ?>
		<?php do_action( 'woocommerce_thankyou', $order_get_id ); ?>

	<?php else : ?>

		<p class="woocommerce-notice woocommerce-notice--success woocommerce-thankyou-order-received"><?php echo apply_filters( 'woocommerce_thankyou_order_received_text', esc_html__( 'Thank you. Your order has been received.', 'adama' ), null ); ?></p>

	<?php endif; ?>

</div>
