<?php
/**
 * Show options for ordering
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/loop/orderby.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     3.3.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

// Currently selected products per page
$current_products_per_page = apply_filters( 'loop_shop_per_page', get_option( 'posts_per_page' ) );

// Available options
$products_per_page = apply_filters( 'adama/shop/products_per_page', array(
	'12' => '12',
	'24' => '24',
	'36' => '36',
	'48' => '48',
) );
?>
<form class="woocommerce-ordering" method="get">
	<select name="<?php echo GALACTICA_WC_SHOP_ITEMS_PER_PAGE; ?>" class="orderby">
		<?php foreach ( $products_per_page as $id => $name ) : ?>
			<option value="<?php echo esc_attr( $id ); ?>" <?php selected( $current_products_per_page, $id, true ) ?>><?php echo esc_html( $name ); ?></option>
		<?php endforeach; ?>
	</select>
	<select name="orderby" class="orderby">
		<?php foreach ( $catalog_orderby_options as $id => $name ) : ?>
			<option value="<?php echo esc_attr( $id ); ?>" <?php selected( $orderby, $id ); ?>><?php echo esc_html( $name ); ?></option>
		<?php endforeach; ?>
	</select>
	<?php
	$exclude_keys = array( 'orderby', 'submit' , 'product-page', 'paged', GALACTICA_WC_SHOP_ITEMS_PER_PAGE );
	// WooCommerce > 3.0.0
	if ( function_exists( 'wc_query_string_form_fields' ) ) {
		?><input type="hidden" name="paged" value="1" /><?php
		wc_query_string_form_fields( null, $exclude_keys );
	} else {
		// Keep query string vars intact
		foreach ( $_GET as $key => $val ) {
			if ( in_array( $key, $exclude_keys ) ) {
				continue;
			}
			if ( is_array( $val ) ) {
				foreach( $val as $innerVal ) {
					echo '<input type="hidden" name="' . esc_attr( $key ) . '[]" value="' . esc_attr( $innerVal ) . '" />';
				}
			} else {
				echo '<input type="hidden" name="' . esc_attr( $key ) . '" value="' . esc_attr( $val ) . '" />';
			}
		}
	} ?>
</form>
